<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'kys: voksen, voksen, lys teint og medium til lys teint',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'kys: voksen, voksen, lys teint og medium teint',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'kys: voksen, voksen, lys teint og medium til mørk teint',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'kys: voksen, voksen, lys teint og mørk teint',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'kys: voksen, voksen, medium til lys teint og lys teint',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'kys: voksen, voksen, medium til lys teint og medium teint',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'kys: voksen, voksen, medium til lys teint og medium til mørk teint',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'kys: voksen, voksen, medium til lys teint og mørk teint',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'kys: voksen, voksen, medium teint og lys teint',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'kys: voksen, voksen, medium teint og medium til lys teint',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'kys: voksen, voksen, medium teint og medium til mørk teint',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'kys: voksen, voksen, medium teint og mørk teint',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'kys: voksen, voksen, medium til mørk teint og lys teint',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'kys: voksen, voksen, medium til mørk teint og medium til lys teint',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'kys: voksen, voksen, medium til mørk teint og medium teint',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'kys: voksen, voksen, medium til mørk teint og mørk teint',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'kys: voksen, voksen, mørk teint og lys teint',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'kys: voksen, voksen, mørk teint og medium til lys teint',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'kys: voksen, voksen, mørk teint og medium teint',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'kys: voksen, voksen, mørk teint og medium til mørk teint',
    '👨🏻‍❤‍💋‍👨🏻' => 'kys: mand, mand og lys teint',
    '👨🏻‍❤‍💋‍👨🏼' => 'kys: mand, mand, lys teint og medium til lys teint',
    '👨🏻‍❤‍💋‍👨🏽' => 'kys: mand, mand, lys teint og medium teint',
    '👨🏻‍❤‍💋‍👨🏾' => 'kys: mand, mand, lys teint og medium til mørk teint',
    '👨🏻‍❤‍💋‍👨🏿' => 'kys: mand, mand, lys teint og mørk teint',
    '👨🏼‍❤‍💋‍👨🏻' => 'kys: mand, mand, medium til lys teint og lys teint',
    '👨🏼‍❤‍💋‍👨🏼' => 'kys: mand, mand og medium til lys teint',
    '👨🏼‍❤‍💋‍👨🏽' => 'kys: mand, mand, medium til lys teint og medium teint',
    '👨🏼‍❤‍💋‍👨🏾' => 'kys: mand, mand, medium til lys teint og medium til mørk teint',
    '👨🏼‍❤‍💋‍👨🏿' => 'kys: mand, mand, medium til lys teint og mørk teint',
    '👨🏽‍❤‍💋‍👨🏻' => 'kys: mand, mand, medium teint og lys teint',
    '👨🏽‍❤‍💋‍👨🏼' => 'kys: mand, mand, medium teint og medium til lys teint',
    '👨🏽‍❤‍💋‍👨🏽' => 'kys: mand, mand og medium teint',
    '👨🏽‍❤‍💋‍👨🏾' => 'kys: mand, mand, medium teint og medium til mørk teint',
    '👨🏽‍❤‍💋‍👨🏿' => 'kys: mand, mand, medium teint og mørk teint',
    '👨🏾‍❤‍💋‍👨🏻' => 'kys: mand, mand, medium til mørk teint og lys teint',
    '👨🏾‍❤‍💋‍👨🏼' => 'kys: mand, mand, medium til mørk teint og medium til lys teint',
    '👨🏾‍❤‍💋‍👨🏽' => 'kys: mand, mand, medium til mørk teint og medium teint',
    '👨🏾‍❤‍💋‍👨🏾' => 'kys: mand, mand og medium til mørk teint',
    '👨🏾‍❤‍💋‍👨🏿' => 'kys: mand, mand, medium til mørk teint og mørk teint',
    '👨🏿‍❤‍💋‍👨🏻' => 'kys: mand, mand, mørk teint og lys teint',
    '👨🏿‍❤‍💋‍👨🏼' => 'kys: mand, mand, mørk teint og medium til lys teint',
    '👨🏿‍❤‍💋‍👨🏽' => 'kys: mand, mand, mørk teint og medium teint',
    '👨🏿‍❤‍💋‍👨🏾' => 'kys: mand, mand, mørk teint og medium til mørk teint',
    '👨🏿‍❤‍💋‍👨🏿' => 'kys: mand, mand og mørk teint',
    '👩🏻‍❤‍💋‍👨🏻' => 'kys: kvinde, mand og lys teint',
    '👩🏻‍❤‍💋‍👨🏼' => 'kys: kvinde, mand, lys teint og medium til lys teint',
    '👩🏻‍❤‍💋‍👨🏽' => 'kys: kvinde, mand, lys teint og medium teint',
    '👩🏻‍❤‍💋‍👨🏾' => 'kys: kvinde, mand, lys teint og medium til mørk teint',
    '👩🏻‍❤‍💋‍👨🏿' => 'kys: kvinde, mand, lys teint og mørk teint',
    '👩🏼‍❤‍💋‍👨🏻' => 'kys: kvinde, mand, medium til lys teint og lys teint',
    '👩🏼‍❤‍💋‍👨🏼' => 'kys: kvinde, mand og medium til lys teint',
    '👩🏼‍❤‍💋‍👨🏽' => 'kys: kvinde, mand, medium til lys teint og medium teint',
    '👩🏼‍❤‍💋‍👨🏾' => 'kys: kvinde, mand, medium til lys teint og medium til mørk teint',
    '👩🏼‍❤‍💋‍👨🏿' => 'kys: kvinde, mand, medium til lys teint og mørk teint',
    '👩🏽‍❤‍💋‍👨🏻' => 'kys: kvinde, mand, medium teint og lys teint',
    '👩🏽‍❤‍💋‍👨🏼' => 'kys: kvinde, mand, medium teint og medium til lys teint',
    '👩🏽‍❤‍💋‍👨🏽' => 'kys: kvinde, mand og medium teint',
    '👩🏽‍❤‍💋‍👨🏾' => 'kys: kvinde, mand, medium teint og medium til mørk teint',
    '👩🏽‍❤‍💋‍👨🏿' => 'kys: kvinde, mand, medium teint og mørk teint',
    '👩🏾‍❤‍💋‍👨🏻' => 'kys: kvinde, mand, medium til mørk teint og lys teint',
    '👩🏾‍❤‍💋‍👨🏼' => 'kys: kvinde, mand, medium til mørk teint og medium til lys teint',
    '👩🏾‍❤‍💋‍👨🏽' => 'kys: kvinde, mand, medium til mørk teint og medium teint',
    '👩🏾‍❤‍💋‍👨🏾' => 'kys: kvinde, mand og medium til mørk teint',
    '👩🏾‍❤‍💋‍👨🏿' => 'kys: kvinde, mand, medium til mørk teint og mørk teint',
    '👩🏿‍❤‍💋‍👨🏻' => 'kys: kvinde, mand, mørk teint og lys teint',
    '👩🏿‍❤‍💋‍👨🏼' => 'kys: kvinde, mand, mørk teint og medium til lys teint',
    '👩🏿‍❤‍💋‍👨🏽' => 'kys: kvinde, mand, mørk teint og medium teint',
    '👩🏿‍❤‍💋‍👨🏾' => 'kys: kvinde, mand, mørk teint og medium til mørk teint',
    '👩🏿‍❤‍💋‍👨🏿' => 'kys: kvinde, mand og mørk teint',
    '👩🏻‍❤‍💋‍👩🏻' => 'kys: kvinde, kvinde og lys teint',
    '👩🏻‍❤‍💋‍👩🏼' => 'kys: kvinde, kvinde, lys teint og medium til lys teint',
    '👩🏻‍❤‍💋‍👩🏽' => 'kys: kvinde, kvinde, lys teint og medium teint',
    '👩🏻‍❤‍💋‍👩🏾' => 'kys: kvinde, kvinde, lys teint og medium til mørk teint',
    '👩🏻‍❤‍💋‍👩🏿' => 'kys: kvinde, kvinde, lys teint og mørk teint',
    '👩🏼‍❤‍💋‍👩🏻' => 'kys: kvinde, kvinde, medium til lys teint og lys teint',
    '👩🏼‍❤‍💋‍👩🏼' => 'kys: kvinde, kvinde og medium til lys teint',
    '👩🏼‍❤‍💋‍👩🏽' => 'kys: kvinde, kvinde, medium til lys teint og medium teint',
    '👩🏼‍❤‍💋‍👩🏾' => 'kys: kvinde, kvinde, medium til lys teint og medium til mørk teint',
    '👩🏼‍❤‍💋‍👩🏿' => 'kys: kvinde, kvinde, medium til lys teint og mørk teint',
    '👩🏽‍❤‍💋‍👩🏻' => 'kys: kvinde, kvinde, medium teint og lys teint',
    '👩🏽‍❤‍💋‍👩🏼' => 'kys: kvinde, kvinde, medium teint og medium til lys teint',
    '👩🏽‍❤‍💋‍👩🏽' => 'kys: kvinde, kvinde og medium teint',
    '👩🏽‍❤‍💋‍👩🏾' => 'kys: kvinde, kvinde, medium teint og medium til mørk teint',
    '👩🏽‍❤‍💋‍👩🏿' => 'kys: kvinde, kvinde, medium teint og mørk teint',
    '👩🏾‍❤‍💋‍👩🏻' => 'kys: kvinde, kvinde, medium til mørk teint og lys teint',
    '👩🏾‍❤‍💋‍👩🏼' => 'kys: kvinde, kvinde, medium til mørk teint og medium til lys teint',
    '👩🏾‍❤‍💋‍👩🏽' => 'kys: kvinde, kvinde, medium til mørk teint og medium teint',
    '👩🏾‍❤‍💋‍👩🏾' => 'kys: kvinde, kvinde og medium til mørk teint',
    '👩🏾‍❤‍💋‍👩🏿' => 'kys: kvinde, kvinde, medium til mørk teint og mørk teint',
    '👩🏿‍❤‍💋‍👩🏻' => 'kys: kvinde, kvinde, mørk teint og lys teint',
    '👩🏿‍❤‍💋‍👩🏼' => 'kys: kvinde, kvinde, mørk teint og medium til lys teint',
    '👩🏿‍❤‍💋‍👩🏽' => 'kys: kvinde, kvinde, mørk teint og medium teint',
    '👩🏿‍❤‍💋‍👩🏾' => 'kys: kvinde, kvinde, mørk teint og medium til mørk teint',
    '👩🏿‍❤‍💋‍👩🏿' => 'kys: kvinde, kvinde og mørk teint',
    '🧑🏻‍🫯‍🧑🏼' => 'brydere: lys teint og medium til lys teint',
    '🧑🏻‍🫯‍🧑🏽' => 'brydere: lys teint og medium teint',
    '🧑🏻‍🫯‍🧑🏾' => 'brydere: lys teint og medium til mørk teint',
    '🧑🏻‍🫯‍🧑🏿' => 'brydere: lys teint og mørk teint',
    '🧑🏼‍🫯‍🧑🏻' => 'brydere: medium til lys teint og lys teint',
    '🧑🏼‍🫯‍🧑🏽' => 'brydere: medium til lys teint og medium teint',
    '🧑🏼‍🫯‍🧑🏾' => 'brydere: medium til lys teint og medium til mørk teint',
    '🧑🏼‍🫯‍🧑🏿' => 'brydere: medium til lys teint og mørk teint',
    '🧑🏽‍🫯‍🧑🏻' => 'brydere: medium teint og lys teint',
    '🧑🏽‍🫯‍🧑🏼' => 'brydere: medium teint og medium til lys teint',
    '🧑🏽‍🫯‍🧑🏾' => 'brydere: medium teint og medium til mørk teint',
    '🧑🏽‍🫯‍🧑🏿' => 'brydere: medium teint og mørk teint',
    '🧑🏾‍🫯‍🧑🏻' => 'brydere: medium til mørk teint og lys teint',
    '🧑🏾‍🫯‍🧑🏼' => 'brydere: medium til mørk teint og medium til lys teint',
    '🧑🏾‍🫯‍🧑🏽' => 'brydere: medium til mørk teint og medium teint',
    '🧑🏾‍🫯‍🧑🏿' => 'brydere: medium til mørk teint og mørk teint',
    '🧑🏿‍🫯‍🧑🏻' => 'brydere: mørk teint og lys teint',
    '🧑🏿‍🫯‍🧑🏼' => 'brydere: mørk teint og medium til lys teint',
    '🧑🏿‍🫯‍🧑🏽' => 'brydere: mørk teint og medium teint',
    '🧑🏿‍🫯‍🧑🏾' => 'brydere: mørk teint og medium til mørk teint',
    '🧑🏻‍❤‍🧑🏼' => 'par med hjerte: voksen, voksen, lys teint og medium til lys teint',
    '🧑🏻‍❤‍🧑🏽' => 'par med hjerte: voksen, voksen, lys teint og medium teint',
    '🧑🏻‍❤‍🧑🏾' => 'par med hjerte: voksen, voksen, lys teint og medium til mørk teint',
    '🧑🏻‍❤‍🧑🏿' => 'par med hjerte: voksen, voksen, lys teint og mørk teint',
    '🧑🏼‍❤‍🧑🏻' => 'par med hjerte: voksen, voksen, medium til lys teint og lys teint',
    '🧑🏼‍❤‍🧑🏽' => 'par med hjerte: voksen, voksen, medium til lys teint og medium teint',
    '🧑🏼‍❤‍🧑🏾' => 'par med hjerte: voksen, voksen, medium til lys teint og medium til mørk teint',
    '🧑🏼‍❤‍🧑🏿' => 'par med hjerte: voksen, voksen, medium til lys teint og mørk teint',
    '🧑🏽‍❤‍🧑🏻' => 'par med hjerte: voksen, voksen, medium teint og lys teint',
    '🧑🏽‍❤‍🧑🏼' => 'par med hjerte: voksen, voksen, medium teint og medium til lys teint',
    '🧑🏽‍❤‍🧑🏾' => 'par med hjerte: voksen, voksen, medium teint og medium til mørk teint',
    '🧑🏽‍❤‍🧑🏿' => 'par med hjerte: voksen, voksen, medium teint og mørk teint',
    '🧑🏾‍❤‍🧑🏻' => 'par med hjerte: voksen, voksen, medium til mørk teint og lys teint',
    '🧑🏾‍❤‍🧑🏼' => 'par med hjerte: voksen, voksen, medium til mørk teint og medium til lys teint',
    '🧑🏾‍❤‍🧑🏽' => 'par med hjerte: voksen, voksen, medium til mørk teint og medium teint',
    '🧑🏾‍❤‍🧑🏿' => 'par med hjerte: voksen, voksen, medium til mørk teint og mørk teint',
    '🧑🏿‍❤‍🧑🏻' => 'par med hjerte: voksen, voksen, mørk teint og lys teint',
    '🧑🏿‍❤‍🧑🏼' => 'par med hjerte: voksen, voksen, mørk teint og medium til lys teint',
    '🧑🏿‍❤‍🧑🏽' => 'par med hjerte: voksen, voksen, mørk teint og medium teint',
    '🧑🏿‍❤‍🧑🏾' => 'par med hjerte: voksen, voksen, mørk teint og medium til mørk teint',
    '🧑🏻‍🐰‍🧑🏼' => 'personer med kaninører: lys teint og medium til lys teint',
    '🧑🏻‍🐰‍🧑🏽' => 'personer med kaninører: lys teint og medium teint',
    '🧑🏻‍🐰‍🧑🏾' => 'personer med kaninører: lys teint og medium til mørk teint',
    '🧑🏻‍🐰‍🧑🏿' => 'personer med kaninører: lys teint og mørk teint',
    '🧑🏼‍🐰‍🧑🏻' => 'personer med kaninører: medium til lys teint og lys teint',
    '🧑🏼‍🐰‍🧑🏽' => 'personer med kaninører: medium til lys teint og medium teint',
    '🧑🏼‍🐰‍🧑🏾' => 'personer med kaninører: medium til lys teint og medium til mørk teint',
    '🧑🏼‍🐰‍🧑🏿' => 'personer med kaninører: medium til lys teint og mørk teint',
    '🧑🏽‍🐰‍🧑🏻' => 'personer med kaninører: medium teint og lys teint',
    '🧑🏽‍🐰‍🧑🏼' => 'personer med kaninører: medium teint og medium til lys teint',
    '🧑🏽‍🐰‍🧑🏾' => 'personer med kaninører: medium teint og medium til mørk teint',
    '🧑🏽‍🐰‍🧑🏿' => 'personer med kaninører: medium teint og mørk teint',
    '🧑🏾‍🐰‍🧑🏻' => 'personer med kaninører: medium til mørk teint og lys teint',
    '🧑🏾‍🐰‍🧑🏼' => 'personer med kaninører: medium til mørk teint og medium til lys teint',
    '🧑🏾‍🐰‍🧑🏽' => 'personer med kaninører: medium til mørk teint og medium teint',
    '🧑🏾‍🐰‍🧑🏿' => 'personer med kaninører: medium til mørk teint og mørk teint',
    '🧑🏿‍🐰‍🧑🏻' => 'personer med kaninører: mørk teint og lys teint',
    '🧑🏿‍🐰‍🧑🏼' => 'personer med kaninører: mørk teint og medium til lys teint',
    '🧑🏿‍🐰‍🧑🏽' => 'personer med kaninører: mørk teint og medium teint',
    '🧑🏿‍🐰‍🧑🏾' => 'personer med kaninører: mørk teint og medium til mørk teint',
    '👨🏻‍🫯‍👨🏼' => 'mandlige brydere: lys teint og medium til lys teint',
    '👨🏻‍🫯‍👨🏽' => 'mandlige brydere: lys teint og medium teint',
    '👨🏻‍🫯‍👨🏾' => 'mandlige brydere: lys teint og medium til mørk teint',
    '👨🏻‍🫯‍👨🏿' => 'mandlige brydere: lys teint og mørk teint',
    '👨🏼‍🫯‍👨🏻' => 'mandlige brydere: medium til lys teint og lys teint',
    '👨🏼‍🫯‍👨🏽' => 'mandlige brydere: medium til lys teint og medium teint',
    '👨🏼‍🫯‍👨🏾' => 'mandlige brydere: medium til lys teint og medium til mørk teint',
    '👨🏼‍🫯‍👨🏿' => 'mandlige brydere: medium til lys teint og mørk teint',
    '👨🏽‍🫯‍👨🏻' => 'mandlige brydere: medium teint og lys teint',
    '👨🏽‍🫯‍👨🏼' => 'mandlige brydere: medium teint og medium til lys teint',
    '👨🏽‍🫯‍👨🏾' => 'mandlige brydere: medium teint og medium til mørk teint',
    '👨🏽‍🫯‍👨🏿' => 'mandlige brydere: medium teint og mørk teint',
    '👨🏾‍🫯‍👨🏻' => 'mandlige brydere: medium til mørk teint og lys teint',
    '👨🏾‍🫯‍👨🏼' => 'mandlige brydere: medium til mørk teint og medium til lys teint',
    '👨🏾‍🫯‍👨🏽' => 'mandlige brydere: medium til mørk teint og medium teint',
    '👨🏾‍🫯‍👨🏿' => 'mandlige brydere: medium til mørk teint og mørk teint',
    '👨🏿‍🫯‍👨🏻' => 'mandlige brydere: mørk teint og lys teint',
    '👨🏿‍🫯‍👨🏼' => 'mandlige brydere: mørk teint og medium til lys teint',
    '👨🏿‍🫯‍👨🏽' => 'mandlige brydere: mørk teint og medium teint',
    '👨🏿‍🫯‍👨🏾' => 'mandlige brydere: mørk teint og medium til mørk teint',
    '👨🏻‍❤‍👨🏻' => 'par med hjerte: mand, mand og lys teint',
    '👨🏻‍❤‍👨🏼' => 'par med hjerte: mand, mand, lys teint og medium til lys teint',
    '👨🏻‍❤‍👨🏽' => 'par med hjerte: mand, mand, lys teint og medium teint',
    '👨🏻‍❤‍👨🏾' => 'par med hjerte: mand, mand, lys teint og medium til mørk teint',
    '👨🏻‍❤‍👨🏿' => 'par med hjerte: mand, mand, lys teint og mørk teint',
    '👨🏼‍❤‍👨🏻' => 'par med hjerte: mand, mand, medium til lys teint og lys teint',
    '👨🏼‍❤‍👨🏼' => 'par med hjerte: mand, mand og medium til lys teint',
    '👨🏼‍❤‍👨🏽' => 'par med hjerte: mand, mand, medium til lys teint og medium teint',
    '👨🏼‍❤‍👨🏾' => 'par med hjerte: mand, mand, medium til lys teint og medium til mørk teint',
    '👨🏼‍❤‍👨🏿' => 'par med hjerte: mand, mand, medium til lys teint og mørk teint',
    '👨🏽‍❤‍👨🏻' => 'par med hjerte: mand, mand, medium teint og lys teint',
    '👨🏽‍❤‍👨🏼' => 'par med hjerte: mand, mand, medium teint og medium til lys teint',
    '👨🏽‍❤‍👨🏽' => 'par med hjerte: mand, mand og medium teint',
    '👨🏽‍❤‍👨🏾' => 'par med hjerte: mand, mand, medium teint og medium til mørk teint',
    '👨🏽‍❤‍👨🏿' => 'par med hjerte: mand, mand, medium teint og mørk teint',
    '👨🏾‍❤‍👨🏻' => 'par med hjerte: mand, mand, medium til mørk teint og lys teint',
    '👨🏾‍❤‍👨🏼' => 'par med hjerte: mand, mand, medium til mørk teint og medium til lys teint',
    '👨🏾‍❤‍👨🏽' => 'par med hjerte: mand, mand, medium til mørk teint og medium teint',
    '👨🏾‍❤‍👨🏾' => 'par med hjerte: mand, mand og medium til mørk teint',
    '👨🏾‍❤‍👨🏿' => 'par med hjerte: mand, mand, medium til mørk teint og mørk teint',
    '👨🏿‍❤‍👨🏻' => 'par med hjerte: mand, mand, mørk teint og lys teint',
    '👨🏿‍❤‍👨🏼' => 'par med hjerte: mand, mand, mørk teint og medium til lys teint',
    '👨🏿‍❤‍👨🏽' => 'par med hjerte: mand, mand, mørk teint og medium teint',
    '👨🏿‍❤‍👨🏾' => 'par med hjerte: mand, mand, mørk teint og medium til mørk teint',
    '👨🏿‍❤‍👨🏿' => 'par med hjerte: mand, mand og mørk teint',
    '👨🏻‍🐰‍👨🏼' => 'mænd med kaninører: lys teint og medium til lys teint',
    '👨🏻‍🐰‍👨🏽' => 'mænd med kaninører: lys teint og medium teint',
    '👨🏻‍🐰‍👨🏾' => 'mænd med kaninører: lys teint og medium til mørk teint',
    '👨🏻‍🐰‍👨🏿' => 'mænd med kaninører: lys teint og mørk teint',
    '👨🏼‍🐰‍👨🏻' => 'mænd med kaninører: medium til lys teint og lys teint',
    '👨🏼‍🐰‍👨🏽' => 'mænd med kaninører: medium til lys teint og medium teint',
    '👨🏼‍🐰‍👨🏾' => 'mænd med kaninører: medium til lys teint og medium til mørk teint',
    '👨🏼‍🐰‍👨🏿' => 'mænd med kaninører: medium til lys teint og mørk teint',
    '👨🏽‍🐰‍👨🏻' => 'mænd med kaninører: medium teint og lys teint',
    '👨🏽‍🐰‍👨🏼' => 'mænd med kaninører: medium teint og medium til lys teint',
    '👨🏽‍🐰‍👨🏾' => 'mænd med kaninører: medium teint og medium til mørk teint',
    '👨🏽‍🐰‍👨🏿' => 'mænd med kaninører: medium teint og mørk teint',
    '👨🏾‍🐰‍👨🏻' => 'mænd med kaninører: medium til mørk teint og lys teint',
    '👨🏾‍🐰‍👨🏼' => 'mænd med kaninører: medium til mørk teint og medium til lys teint',
    '👨🏾‍🐰‍👨🏽' => 'mænd med kaninører: medium til mørk teint og medium teint',
    '👨🏾‍🐰‍👨🏿' => 'mænd med kaninører: medium til mørk teint og mørk teint',
    '👨🏿‍🐰‍👨🏻' => 'mænd med kaninører: mørk teint og lys teint',
    '👨🏿‍🐰‍👨🏼' => 'mænd med kaninører: mørk teint og medium til lys teint',
    '👨🏿‍🐰‍👨🏽' => 'mænd med kaninører: mørk teint og medium teint',
    '👨🏿‍🐰‍👨🏾' => 'mænd med kaninører: mørk teint og medium til mørk teint',
    '👩🏻‍🫯‍👩🏼' => 'kvindelige brydere: lys teint og medium til lys teint',
    '👩🏻‍🫯‍👩🏽' => 'kvindelige brydere: lys teint og medium teint',
    '👩🏻‍🫯‍👩🏾' => 'kvindelige brydere: lys teint og medium til mørk teint',
    '👩🏻‍🫯‍👩🏿' => 'kvindelige brydere: lys teint og mørk teint',
    '👩🏼‍🫯‍👩🏻' => 'kvindelige brydere: medium til lys teint og lys teint',
    '👩🏼‍🫯‍👩🏽' => 'kvindelige brydere: medium til lys teint og medium teint',
    '👩🏼‍🫯‍👩🏾' => 'kvindelige brydere: medium til lys teint og medium til mørk teint',
    '👩🏼‍🫯‍👩🏿' => 'kvindelige brydere: medium til lys teint og mørk teint',
    '👩🏽‍🫯‍👩🏻' => 'kvindelige brydere: medium teint og lys teint',
    '👩🏽‍🫯‍👩🏼' => 'kvindelige brydere: medium teint og medium til lys teint',
    '👩🏽‍🫯‍👩🏾' => 'kvindelige brydere: medium teint og medium til mørk teint',
    '👩🏽‍🫯‍👩🏿' => 'kvindelige brydere: medium teint og mørk teint',
    '👩🏾‍🫯‍👩🏻' => 'kvindelige brydere: medium til mørk teint og lys teint',
    '👩🏾‍🫯‍👩🏼' => 'kvindelige brydere: medium til mørk teint og medium til lys teint',
    '👩🏾‍🫯‍👩🏽' => 'kvindelige brydere: medium til mørk teint og medium teint',
    '👩🏾‍🫯‍👩🏿' => 'kvindelige brydere: medium til mørk teint og mørk teint',
    '👩🏿‍🫯‍👩🏻' => 'kvindelige brydere: mørk teint og lys teint',
    '👩🏿‍🫯‍👩🏼' => 'kvindelige brydere: mørk teint og medium til lys teint',
    '👩🏿‍🫯‍👩🏽' => 'kvindelige brydere: mørk teint og medium teint',
    '👩🏿‍🫯‍👩🏾' => 'kvindelige brydere: mørk teint og medium til mørk teint',
    '👩🏻‍❤‍👨🏻' => 'par med hjerte: kvinde, mand og lys teint',
    '👩🏻‍❤‍👨🏼' => 'par med hjerte: kvinde, mand, lys teint og medium til lys teint',
    '👩🏻‍❤‍👨🏽' => 'par med hjerte: kvinde, mand, lys teint og medium teint',
    '👩🏻‍❤‍👨🏾' => 'par med hjerte: kvinde, mand, lys teint og medium til mørk teint',
    '👩🏻‍❤‍👨🏿' => 'par med hjerte: kvinde, mand, lys teint og mørk teint',
    '👩🏼‍❤‍👨🏻' => 'par med hjerte: kvinde, mand, medium til lys teint og lys teint',
    '👩🏼‍❤‍👨🏼' => 'par med hjerte: kvinde, mand og medium til lys teint',
    '👩🏼‍❤‍👨🏽' => 'par med hjerte: kvinde, mand, medium til lys teint og medium teint',
    '👩🏼‍❤‍👨🏾' => 'par med hjerte: kvinde, mand, medium til lys teint og medium til mørk teint',
    '👩🏼‍❤‍👨🏿' => 'par med hjerte: kvinde, mand, medium til lys teint og mørk teint',
    '👩🏽‍❤‍👨🏻' => 'par med hjerte: kvinde, mand, medium teint og lys teint',
    '👩🏽‍❤‍👨🏼' => 'par med hjerte: kvinde, mand, medium teint og medium til lys teint',
    '👩🏽‍❤‍👨🏽' => 'par med hjerte: kvinde, mand og medium teint',
    '👩🏽‍❤‍👨🏾' => 'par med hjerte: kvinde, mand, medium teint og medium til mørk teint',
    '👩🏽‍❤‍👨🏿' => 'par med hjerte: kvinde, mand, medium teint og mørk teint',
    '👩🏾‍❤‍👨🏻' => 'par med hjerte: kvinde, mand, medium til mørk teint og lys teint',
    '👩🏾‍❤‍👨🏼' => 'par med hjerte: kvinde, mand, medium til mørk teint og medium til lys teint',
    '👩🏾‍❤‍👨🏽' => 'par med hjerte: kvinde, mand, medium til mørk teint og medium teint',
    '👩🏾‍❤‍👨🏾' => 'par med hjerte: kvinde, mand og medium til mørk teint',
    '👩🏾‍❤‍👨🏿' => 'par med hjerte: kvinde, mand, medium til mørk teint og mørk teint',
    '👩🏿‍❤‍👨🏻' => 'par med hjerte: kvinde, mand, mørk teint og lys teint',
    '👩🏿‍❤‍👨🏼' => 'par med hjerte: kvinde, mand, mørk teint og medium til lys teint',
    '👩🏿‍❤‍👨🏽' => 'par med hjerte: kvinde, mand, mørk teint og medium teint',
    '👩🏿‍❤‍👨🏾' => 'par med hjerte: kvinde, mand, mørk teint og medium til mørk teint',
    '👩🏿‍❤‍👨🏿' => 'par med hjerte: kvinde, mand og mørk teint',
    '👩🏻‍❤‍👩🏻' => 'par med hjerte: kvinde, kvinde og lys teint',
    '👩🏻‍❤‍👩🏼' => 'par med hjerte: kvinde, kvinde, lys teint og medium til lys teint',
    '👩🏻‍❤‍👩🏽' => 'par med hjerte: kvinde, kvinde, lys teint og medium teint',
    '👩🏻‍❤‍👩🏾' => 'par med hjerte: kvinde, kvinde, lys teint og medium til mørk teint',
    '👩🏻‍❤‍👩🏿' => 'par med hjerte: kvinde, kvinde, lys teint og mørk teint',
    '👩🏼‍❤‍👩🏻' => 'par med hjerte: kvinde, kvinde, medium til lys teint og lys teint',
    '👩🏼‍❤‍👩🏼' => 'par med hjerte: kvinde, kvinde og medium til lys teint',
    '👩🏼‍❤‍👩🏽' => 'par med hjerte: kvinde, kvinde, medium til lys teint og medium teint',
    '👩🏼‍❤‍👩🏾' => 'par med hjerte: kvinde, kvinde, medium til lys teint og medium til mørk teint',
    '👩🏼‍❤‍👩🏿' => 'par med hjerte: kvinde, kvinde, medium til lys teint og mørk teint',
    '👩🏽‍❤‍👩🏻' => 'par med hjerte: kvinde, kvinde, medium teint og lys teint',
    '👩🏽‍❤‍👩🏼' => 'par med hjerte: kvinde, kvinde, medium teint og medium til lys teint',
    '👩🏽‍❤‍👩🏽' => 'par med hjerte: kvinde, kvinde og medium teint',
    '👩🏽‍❤‍👩🏾' => 'par med hjerte: kvinde, kvinde, medium teint og medium til mørk teint',
    '👩🏽‍❤‍👩🏿' => 'par med hjerte: kvinde, kvinde, medium teint og mørk teint',
    '👩🏾‍❤‍👩🏻' => 'par med hjerte: kvinde, kvinde, medium til mørk teint og lys teint',
    '👩🏾‍❤‍👩🏼' => 'par med hjerte: kvinde, kvinde, medium til mørk teint og medium til lys teint',
    '👩🏾‍❤‍👩🏽' => 'par med hjerte: kvinde, kvinde, medium til mørk teint og medium teint',
    '👩🏾‍❤‍👩🏾' => 'par med hjerte: kvinde, kvinde og medium til mørk teint',
    '👩🏾‍❤‍👩🏿' => 'par med hjerte: kvinde, kvinde, medium til mørk teint og mørk teint',
    '👩🏿‍❤‍👩🏻' => 'par med hjerte: kvinde, kvinde, mørk teint og lys teint',
    '👩🏿‍❤‍👩🏼' => 'par med hjerte: kvinde, kvinde, mørk teint og medium til lys teint',
    '👩🏿‍❤‍👩🏽' => 'par med hjerte: kvinde, kvinde, mørk teint og medium teint',
    '👩🏿‍❤‍👩🏾' => 'par med hjerte: kvinde, kvinde, mørk teint og medium til mørk teint',
    '👩🏿‍❤‍👩🏿' => 'par med hjerte: kvinde, kvinde og mørk teint',
    '👩🏻‍🐰‍👩🏼' => 'kvinder med kaninører: lys teint og medium til lys teint',
    '👩🏻‍🐰‍👩🏽' => 'kvinder med kaninører: lys teint og medium teint',
    '👩🏻‍🐰‍👩🏾' => 'kvinder med kaninører: lys teint og medium til mørk teint',
    '👩🏻‍🐰‍👩🏿' => 'kvinder med kaninører: lys teint og mørk teint',
    '👩🏼‍🐰‍👩🏻' => 'kvinder med kaninører: medium til lys teint og lys teint',
    '👩🏼‍🐰‍👩🏽' => 'kvinder med kaninører: medium til lys teint og medium teint',
    '👩🏼‍🐰‍👩🏾' => 'kvinder med kaninører: medium til lys teint og medium til mørk teint',
    '👩🏼‍🐰‍👩🏿' => 'kvinder med kaninører: medium til lys teint og mørk teint',
    '👩🏽‍🐰‍👩🏻' => 'kvinder med kaninører: medium teint og lys teint',
    '👩🏽‍🐰‍👩🏼' => 'kvinder med kaninører: medium teint og medium til lys teint',
    '👩🏽‍🐰‍👩🏾' => 'kvinder med kaninører: medium teint og medium til mørk teint',
    '👩🏽‍🐰‍👩🏿' => 'kvinder med kaninører: medium teint og mørk teint',
    '👩🏾‍🐰‍👩🏻' => 'kvinder med kaninører: medium til mørk teint og lys teint',
    '👩🏾‍🐰‍👩🏼' => 'kvinder med kaninører: medium til mørk teint og medium til lys teint',
    '👩🏾‍🐰‍👩🏽' => 'kvinder med kaninører: medium til mørk teint og medium teint',
    '👩🏾‍🐰‍👩🏿' => 'kvinder med kaninører: medium til mørk teint og mørk teint',
    '👩🏿‍🐰‍👩🏻' => 'kvinder med kaninører: mørk teint og lys teint',
    '👩🏿‍🐰‍👩🏼' => 'kvinder med kaninører: mørk teint og medium til lys teint',
    '👩🏿‍🐰‍👩🏽' => 'kvinder med kaninører: mørk teint og medium teint',
    '👩🏿‍🐰‍👩🏾' => 'kvinder med kaninører: mørk teint og medium til mørk teint',
    '🧑🏻‍🤝‍🧑🏻' => 'personer hånd i hånd: lys teint',
    '🧑🏻‍🤝‍🧑🏼' => 'personer hånd i hånd: lys teint og medium til lys teint',
    '🧑🏻‍🤝‍🧑🏽' => 'personer hånd i hånd: lys teint og medium teint',
    '🧑🏻‍🤝‍🧑🏾' => 'personer hånd i hånd: lys teint og medium til mørk teint',
    '🧑🏻‍🤝‍🧑🏿' => 'personer hånd i hånd: lys teint og mørk teint',
    '🧑🏼‍🤝‍🧑🏻' => 'personer hånd i hånd: medium til lys teint og lys teint',
    '🧑🏼‍🤝‍🧑🏼' => 'personer hånd i hånd: medium til lys teint',
    '🧑🏼‍🤝‍🧑🏽' => 'personer hånd i hånd: medium til lys teint og medium teint',
    '🧑🏼‍🤝‍🧑🏾' => 'personer hånd i hånd: medium til lys teint og medium til mørk teint',
    '🧑🏼‍🤝‍🧑🏿' => 'personer hånd i hånd: medium til lys teint og mørk teint',
    '🧑🏽‍🤝‍🧑🏻' => 'personer hånd i hånd: medium teint og lys teint',
    '🧑🏽‍🤝‍🧑🏼' => 'personer hånd i hånd: medium teint og medium til lys teint',
    '🧑🏽‍🤝‍🧑🏽' => 'personer hånd i hånd: medium teint',
    '🧑🏽‍🤝‍🧑🏾' => 'personer hånd i hånd: medium teint og medium til mørk teint',
    '🧑🏽‍🤝‍🧑🏿' => 'personer hånd i hånd: medium teint og mørk teint',
    '🧑🏾‍🤝‍🧑🏻' => 'personer hånd i hånd: medium til mørk teint og lys teint',
    '🧑🏾‍🤝‍🧑🏼' => 'personer hånd i hånd: medium til mørk teint og medium til lys teint',
    '🧑🏾‍🤝‍🧑🏽' => 'personer hånd i hånd: medium til mørk teint og medium teint',
    '🧑🏾‍🤝‍🧑🏾' => 'personer hånd i hånd: medium til mørk teint',
    '🧑🏾‍🤝‍🧑🏿' => 'personer hånd i hånd: medium til mørk teint og mørk teint',
    '🧑🏿‍🤝‍🧑🏻' => 'personer hånd i hånd: mørk teint og lys teint',
    '🧑🏿‍🤝‍🧑🏼' => 'personer hånd i hånd: mørk teint og medium til lys teint',
    '🧑🏿‍🤝‍🧑🏽' => 'personer hånd i hånd: mørk teint og medium teint',
    '🧑🏿‍🤝‍🧑🏾' => 'personer hånd i hånd: mørk teint og medium til mørk teint',
    '🧑🏿‍🤝‍🧑🏿' => 'personer hånd i hånd: mørk teint',
    '👩🏻‍🤝‍👩🏼' => 'to kvinder hånd i hånd: lys teint og medium til lys teint',
    '👩🏻‍🤝‍👩🏽' => 'to kvinder hånd i hånd: lys teint og medium teint',
    '👩🏻‍🤝‍👩🏾' => 'to kvinder hånd i hånd: lys teint og medium til mørk teint',
    '👩🏻‍🤝‍👩🏿' => 'to kvinder hånd i hånd: lys teint og mørk teint',
    '👩🏼‍🤝‍👩🏻' => 'to kvinder hånd i hånd: medium til lys teint og lys teint',
    '👩🏼‍🤝‍👩🏽' => 'to kvinder hånd i hånd: medium til lys teint og medium teint',
    '👩🏼‍🤝‍👩🏾' => 'to kvinder hånd i hånd: medium til lys teint og medium til mørk teint',
    '👩🏼‍🤝‍👩🏿' => 'to kvinder hånd i hånd: medium til lys teint og mørk teint',
    '👩🏽‍🤝‍👩🏻' => 'to kvinder hånd i hånd: medium teint og lys teint',
    '👩🏽‍🤝‍👩🏼' => 'to kvinder hånd i hånd: medium teint og medium til lys teint',
    '👩🏽‍🤝‍👩🏾' => 'to kvinder hånd i hånd: medium teint og medium til mørk teint',
    '👩🏽‍🤝‍👩🏿' => 'to kvinder hånd i hånd: medium teint og mørk teint',
    '👩🏾‍🤝‍👩🏻' => 'to kvinder hånd i hånd: medium til mørk teint og lys teint',
    '👩🏾‍🤝‍👩🏼' => 'to kvinder hånd i hånd: medium til mørk teint og medium til lys teint',
    '👩🏾‍🤝‍👩🏽' => 'to kvinder hånd i hånd: medium til mørk teint og medium teint',
    '👩🏾‍🤝‍👩🏿' => 'to kvinder hånd i hånd: medium til mørk teint og mørk teint',
    '👩🏿‍🤝‍👩🏻' => 'to kvinder hånd i hånd: mørk teint og lys teint',
    '👩🏿‍🤝‍👩🏼' => 'to kvinder hånd i hånd: mørk teint og medium til lys teint',
    '👩🏿‍🤝‍👩🏽' => 'to kvinder hånd i hånd: mørk teint og medium teint',
    '👩🏿‍🤝‍👩🏾' => 'to kvinder hånd i hånd: mørk teint og medium til mørk teint',
    '👩🏻‍🤝‍👨🏼' => 'mand og kvinde hånd i hånd: lys teint og medium til lys teint',
    '👩🏻‍🤝‍👨🏽' => 'mand og kvinde hånd i hånd: lys teint og medium teint',
    '👩🏻‍🤝‍👨🏾' => 'mand og kvinde hånd i hånd: lys teint og medium til mørk teint',
    '👩🏻‍🤝‍👨🏿' => 'mand og kvinde hånd i hånd: lys teint og mørk teint',
    '👩🏼‍🤝‍👨🏻' => 'mand og kvinde hånd i hånd: medium til lys teint og lys teint',
    '👩🏼‍🤝‍👨🏽' => 'mand og kvinde hånd i hånd: medium til lys teint og medium teint',
    '👩🏼‍🤝‍👨🏾' => 'mand og kvinde hånd i hånd: medium til lys teint og medium til mørk teint',
    '👩🏼‍🤝‍👨🏿' => 'mand og kvinde hånd i hånd: medium til lys teint og mørk teint',
    '👩🏽‍🤝‍👨🏻' => 'mand og kvinde hånd i hånd: medium teint og lys teint',
    '👩🏽‍🤝‍👨🏼' => 'mand og kvinde hånd i hånd: medium teint og medium til lys teint',
    '👩🏽‍🤝‍👨🏾' => 'mand og kvinde hånd i hånd: medium teint og medium til mørk teint',
    '👩🏽‍🤝‍👨🏿' => 'mand og kvinde hånd i hånd: medium teint og mørk teint',
    '👩🏾‍🤝‍👨🏻' => 'mand og kvinde hånd i hånd: medium til mørk teint og lys teint',
    '👩🏾‍🤝‍👨🏼' => 'mand og kvinde hånd i hånd: medium til mørk teint og medium til lys teint',
    '👩🏾‍🤝‍👨🏽' => 'mand og kvinde hånd i hånd: medium til mørk teint og medium teint',
    '👩🏾‍🤝‍👨🏿' => 'mand og kvinde hånd i hånd: medium til mørk teint og mørk teint',
    '👩🏿‍🤝‍👨🏻' => 'mand og kvinde hånd i hånd: mørk teint og lys teint',
    '👩🏿‍🤝‍👨🏼' => 'mand og kvinde hånd i hånd: mørk teint og medium til lys teint',
    '👩🏿‍🤝‍👨🏽' => 'mand og kvinde hånd i hånd: mørk teint og medium teint',
    '👩🏿‍🤝‍👨🏾' => 'mand og kvinde hånd i hånd: mørk teint og medium til mørk teint',
    '👨🏻‍🤝‍👨🏼' => 'to mænd hånd i hånd: lys teint og medium til lys teint',
    '👨🏻‍🤝‍👨🏽' => 'to mænd hånd i hånd: lys teint og medium teint',
    '👨🏻‍🤝‍👨🏾' => 'to mænd hånd i hånd: lys teint og medium til mørk teint',
    '👨🏻‍🤝‍👨🏿' => 'to mænd hånd i hånd: lys teint og mørk teint',
    '👨🏼‍🤝‍👨🏻' => 'to mænd hånd i hånd: medium til lys teint og lys teint',
    '👨🏼‍🤝‍👨🏽' => 'to mænd hånd i hånd: medium til lys teint og medium teint',
    '👨🏼‍🤝‍👨🏾' => 'to mænd hånd i hånd: medium til lys teint og medium til mørk teint',
    '👨🏼‍🤝‍👨🏿' => 'to mænd hånd i hånd: medium til lys teint og mørk teint',
    '👨🏽‍🤝‍👨🏻' => 'to mænd hånd i hånd: medium teint og lys teint',
    '👨🏽‍🤝‍👨🏼' => 'to mænd hånd i hånd: medium teint og medium til lys teint',
    '👨🏽‍🤝‍👨🏾' => 'to mænd hånd i hånd: medium teint og medium til mørk teint',
    '👨🏽‍🤝‍👨🏿' => 'to mænd hånd i hånd: medium teint og mørk teint',
    '👨🏾‍🤝‍👨🏻' => 'to mænd hånd i hånd: medium til mørk teint og lys teint',
    '👨🏾‍🤝‍👨🏼' => 'to mænd hånd i hånd: medium til mørk teint og medium til lys teint',
    '👨🏾‍🤝‍👨🏽' => 'to mænd hånd i hånd: medium til mørk teint og medium teint',
    '👨🏾‍🤝‍👨🏿' => 'to mænd hånd i hånd: medium til mørk teint og mørk teint',
    '👨🏿‍🤝‍👨🏻' => 'to mænd hånd i hånd: mørk teint og lys teint',
    '👨🏿‍🤝‍👨🏼' => 'to mænd hånd i hånd: mørk teint og medium til lys teint',
    '👨🏿‍🤝‍👨🏽' => 'to mænd hånd i hånd: mørk teint og medium teint',
    '👨🏿‍🤝‍👨🏾' => 'to mænd hånd i hånd: mørk teint og medium til mørk teint',
    '👩‍❤‍💋‍👨' => 'kys: kvinde og mand',
    '👨‍❤‍💋‍👨' => 'kys: mand og mand',
    '👩‍❤‍💋‍👩' => 'kys: kvinde og kvinde',
    '👨‍👩‍👧‍👦' => 'familie: mand, kvinde, pige og dreng',
    '👨‍👩‍👦‍👦' => 'familie: mand, kvinde, dreng og dreng',
    '👨‍👩‍👧‍👧' => 'familie: mand, kvinde, pige og pige',
    '👨‍👨‍👧‍👦' => 'familie: mand, mand, pige og dreng',
    '👨‍👨‍👦‍👦' => 'familie: mand, mand, dreng og dreng',
    '👨‍👨‍👧‍👧' => 'familie: mand, mand, pige og pige',
    '👩‍👩‍👧‍👦' => 'familie: kvinde, kvinde, pige og dreng',
    '👩‍👩‍👦‍👦' => 'familie: kvinde, kvinde, dreng og dreng',
    '👩‍👩‍👧‍👧' => 'familie: kvinde, kvinde, pige og pige',
    '🧑‍🧑‍🧒‍🧒' => 'familie: voksen, voksen, barn, barn',
    '🚶🏻‍♀‍➡' => 'kvinde går: lys teint og mod højre',
    '🚶🏼‍♀‍➡' => 'kvinde går: medium til lys teint og mod højre',
    '🚶🏽‍♀‍➡' => 'kvinde går: medium teint og mod højre',
    '🚶🏾‍♀‍➡' => 'kvinde går: medium til mørk teint og mod højre',
    '🚶🏿‍♀‍➡' => 'kvinde går: mørk teint og mod højre',
    '🚶🏻‍♂‍➡' => 'mand går: lys teint og mod højre',
    '🚶🏼‍♂‍➡' => 'mand går: medium til lys teint og mod højre',
    '🚶🏽‍♂‍➡' => 'mand går: medium teint og mod højre',
    '🚶🏾‍♂‍➡' => 'mand går: medium til mørk teint og mod højre',
    '🚶🏿‍♂‍➡' => 'mand går: mørk teint og mod højre',
    '🧎🏻‍♀‍➡' => 'knælende kvinde: lys teint og mod højre',
    '🧎🏼‍♀‍➡' => 'knælende kvinde: medium til lys teint og mod højre',
    '🧎🏽‍♀‍➡' => 'knælende kvinde: medium teint og mod højre',
    '🧎🏾‍♀‍➡' => 'knælende kvinde: medium til mørk teint og mod højre',
    '🧎🏿‍♀‍➡' => 'knælende kvinde: mørk teint og mod højre',
    '🧎🏻‍♂‍➡' => 'knælende mand: lys teint og mod højre',
    '🧎🏼‍♂‍➡' => 'knælende mand: medium til lys teint og mod højre',
    '🧎🏽‍♂‍➡' => 'knælende mand: medium teint og mod højre',
    '🧎🏾‍♂‍➡' => 'knælende mand: medium til mørk teint og mod højre',
    '🧎🏿‍♂‍➡' => 'knælende mand: mørk teint og mod højre',
    '🧑🏻‍🦯‍➡' => 'person med blindestok: lys teint og mod højre',
    '🧑🏼‍🦯‍➡' => 'person med blindestok: medium til lys teint og mod højre',
    '🧑🏽‍🦯‍➡' => 'person med blindestok: medium teint og mod højre',
    '🧑🏾‍🦯‍➡' => 'person med blindestok: medium til mørk teint og mod højre',
    '🧑🏿‍🦯‍➡' => 'person med blindestok: mørk teint og mod højre',
    '👨🏻‍🦯‍➡' => 'mand med blindestok: lys teint og mod højre',
    '👨🏼‍🦯‍➡' => 'mand med blindestok: medium til lys teint og mod højre',
    '👨🏽‍🦯‍➡' => 'mand med blindestok: medium teint og mod højre',
    '👨🏾‍🦯‍➡' => 'mand med blindestok: medium til mørk teint og mod højre',
    '👨🏿‍🦯‍➡' => 'mand med blindestok: mørk teint og mod højre',
    '👩🏻‍🦯‍➡' => 'kvinde med blindestok: lys teint og mod højre',
    '👩🏼‍🦯‍➡' => 'kvinde med blindestok: medium til lys teint og mod højre',
    '👩🏽‍🦯‍➡' => 'kvinde med blindestok: medium teint og mod højre',
    '👩🏾‍🦯‍➡' => 'kvinde med blindestok: medium til mørk teint og mod højre',
    '👩🏿‍🦯‍➡' => 'kvinde med blindestok: mørk teint og mod højre',
    '🧑🏻‍🦼‍➡' => 'person i elkørestol: lys teint og mod højre',
    '🧑🏼‍🦼‍➡' => 'person i elkørestol: medium til lys teint og mod højre',
    '🧑🏽‍🦼‍➡' => 'person i elkørestol: medium teint og mod højre',
    '🧑🏾‍🦼‍➡' => 'person i elkørestol: medium til mørk teint og mod højre',
    '🧑🏿‍🦼‍➡' => 'person i elkørestol: mørk teint og mod højre',
    '👨🏻‍🦼‍➡' => 'mand i elektrisk kørestol: lys teint og mod højre',
    '👨🏼‍🦼‍➡' => 'mand i elektrisk kørestol: medium til lys teint og mod højre',
    '👨🏽‍🦼‍➡' => 'mand i elektrisk kørestol: medium teint og mod højre',
    '👨🏾‍🦼‍➡' => 'mand i elektrisk kørestol: medium til mørk teint og mod højre',
    '👨🏿‍🦼‍➡' => 'mand i elektrisk kørestol: mørk teint og mod højre',
    '👩🏻‍🦼‍➡' => 'kvinde i elektrisk kørestol: lys teint og mod højre',
    '👩🏼‍🦼‍➡' => 'kvinde i elektrisk kørestol: medium til lys teint og mod højre',
    '👩🏽‍🦼‍➡' => 'kvinde i elektrisk kørestol: medium teint og mod højre',
    '👩🏾‍🦼‍➡' => 'kvinde i elektrisk kørestol: medium til mørk teint og mod højre',
    '👩🏿‍🦼‍➡' => 'kvinde i elektrisk kørestol: mørk teint og mod højre',
    '🧑🏻‍🦽‍➡' => 'person i manuel kørestol: lys teint og mod højre',
    '🧑🏼‍🦽‍➡' => 'person i manuel kørestol: medium til lys teint og mod højre',
    '🧑🏽‍🦽‍➡' => 'person i manuel kørestol: medium teint og mod højre',
    '🧑🏾‍🦽‍➡' => 'person i manuel kørestol: medium til mørk teint og mod højre',
    '🧑🏿‍🦽‍➡' => 'person i manuel kørestol: mørk teint og mod højre',
    '👨🏻‍🦽‍➡' => 'mand i manuel kørestol: lys teint og mod højre',
    '👨🏼‍🦽‍➡' => 'mand i manuel kørestol: medium til lys teint og mod højre',
    '👨🏽‍🦽‍➡' => 'mand i manuel kørestol: medium teint og mod højre',
    '👨🏾‍🦽‍➡' => 'mand i manuel kørestol: medium til mørk teint og mod højre',
    '👨🏿‍🦽‍➡' => 'mand i manuel kørestol: mørk teint og mod højre',
    '👩🏻‍🦽‍➡' => 'kvinde i manuel kørestol: lys teint og mod højre',
    '👩🏼‍🦽‍➡' => 'kvinde i manuel kørestol: medium til lys teint og mod højre',
    '👩🏽‍🦽‍➡' => 'kvinde i manuel kørestol: medium teint og mod højre',
    '👩🏾‍🦽‍➡' => 'kvinde i manuel kørestol: medium til mørk teint og mod højre',
    '👩🏿‍🦽‍➡' => 'kvinde i manuel kørestol: mørk teint og mod højre',
    '🏃🏻‍♀‍➡' => 'kvinde løber: lys teint og mod højre',
    '🏃🏼‍♀‍➡' => 'kvinde løber: medium til lys teint og mod højre',
    '🏃🏽‍♀‍➡' => 'kvinde løber: medium teint og mod højre',
    '🏃🏾‍♀‍➡' => 'kvinde løber: medium til mørk teint og mod højre',
    '🏃🏿‍♀‍➡' => 'kvinde løber: mørk teint og mod højre',
    '🏃🏻‍♂‍➡' => 'mand løber: lys teint og mod højre',
    '🏃🏼‍♂‍➡' => 'mand løber: medium til lys teint og mod højre',
    '🏃🏽‍♂‍➡' => 'mand løber: medium teint og mod højre',
    '🏃🏾‍♂‍➡' => 'mand løber: medium til mørk teint og mod højre',
    '🏃🏿‍♂‍➡' => 'mand løber: mørk teint og mod højre',
    '🫱🏻‍🫲🏼' => 'håndtryk: lys teint og medium til lys teint',
    '🫱🏻‍🫲🏽' => 'håndtryk: lys teint og medium teint',
    '🫱🏻‍🫲🏾' => 'håndtryk: lys teint og medium til mørk teint',
    '🫱🏻‍🫲🏿' => 'håndtryk: lys teint og mørk teint',
    '🫱🏼‍🫲🏻' => 'håndtryk: medium til lys teint og lys teint',
    '🫱🏼‍🫲🏽' => 'håndtryk: medium til lys teint og medium teint',
    '🫱🏼‍🫲🏾' => 'håndtryk: medium til lys teint og medium til mørk teint',
    '🫱🏼‍🫲🏿' => 'håndtryk: medium til lys teint og mørk teint',
    '🫱🏽‍🫲🏻' => 'håndtryk: medium teint og lys teint',
    '🫱🏽‍🫲🏼' => 'håndtryk: medium teint og medium til lys teint',
    '🫱🏽‍🫲🏾' => 'håndtryk: medium teint og medium til mørk teint',
    '🫱🏽‍🫲🏿' => 'håndtryk: medium teint og mørk teint',
    '🫱🏾‍🫲🏻' => 'håndtryk: medium til mørk teint og lys teint',
    '🫱🏾‍🫲🏼' => 'håndtryk: medium til mørk teint og medium til lys teint',
    '🫱🏾‍🫲🏽' => 'håndtryk: medium til mørk teint og medium teint',
    '🫱🏾‍🫲🏿' => 'håndtryk: medium til mørk teint og mørk teint',
    '🫱🏿‍🫲🏻' => 'håndtryk: mørk teint og lys teint',
    '🫱🏿‍🫲🏼' => 'håndtryk: mørk teint og medium til lys teint',
    '🫱🏿‍🫲🏽' => 'håndtryk: mørk teint og medium teint',
    '🫱🏿‍🫲🏾' => 'håndtryk: mørk teint og medium til mørk teint',
    '🚶‍♀‍➡' => 'kvinde går: mod højre',
    '🚶‍♂‍➡' => 'mand går: mod højre',
    '🧎‍♀‍➡' => 'knælende kvinde: mod højre',
    '🧎‍♂‍➡' => 'knælende mand: mod højre',
    '🧑‍🦯‍➡' => 'person med blindestok: mod højre',
    '👨‍🦯‍➡' => 'mand med blindestok: mod højre',
    '👩‍🦯‍➡' => 'kvinde med blindestok: mod højre',
    '🧑‍🦼‍➡' => 'person i elkørestol: mod højre',
    '👨‍🦼‍➡' => 'mand i elektrisk kørestol: mod højre',
    '👩‍🦼‍➡' => 'kvinde i elektrisk kørestol: mod højre',
    '🧑‍🦽‍➡' => 'person i manuel kørestol: mod højre',
    '👨‍🦽‍➡' => 'mand i manuel kørestol: mod højre',
    '👩‍🦽‍➡' => 'kvinde i manuel kørestol: mod højre',
    '🏃‍♀‍➡' => 'kvinde løber: mod højre',
    '🏃‍♂‍➡' => 'mand løber: mod højre',
    '👩‍❤‍👨' => 'par med hjerte: kvinde og mand',
    '👨‍❤‍👨' => 'par med hjerte: mand og mand',
    '👩‍❤‍👩' => 'par med hjerte: kvinde og kvinde',
    '👨‍👩‍👦' => 'familie: mand, kvinde og dreng',
    '👨‍👩‍👧' => 'familie: mand, kvinde og pige',
    '👨‍👨‍👦' => 'familie: mand, mand og dreng',
    '👨‍👨‍👧' => 'familie: mand, mand og pige',
    '👩‍👩‍👦' => 'familie: kvinde, kvinde og dreng',
    '👩‍👩‍👧' => 'familie: kvinde, kvinde og pige',
    '👨‍👦‍👦' => 'familie: mand, dreng og dreng',
    '👨‍👧‍👦' => 'familie: mand, pige og dreng',
    '👨‍👧‍👧' => 'familie: mand, pige og pige',
    '👩‍👦‍👦' => 'familie: kvinde, dreng og dreng',
    '👩‍👧‍👦' => 'familie: kvinde, pige og dreng',
    '👩‍👧‍👧' => 'familie: kvinde, pige og pige',
    '🧑‍🤝‍🧑' => 'personer hånd i hånd',
    '🧑‍🧑‍🧒' => 'familie: voksen, voksen, barn',
    '🧑‍🧒‍🧒' => 'familie: voksen, barn, barn',
    '🧑🏻‍🦰' => 'voksen: lys teint og rødt hår',
    '🧑🏼‍🦰' => 'voksen: medium til lys teint og rødt hår',
    '🧑🏽‍🦰' => 'voksen: medium teint og rødt hår',
    '🧑🏾‍🦰' => 'voksen: medium til mørk teint og rødt hår',
    '🧑🏿‍🦰' => 'voksen: mørk teint og rødt hår',
    '🧑🏻‍🦱' => 'voksen: lys teint og krøllet hår',
    '🧑🏼‍🦱' => 'voksen: medium til lys teint og krøllet hår',
    '🧑🏽‍🦱' => 'voksen: medium teint og krøllet hår',
    '🧑🏾‍🦱' => 'voksen: medium til mørk teint og krøllet hår',
    '🧑🏿‍🦱' => 'voksen: mørk teint og krøllet hår',
    '🧑🏻‍🦳' => 'voksen: lys teint og hvidt hår',
    '🧑🏼‍🦳' => 'voksen: medium til lys teint og hvidt hår',
    '🧑🏽‍🦳' => 'voksen: medium teint og hvidt hår',
    '🧑🏾‍🦳' => 'voksen: medium til mørk teint og hvidt hår',
    '🧑🏿‍🦳' => 'voksen: mørk teint og hvidt hår',
    '🧑🏻‍🦲' => 'voksen: lys teint og skaldet',
    '🧑🏼‍🦲' => 'voksen: medium til lys teint og skaldet',
    '🧑🏽‍🦲' => 'voksen: medium teint og skaldet',
    '🧑🏾‍🦲' => 'voksen: medium til mørk teint og skaldet',
    '🧑🏿‍🦲' => 'voksen: mørk teint og skaldet',
    '🧑🏻‍🩰' => 'balletdanser: lys teint',
    '🧑🏼‍🩰' => 'balletdanser: medium til lys teint',
    '🧑🏽‍🩰' => 'balletdanser: medium teint',
    '🧑🏾‍🩰' => 'balletdanser: medium til mørk teint',
    '🧑🏿‍🩰' => 'balletdanser: mørk teint',
    '🧔🏻‍♂' => 'mand med skæg: lys teint',
    '🧔🏼‍♂' => 'mand med skæg: medium til lys teint',
    '🧔🏽‍♂' => 'mand med skæg: medium teint',
    '🧔🏾‍♂' => 'mand med skæg: medium til mørk teint',
    '🧔🏿‍♂' => 'mand med skæg: mørk teint',
    '👱🏻‍♂' => 'blond mand: lys teint',
    '👱🏼‍♂' => 'blond mand: medium til lys teint',
    '👱🏽‍♂' => 'blond mand: medium teint',
    '👱🏾‍♂' => 'blond mand: medium til mørk teint',
    '👱🏿‍♂' => 'blond mand: mørk teint',
    '👨🏻‍🦰' => 'mand: lys teint og rødt hår',
    '👨🏼‍🦰' => 'mand: medium til lys teint og rødt hår',
    '👨🏽‍🦰' => 'mand: medium teint og rødt hår',
    '👨🏾‍🦰' => 'mand: medium til mørk teint og rødt hår',
    '👨🏿‍🦰' => 'mand: mørk teint og rødt hår',
    '👨🏻‍🦱' => 'mand: lys teint og krøllet hår',
    '👨🏼‍🦱' => 'mand: medium til lys teint og krøllet hår',
    '👨🏽‍🦱' => 'mand: medium teint og krøllet hår',
    '👨🏾‍🦱' => 'mand: medium til mørk teint og krøllet hår',
    '👨🏿‍🦱' => 'mand: mørk teint og krøllet hår',
    '👨🏻‍🦳' => 'mand: lys teint og hvidt hår',
    '👨🏼‍🦳' => 'mand: medium til lys teint og hvidt hår',
    '👨🏽‍🦳' => 'mand: medium teint og hvidt hår',
    '👨🏾‍🦳' => 'mand: medium til mørk teint og hvidt hår',
    '👨🏿‍🦳' => 'mand: mørk teint og hvidt hår',
    '👨🏻‍🦲' => 'mand: lys teint og skaldet',
    '👨🏼‍🦲' => 'mand: medium til lys teint og skaldet',
    '👨🏽‍🦲' => 'mand: medium teint og skaldet',
    '👨🏾‍🦲' => 'mand: medium til mørk teint og skaldet',
    '👨🏿‍🦲' => 'mand: mørk teint og skaldet',
    '🧔🏻‍♀' => 'kvinde med skæg: lys teint',
    '🧔🏼‍♀' => 'kvinde med skæg: medium til lys teint',
    '🧔🏽‍♀' => 'kvinde med skæg: medium teint',
    '🧔🏾‍♀' => 'kvinde med skæg: medium til mørk teint',
    '🧔🏿‍♀' => 'kvinde med skæg: mørk teint',
    '👱🏻‍♀' => 'blond kvinde: lys teint',
    '👱🏼‍♀' => 'blond kvinde: medium til lys teint',
    '👱🏽‍♀' => 'blond kvinde: medium teint',
    '👱🏾‍♀' => 'blond kvinde: medium til mørk teint',
    '👱🏿‍♀' => 'blond kvinde: mørk teint',
    '👩🏻‍🦰' => 'kvinde: lys teint og rødt hår',
    '👩🏼‍🦰' => 'kvinde: medium til lys teint og rødt hår',
    '👩🏽‍🦰' => 'kvinde: medium teint og rødt hår',
    '👩🏾‍🦰' => 'kvinde: medium til mørk teint og rødt hår',
    '👩🏿‍🦰' => 'kvinde: mørk teint og rødt hår',
    '👩🏻‍🦱' => 'kvinde: lys teint og krøllet hår',
    '👩🏼‍🦱' => 'kvinde: medium til lys teint og krøllet hår',
    '👩🏽‍🦱' => 'kvinde: medium teint og krøllet hår',
    '👩🏾‍🦱' => 'kvinde: medium til mørk teint og krøllet hår',
    '👩🏿‍🦱' => 'kvinde: mørk teint og krøllet hår',
    '👩🏻‍🦳' => 'kvinde: lys teint og hvidt hår',
    '👩🏼‍🦳' => 'kvinde: medium til lys teint og hvidt hår',
    '👩🏽‍🦳' => 'kvinde: medium teint og hvidt hår',
    '👩🏾‍🦳' => 'kvinde: medium til mørk teint og hvidt hår',
    '👩🏿‍🦳' => 'kvinde: mørk teint og hvidt hår',
    '👩🏻‍🦲' => 'kvinde: lys teint og skaldet',
    '👩🏼‍🦲' => 'kvinde: medium til lys teint og skaldet',
    '👩🏽‍🦲' => 'kvinde: medium teint og skaldet',
    '👩🏾‍🦲' => 'kvinde: medium til mørk teint og skaldet',
    '👩🏿‍🦲' => 'kvinde: mørk teint og skaldet',
    '🙍🏻‍♂' => 'Utilfreds mand: lys teint',
    '🙍🏼‍♂' => 'Utilfreds mand: medium til lys teint',
    '🙍🏽‍♂' => 'Utilfreds mand: medium teint',
    '🙍🏾‍♂' => 'Utilfreds mand: medium til mørk teint',
    '🙍🏿‍♂' => 'Utilfreds mand: mørk teint',
    '🙍🏻‍♀' => 'Utilfreds kvinde: lys teint',
    '🙍🏼‍♀' => 'Utilfreds kvinde: medium til lys teint',
    '🙍🏽‍♀' => 'Utilfreds kvinde: medium teint',
    '🙍🏾‍♀' => 'Utilfreds kvinde: medium til mørk teint',
    '🙍🏿‍♀' => 'Utilfreds kvinde: mørk teint',
    '🙎🏻‍♂' => 'surmulende mand: lys teint',
    '🙎🏼‍♂' => 'surmulende mand: medium til lys teint',
    '🙎🏽‍♂' => 'surmulende mand: medium teint',
    '🙎🏾‍♂' => 'surmulende mand: medium til mørk teint',
    '🙎🏿‍♂' => 'surmulende mand: mørk teint',
    '🙎🏻‍♀' => 'surmulende kvinde: lys teint',
    '🙎🏼‍♀' => 'surmulende kvinde: medium til lys teint',
    '🙎🏽‍♀' => 'surmulende kvinde: medium teint',
    '🙎🏾‍♀' => 'surmulende kvinde: medium til mørk teint',
    '🙎🏿‍♀' => 'surmulende kvinde: mørk teint',
    '🙅🏻‍♂' => 'mand signalerer nej: lys teint',
    '🙅🏼‍♂' => 'mand signalerer nej: medium til lys teint',
    '🙅🏽‍♂' => 'mand signalerer nej: medium teint',
    '🙅🏾‍♂' => 'mand signalerer nej: medium til mørk teint',
    '🙅🏿‍♂' => 'mand signalerer nej: mørk teint',
    '🙅🏻‍♀' => 'kvinde signalerer nej: lys teint',
    '🙅🏼‍♀' => 'kvinde signalerer nej: medium til lys teint',
    '🙅🏽‍♀' => 'kvinde signalerer nej: medium teint',
    '🙅🏾‍♀' => 'kvinde signalerer nej: medium til mørk teint',
    '🙅🏿‍♀' => 'kvinde signalerer nej: mørk teint',
    '🙆🏻‍♂' => 'mand signalerer ok: lys teint',
    '🙆🏼‍♂' => 'mand signalerer ok: medium til lys teint',
    '🙆🏽‍♂' => 'mand signalerer ok: medium teint',
    '🙆🏾‍♂' => 'mand signalerer ok: medium til mørk teint',
    '🙆🏿‍♂' => 'mand signalerer ok: mørk teint',
    '🙆🏻‍♀' => 'kvinde signalerer ok: lys teint',
    '🙆🏼‍♀' => 'kvinde signalerer ok: medium til lys teint',
    '🙆🏽‍♀' => 'kvinde signalerer ok: medium teint',
    '🙆🏾‍♀' => 'kvinde signalerer ok: medium til mørk teint',
    '🙆🏿‍♀' => 'kvinde signalerer ok: mørk teint',
    '💁🏻‍♂' => 'mand vender håndfladen op: lys teint',
    '💁🏼‍♂' => 'mand vender håndfladen op: medium til lys teint',
    '💁🏽‍♂' => 'mand vender håndfladen op: medium teint',
    '💁🏾‍♂' => 'mand vender håndfladen op: medium til mørk teint',
    '💁🏿‍♂' => 'mand vender håndfladen op: mørk teint',
    '💁🏻‍♀' => 'kvinde vender håndfladen op: lys teint',
    '💁🏼‍♀' => 'kvinde vender håndfladen op: medium til lys teint',
    '💁🏽‍♀' => 'kvinde vender håndfladen op: medium teint',
    '💁🏾‍♀' => 'kvinde vender håndfladen op: medium til mørk teint',
    '💁🏿‍♀' => 'kvinde vender håndfladen op: mørk teint',
    '🙋🏻‍♂' => 'mand med løftet hånd: lys teint',
    '🙋🏼‍♂' => 'mand med løftet hånd: medium til lys teint',
    '🙋🏽‍♂' => 'mand med løftet hånd: medium teint',
    '🙋🏾‍♂' => 'mand med løftet hånd: medium til mørk teint',
    '🙋🏿‍♂' => 'mand med løftet hånd: mørk teint',
    '🙋🏻‍♀' => 'kvinde med løftet hånd: lys teint',
    '🙋🏼‍♀' => 'kvinde med løftet hånd: medium til lys teint',
    '🙋🏽‍♀' => 'kvinde med løftet hånd: medium teint',
    '🙋🏾‍♀' => 'kvinde med løftet hånd: medium til mørk teint',
    '🙋🏿‍♀' => 'kvinde med løftet hånd: mørk teint',
    '🧏🏻‍♂' => 'døv mand: lys teint',
    '🧏🏼‍♂' => 'døv mand: medium til lys teint',
    '🧏🏽‍♂' => 'døv mand: medium teint',
    '🧏🏾‍♂' => 'døv mand: medium til mørk teint',
    '🧏🏿‍♂' => 'døv mand: mørk teint',
    '🧏🏻‍♀' => 'døv kvinde: lys teint',
    '🧏🏼‍♀' => 'døv kvinde: medium til lys teint',
    '🧏🏽‍♀' => 'døv kvinde: medium teint',
    '🧏🏾‍♀' => 'døv kvinde: medium til mørk teint',
    '🧏🏿‍♀' => 'døv kvinde: mørk teint',
    '🙇🏻‍♂' => 'mand bukker dybt: lys teint',
    '🙇🏼‍♂' => 'mand bukker dybt: medium til lys teint',
    '🙇🏽‍♂' => 'mand bukker dybt: medium teint',
    '🙇🏾‍♂' => 'mand bukker dybt: medium til mørk teint',
    '🙇🏿‍♂' => 'mand bukker dybt: mørk teint',
    '🙇🏻‍♀' => 'kvinde bukker dybt: lys teint',
    '🙇🏼‍♀' => 'kvinde bukker dybt: medium til lys teint',
    '🙇🏽‍♀' => 'kvinde bukker dybt: medium teint',
    '🙇🏾‍♀' => 'kvinde bukker dybt: medium til mørk teint',
    '🙇🏿‍♀' => 'kvinde bukker dybt: mørk teint',
    '🤦🏻‍♂' => 'mand slår sig for panden: lys teint',
    '🤦🏼‍♂' => 'mand slår sig for panden: medium til lys teint',
    '🤦🏽‍♂' => 'mand slår sig for panden: medium teint',
    '🤦🏾‍♂' => 'mand slår sig for panden: medium til mørk teint',
    '🤦🏿‍♂' => 'mand slår sig for panden: mørk teint',
    '🤦🏻‍♀' => 'kvinde slår sig for panden: lys teint',
    '🤦🏼‍♀' => 'kvinde slår sig for panden: medium til lys teint',
    '🤦🏽‍♀' => 'kvinde slår sig for panden: medium teint',
    '🤦🏾‍♀' => 'kvinde slår sig for panden: medium til mørk teint',
    '🤦🏿‍♀' => 'kvinde slår sig for panden: mørk teint',
    '🤷🏻‍♂' => 'mand trækker på skuldrene: lys teint',
    '🤷🏼‍♂' => 'mand trækker på skuldrene: medium til lys teint',
    '🤷🏽‍♂' => 'mand trækker på skuldrene: medium teint',
    '🤷🏾‍♂' => 'mand trækker på skuldrene: medium til mørk teint',
    '🤷🏿‍♂' => 'mand trækker på skuldrene: mørk teint',
    '🤷🏻‍♀' => 'kvinde trækker på skuldrene: lys teint',
    '🤷🏼‍♀' => 'kvinde trækker på skuldrene: medium til lys teint',
    '🤷🏽‍♀' => 'kvinde trækker på skuldrene: medium teint',
    '🤷🏾‍♀' => 'kvinde trækker på skuldrene: medium til mørk teint',
    '🤷🏿‍♀' => 'kvinde trækker på skuldrene: mørk teint',
    '🧑🏻‍⚕' => 'sundhedspersonale: lys teint',
    '🧑🏼‍⚕' => 'sundhedspersonale: medium til lys teint',
    '🧑🏽‍⚕' => 'sundhedspersonale: medium teint',
    '🧑🏾‍⚕' => 'sundhedspersonale: medium til mørk teint',
    '🧑🏿‍⚕' => 'sundhedspersonale: mørk teint',
    '👨🏻‍⚕' => 'mandlig sundhedsperson: lys teint',
    '👨🏼‍⚕' => 'mandlig sundhedsperson: medium til lys teint',
    '👨🏽‍⚕' => 'mandlig sundhedsperson: medium teint',
    '👨🏾‍⚕' => 'mandlig sundhedsperson: medium til mørk teint',
    '👨🏿‍⚕' => 'mandlig sundhedsperson: mørk teint',
    '👩🏻‍⚕' => 'kvindelig sundhedsperson: lys teint',
    '👩🏼‍⚕' => 'kvindelig sundhedsperson: medium til lys teint',
    '👩🏽‍⚕' => 'kvindelig sundhedsperson: medium teint',
    '👩🏾‍⚕' => 'kvindelig sundhedsperson: medium til mørk teint',
    '👩🏿‍⚕' => 'kvindelig sundhedsperson: mørk teint',
    '🧑🏻‍🎓' => 'studerende: lys teint',
    '🧑🏼‍🎓' => 'studerende: medium til lys teint',
    '🧑🏽‍🎓' => 'studerende: medium teint',
    '🧑🏾‍🎓' => 'studerende: medium til mørk teint',
    '🧑🏿‍🎓' => 'studerende: mørk teint',
    '👨🏻‍🎓' => 'mandlig studerende: lys teint',
    '👨🏼‍🎓' => 'mandlig studerende: medium til lys teint',
    '👨🏽‍🎓' => 'mandlig studerende: medium teint',
    '👨🏾‍🎓' => 'mandlig studerende: medium til mørk teint',
    '👨🏿‍🎓' => 'mandlig studerende: mørk teint',
    '👩🏻‍🎓' => 'kvindelig studerende: lys teint',
    '👩🏼‍🎓' => 'kvindelig studerende: medium til lys teint',
    '👩🏽‍🎓' => 'kvindelig studerende: medium teint',
    '👩🏾‍🎓' => 'kvindelig studerende: medium til mørk teint',
    '👩🏿‍🎓' => 'kvindelig studerende: mørk teint',
    '🧑🏻‍🏫' => 'lærer: lys teint',
    '🧑🏼‍🏫' => 'lærer: medium til lys teint',
    '🧑🏽‍🏫' => 'lærer: medium teint',
    '🧑🏾‍🏫' => 'lærer: medium til mørk teint',
    '🧑🏿‍🏫' => 'lærer: mørk teint',
    '👨🏻‍🏫' => 'mandlig lærer: lys teint',
    '👨🏼‍🏫' => 'mandlig lærer: medium til lys teint',
    '👨🏽‍🏫' => 'mandlig lærer: medium teint',
    '👨🏾‍🏫' => 'mandlig lærer: medium til mørk teint',
    '👨🏿‍🏫' => 'mandlig lærer: mørk teint',
    '👩🏻‍🏫' => 'kvindelig lærer: lys teint',
    '👩🏼‍🏫' => 'kvindelig lærer: medium til lys teint',
    '👩🏽‍🏫' => 'kvindelig lærer: medium teint',
    '👩🏾‍🏫' => 'kvindelig lærer: medium til mørk teint',
    '👩🏿‍🏫' => 'kvindelig lærer: mørk teint',
    '🧑🏻‍⚖' => 'dommer: lys teint',
    '🧑🏼‍⚖' => 'dommer: medium til lys teint',
    '🧑🏽‍⚖' => 'dommer: medium teint',
    '🧑🏾‍⚖' => 'dommer: medium til mørk teint',
    '🧑🏿‍⚖' => 'dommer: mørk teint',
    '👨🏻‍⚖' => 'mandlig dommer: lys teint',
    '👨🏼‍⚖' => 'mandlig dommer: medium til lys teint',
    '👨🏽‍⚖' => 'mandlig dommer: medium teint',
    '👨🏾‍⚖' => 'mandlig dommer: medium til mørk teint',
    '👨🏿‍⚖' => 'mandlig dommer: mørk teint',
    '👩🏻‍⚖' => 'kvindelig dommer: lys teint',
    '👩🏼‍⚖' => 'kvindelig dommer: medium til lys teint',
    '👩🏽‍⚖' => 'kvindelig dommer: medium teint',
    '👩🏾‍⚖' => 'kvindelig dommer: medium til mørk teint',
    '👩🏿‍⚖' => 'kvindelig dommer: mørk teint',
    '🧑🏻‍🌾' => 'bonde: lys teint',
    '🧑🏼‍🌾' => 'bonde: medium til lys teint',
    '🧑🏽‍🌾' => 'bonde: medium teint',
    '🧑🏾‍🌾' => 'bonde: medium til mørk teint',
    '🧑🏿‍🌾' => 'bonde: mørk teint',
    '👨🏻‍🌾' => 'landmand: lys teint',
    '👨🏼‍🌾' => 'landmand: medium til lys teint',
    '👨🏽‍🌾' => 'landmand: medium teint',
    '👨🏾‍🌾' => 'landmand: medium til mørk teint',
    '👨🏿‍🌾' => 'landmand: mørk teint',
    '👩🏻‍🌾' => 'kvindelig landmand: lys teint',
    '👩🏼‍🌾' => 'kvindelig landmand: medium til lys teint',
    '👩🏽‍🌾' => 'kvindelig landmand: medium teint',
    '👩🏾‍🌾' => 'kvindelig landmand: medium til mørk teint',
    '👩🏿‍🌾' => 'kvindelig landmand: mørk teint',
    '🧑🏻‍🍳' => 'kok: lys teint',
    '🧑🏼‍🍳' => 'kok: medium til lys teint',
    '🧑🏽‍🍳' => 'kok: medium teint',
    '🧑🏾‍🍳' => 'kok: medium til mørk teint',
    '🧑🏿‍🍳' => 'kok: mørk teint',
    '👨🏻‍🍳' => 'mandlig kok: lys teint',
    '👨🏼‍🍳' => 'mandlig kok: medium til lys teint',
    '👨🏽‍🍳' => 'mandlig kok: medium teint',
    '👨🏾‍🍳' => 'mandlig kok: medium til mørk teint',
    '👨🏿‍🍳' => 'mandlig kok: mørk teint',
    '👩🏻‍🍳' => 'kvindelig kok: lys teint',
    '👩🏼‍🍳' => 'kvindelig kok: medium til lys teint',
    '👩🏽‍🍳' => 'kvindelig kok: medium teint',
    '👩🏾‍🍳' => 'kvindelig kok: medium til mørk teint',
    '👩🏿‍🍳' => 'kvindelig kok: mørk teint',
    '🧑🏻‍🔧' => 'mekaniker: lys teint',
    '🧑🏼‍🔧' => 'mekaniker: medium til lys teint',
    '🧑🏽‍🔧' => 'mekaniker: medium teint',
    '🧑🏾‍🔧' => 'mekaniker: medium til mørk teint',
    '🧑🏿‍🔧' => 'mekaniker: mørk teint',
    '👨🏻‍🔧' => 'mandlig mekaniker: lys teint',
    '👨🏼‍🔧' => 'mandlig mekaniker: medium til lys teint',
    '👨🏽‍🔧' => 'mandlig mekaniker: medium teint',
    '👨🏾‍🔧' => 'mandlig mekaniker: medium til mørk teint',
    '👨🏿‍🔧' => 'mandlig mekaniker: mørk teint',
    '👩🏻‍🔧' => 'kvindelig mekaniker: lys teint',
    '👩🏼‍🔧' => 'kvindelig mekaniker: medium til lys teint',
    '👩🏽‍🔧' => 'kvindelig mekaniker: medium teint',
    '👩🏾‍🔧' => 'kvindelig mekaniker: medium til mørk teint',
    '👩🏿‍🔧' => 'kvindelig mekaniker: mørk teint',
    '🧑🏻‍🏭' => 'fabriksarbejder: lys teint',
    '🧑🏼‍🏭' => 'fabriksarbejder: medium til lys teint',
    '🧑🏽‍🏭' => 'fabriksarbejder: medium teint',
    '🧑🏾‍🏭' => 'fabriksarbejder: medium til mørk teint',
    '🧑🏿‍🏭' => 'fabriksarbejder: mørk teint',
    '👨🏻‍🏭' => 'mandlig fabriksarbejder: lys teint',
    '👨🏼‍🏭' => 'mandlig fabriksarbejder: medium til lys teint',
    '👨🏽‍🏭' => 'mandlig fabriksarbejder: medium teint',
    '👨🏾‍🏭' => 'mandlig fabriksarbejder: medium til mørk teint',
    '👨🏿‍🏭' => 'mandlig fabriksarbejder: mørk teint',
    '👩🏻‍🏭' => 'kvindelig fabriksarbejder: lys teint',
    '👩🏼‍🏭' => 'kvindelig fabriksarbejder: medium til lys teint',
    '👩🏽‍🏭' => 'kvindelig fabriksarbejder: medium teint',
    '👩🏾‍🏭' => 'kvindelig fabriksarbejder: medium til mørk teint',
    '👩🏿‍🏭' => 'kvindelig fabriksarbejder: mørk teint',
    '🧑🏻‍💼' => 'kontoransat: lys teint',
    '🧑🏼‍💼' => 'kontoransat: medium til lys teint',
    '🧑🏽‍💼' => 'kontoransat: medium teint',
    '🧑🏾‍💼' => 'kontoransat: medium til mørk teint',
    '🧑🏿‍💼' => 'kontoransat: mørk teint',
    '👨🏻‍💼' => 'mandlig kontoransat: lys teint',
    '👨🏼‍💼' => 'mandlig kontoransat: medium til lys teint',
    '👨🏽‍💼' => 'mandlig kontoransat: medium teint',
    '👨🏾‍💼' => 'mandlig kontoransat: medium til mørk teint',
    '👨🏿‍💼' => 'mandlig kontoransat: mørk teint',
    '👩🏻‍💼' => 'kvindelig kontoransat: lys teint',
    '👩🏼‍💼' => 'kvindelig kontoransat: medium til lys teint',
    '👩🏽‍💼' => 'kvindelig kontoransat: medium teint',
    '👩🏾‍💼' => 'kvindelig kontoransat: medium til mørk teint',
    '👩🏿‍💼' => 'kvindelig kontoransat: mørk teint',
    '🧑🏻‍🔬' => 'forsker: lys teint',
    '🧑🏼‍🔬' => 'forsker: medium til lys teint',
    '🧑🏽‍🔬' => 'forsker: medium teint',
    '🧑🏾‍🔬' => 'forsker: medium til mørk teint',
    '🧑🏿‍🔬' => 'forsker: mørk teint',
    '👨🏻‍🔬' => 'mandlig forsker: lys teint',
    '👨🏼‍🔬' => 'mandlig forsker: medium til lys teint',
    '👨🏽‍🔬' => 'mandlig forsker: medium teint',
    '👨🏾‍🔬' => 'mandlig forsker: medium til mørk teint',
    '👨🏿‍🔬' => 'mandlig forsker: mørk teint',
    '👩🏻‍🔬' => 'kvindelig forsker: lys teint',
    '👩🏼‍🔬' => 'kvindelig forsker: medium til lys teint',
    '👩🏽‍🔬' => 'kvindelig forsker: medium teint',
    '👩🏾‍🔬' => 'kvindelig forsker: medium til mørk teint',
    '👩🏿‍🔬' => 'kvindelig forsker: mørk teint',
    '🧑🏻‍💻' => 'it-medarbejder: lys teint',
    '🧑🏼‍💻' => 'it-medarbejder: medium til lys teint',
    '🧑🏽‍💻' => 'it-medarbejder: medium teint',
    '🧑🏾‍💻' => 'it-medarbejder: medium til mørk teint',
    '🧑🏿‍💻' => 'it-medarbejder: mørk teint',
    '👨🏻‍💻' => 'mandlig IT-medarbejder: lys teint',
    '👨🏼‍💻' => 'mandlig IT-medarbejder: medium til lys teint',
    '👨🏽‍💻' => 'mandlig IT-medarbejder: medium teint',
    '👨🏾‍💻' => 'mandlig IT-medarbejder: medium til mørk teint',
    '👨🏿‍💻' => 'mandlig IT-medarbejder: mørk teint',
    '👩🏻‍💻' => 'kvindelig IT-medarbejder: lys teint',
    '👩🏼‍💻' => 'kvindelig IT-medarbejder: medium til lys teint',
    '👩🏽‍💻' => 'kvindelig IT-medarbejder: medium teint',
    '👩🏾‍💻' => 'kvindelig IT-medarbejder: medium til mørk teint',
    '👩🏿‍💻' => 'kvindelig IT-medarbejder: mørk teint',
    '🧑🏻‍🎤' => 'sanger: lys teint',
    '🧑🏼‍🎤' => 'sanger: medium til lys teint',
    '🧑🏽‍🎤' => 'sanger: medium teint',
    '🧑🏾‍🎤' => 'sanger: medium til mørk teint',
    '🧑🏿‍🎤' => 'sanger: mørk teint',
    '👨🏻‍🎤' => 'mandlig sanger: lys teint',
    '👨🏼‍🎤' => 'mandlig sanger: medium til lys teint',
    '👨🏽‍🎤' => 'mandlig sanger: medium teint',
    '👨🏾‍🎤' => 'mandlig sanger: medium til mørk teint',
    '👨🏿‍🎤' => 'mandlig sanger: mørk teint',
    '👩🏻‍🎤' => 'sangerinde: lys teint',
    '👩🏼‍🎤' => 'sangerinde: medium til lys teint',
    '👩🏽‍🎤' => 'sangerinde: medium teint',
    '👩🏾‍🎤' => 'sangerinde: medium til mørk teint',
    '👩🏿‍🎤' => 'sangerinde: mørk teint',
    '🧑🏻‍🎨' => 'kunstner: lys teint',
    '🧑🏼‍🎨' => 'kunstner: medium til lys teint',
    '🧑🏽‍🎨' => 'kunstner: medium teint',
    '🧑🏾‍🎨' => 'kunstner: medium til mørk teint',
    '🧑🏿‍🎨' => 'kunstner: mørk teint',
    '👨🏻‍🎨' => 'mandlig kunstner: lys teint',
    '👨🏼‍🎨' => 'mandlig kunstner: medium til lys teint',
    '👨🏽‍🎨' => 'mandlig kunstner: medium teint',
    '👨🏾‍🎨' => 'mandlig kunstner: medium til mørk teint',
    '👨🏿‍🎨' => 'mandlig kunstner: mørk teint',
    '👩🏻‍🎨' => 'kvindelig kunstner: lys teint',
    '👩🏼‍🎨' => 'kvindelig kunstner: medium til lys teint',
    '👩🏽‍🎨' => 'kvindelig kunstner: medium teint',
    '👩🏾‍🎨' => 'kvindelig kunstner: medium til mørk teint',
    '👩🏿‍🎨' => 'kvindelig kunstner: mørk teint',
    '🧑🏻‍✈' => 'pilot: lys teint',
    '🧑🏼‍✈' => 'pilot: medium til lys teint',
    '🧑🏽‍✈' => 'pilot: medium teint',
    '🧑🏾‍✈' => 'pilot: medium til mørk teint',
    '🧑🏿‍✈' => 'pilot: mørk teint',
    '👨🏻‍✈' => 'mandlig pilot: lys teint',
    '👨🏼‍✈' => 'mandlig pilot: medium til lys teint',
    '👨🏽‍✈' => 'mandlig pilot: medium teint',
    '👨🏾‍✈' => 'mandlig pilot: medium til mørk teint',
    '👨🏿‍✈' => 'mandlig pilot: mørk teint',
    '👩🏻‍✈' => 'kvindelig pilot: lys teint',
    '👩🏼‍✈' => 'kvindelig pilot: medium til lys teint',
    '👩🏽‍✈' => 'kvindelig pilot: medium teint',
    '👩🏾‍✈' => 'kvindelig pilot: medium til mørk teint',
    '👩🏿‍✈' => 'kvindelig pilot: mørk teint',
    '🧑🏻‍🚀' => 'astronaut: lys teint',
    '🧑🏼‍🚀' => 'astronaut: medium til lys teint',
    '🧑🏽‍🚀' => 'astronaut: medium teint',
    '🧑🏾‍🚀' => 'astronaut: medium til mørk teint',
    '🧑🏿‍🚀' => 'astronaut: mørk teint',
    '👨🏻‍🚀' => 'mandlig astronaut: lys teint',
    '👨🏼‍🚀' => 'mandlig astronaut: medium til lys teint',
    '👨🏽‍🚀' => 'mandlig astronaut: medium teint',
    '👨🏾‍🚀' => 'mandlig astronaut: medium til mørk teint',
    '👨🏿‍🚀' => 'mandlig astronaut: mørk teint',
    '👩🏻‍🚀' => 'kvindelig astronaut: lys teint',
    '👩🏼‍🚀' => 'kvindelig astronaut: medium til lys teint',
    '👩🏽‍🚀' => 'kvindelig astronaut: medium teint',
    '👩🏾‍🚀' => 'kvindelig astronaut: medium til mørk teint',
    '👩🏿‍🚀' => 'kvindelig astronaut: mørk teint',
    '🧑🏻‍🚒' => 'brandfolk: lys teint',
    '🧑🏼‍🚒' => 'brandfolk: medium til lys teint',
    '🧑🏽‍🚒' => 'brandfolk: medium teint',
    '🧑🏾‍🚒' => 'brandfolk: medium til mørk teint',
    '🧑🏿‍🚒' => 'brandfolk: mørk teint',
    '👨🏻‍🚒' => 'brandmand: lys teint',
    '👨🏼‍🚒' => 'brandmand: medium til lys teint',
    '👨🏽‍🚒' => 'brandmand: medium teint',
    '👨🏾‍🚒' => 'brandmand: medium til mørk teint',
    '👨🏿‍🚒' => 'brandmand: mørk teint',
    '👩🏻‍🚒' => 'kvindelig brandmand: lys teint',
    '👩🏼‍🚒' => 'kvindelig brandmand: medium til lys teint',
    '👩🏽‍🚒' => 'kvindelig brandmand: medium teint',
    '👩🏾‍🚒' => 'kvindelig brandmand: medium til mørk teint',
    '👩🏿‍🚒' => 'kvindelig brandmand: mørk teint',
    '👮🏻‍♂' => 'mandlig politibetjent: lys teint',
    '👮🏼‍♂' => 'mandlig politibetjent: medium til lys teint',
    '👮🏽‍♂' => 'mandlig politibetjent: medium teint',
    '👮🏾‍♂' => 'mandlig politibetjent: medium til mørk teint',
    '👮🏿‍♂' => 'mandlig politibetjent: mørk teint',
    '👮🏻‍♀' => 'kvindelig politibetjent: lys teint',
    '👮🏼‍♀' => 'kvindelig politibetjent: medium til lys teint',
    '👮🏽‍♀' => 'kvindelig politibetjent: medium teint',
    '👮🏾‍♀' => 'kvindelig politibetjent: medium til mørk teint',
    '👮🏿‍♀' => 'kvindelig politibetjent: mørk teint',
    '🕵🏻‍♂' => 'mandlig detektiv: lys teint',
    '🕵🏼‍♂' => 'mandlig detektiv: medium til lys teint',
    '🕵🏽‍♂' => 'mandlig detektiv: medium teint',
    '🕵🏾‍♂' => 'mandlig detektiv: medium til mørk teint',
    '🕵🏿‍♂' => 'mandlig detektiv: mørk teint',
    '🕵🏻‍♀' => 'kvindelig detektiv: lys teint',
    '🕵🏼‍♀' => 'kvindelig detektiv: medium til lys teint',
    '🕵🏽‍♀' => 'kvindelig detektiv: medium teint',
    '🕵🏾‍♀' => 'kvindelig detektiv: medium til mørk teint',
    '🕵🏿‍♀' => 'kvindelig detektiv: mørk teint',
    '💂🏻‍♂' => 'mandlig garder: lys teint',
    '💂🏼‍♂' => 'mandlig garder: medium til lys teint',
    '💂🏽‍♂' => 'mandlig garder: medium teint',
    '💂🏾‍♂' => 'mandlig garder: medium til mørk teint',
    '💂🏿‍♂' => 'mandlig garder: mørk teint',
    '💂🏻‍♀' => 'kvindelig garder: lys teint',
    '💂🏼‍♀' => 'kvindelig garder: medium til lys teint',
    '💂🏽‍♀' => 'kvindelig garder: medium teint',
    '💂🏾‍♀' => 'kvindelig garder: medium til mørk teint',
    '💂🏿‍♀' => 'kvindelig garder: mørk teint',
    '👷🏻‍♂' => 'mandlig bygningsarbejder: lys teint',
    '👷🏼‍♂' => 'mandlig bygningsarbejder: medium til lys teint',
    '👷🏽‍♂' => 'mandlig bygningsarbejder: medium teint',
    '👷🏾‍♂' => 'mandlig bygningsarbejder: medium til mørk teint',
    '👷🏿‍♂' => 'mandlig bygningsarbejder: mørk teint',
    '👷🏻‍♀' => 'kvindelig bygningsarbejder: lys teint',
    '👷🏼‍♀' => 'kvindelig bygningsarbejder: medium til lys teint',
    '👷🏽‍♀' => 'kvindelig bygningsarbejder: medium teint',
    '👷🏾‍♀' => 'kvindelig bygningsarbejder: medium til mørk teint',
    '👷🏿‍♀' => 'kvindelig bygningsarbejder: mørk teint',
    '👳🏻‍♂' => 'mand med turban: lys teint',
    '👳🏼‍♂' => 'mand med turban: medium til lys teint',
    '👳🏽‍♂' => 'mand med turban: medium teint',
    '👳🏾‍♂' => 'mand med turban: medium til mørk teint',
    '👳🏿‍♂' => 'mand med turban: mørk teint',
    '👳🏻‍♀' => 'kvinde med turban: lys teint',
    '👳🏼‍♀' => 'kvinde med turban: medium til lys teint',
    '👳🏽‍♀' => 'kvinde med turban: medium teint',
    '👳🏾‍♀' => 'kvinde med turban: medium til mørk teint',
    '👳🏿‍♀' => 'kvinde med turban: mørk teint',
    '🤵🏻‍♂' => 'mand i smoking: lys teint',
    '🤵🏼‍♂' => 'mand i smoking: medium til lys teint',
    '🤵🏽‍♂' => 'mand i smoking: medium teint',
    '🤵🏾‍♂' => 'mand i smoking: medium til mørk teint',
    '🤵🏿‍♂' => 'mand i smoking: mørk teint',
    '🤵🏻‍♀' => 'kvinde i smoking: lys teint',
    '🤵🏼‍♀' => 'kvinde i smoking: medium til lys teint',
    '🤵🏽‍♀' => 'kvinde i smoking: medium teint',
    '🤵🏾‍♀' => 'kvinde i smoking: medium til mørk teint',
    '🤵🏿‍♀' => 'kvinde i smoking: mørk teint',
    '👰🏻‍♂' => 'mand med brudeslør: lys teint',
    '👰🏼‍♂' => 'mand med brudeslør: medium til lys teint',
    '👰🏽‍♂' => 'mand med brudeslør: medium teint',
    '👰🏾‍♂' => 'mand med brudeslør: medium til mørk teint',
    '👰🏿‍♂' => 'mand med brudeslør: mørk teint',
    '👰🏻‍♀' => 'kvinde med brudeslør: lys teint',
    '👰🏼‍♀' => 'kvinde med brudeslør: medium til lys teint',
    '👰🏽‍♀' => 'kvinde med brudeslør: medium teint',
    '👰🏾‍♀' => 'kvinde med brudeslør: medium til mørk teint',
    '👰🏿‍♀' => 'kvinde med brudeslør: mørk teint',
    '👩🏻‍🍼' => 'kvinde, der mader baby: lys teint',
    '👩🏼‍🍼' => 'kvinde, der mader baby: medium til lys teint',
    '👩🏽‍🍼' => 'kvinde, der mader baby: medium teint',
    '👩🏾‍🍼' => 'kvinde, der mader baby: medium til mørk teint',
    '👩🏿‍🍼' => 'kvinde, der mader baby: mørk teint',
    '👨🏻‍🍼' => 'mand, der mader baby: lys teint',
    '👨🏼‍🍼' => 'mand, der mader baby: medium til lys teint',
    '👨🏽‍🍼' => 'mand, der mader baby: medium teint',
    '👨🏾‍🍼' => 'mand, der mader baby: medium til mørk teint',
    '👨🏿‍🍼' => 'mand, der mader baby: mørk teint',
    '🧑🏻‍🍼' => 'person, der mader baby: lys teint',
    '🧑🏼‍🍼' => 'person, der mader baby: medium til lys teint',
    '🧑🏽‍🍼' => 'person, der mader baby: medium teint',
    '🧑🏾‍🍼' => 'person, der mader baby: medium til mørk teint',
    '🧑🏿‍🍼' => 'person, der mader baby: mørk teint',
    '🧑🏻‍🎄' => 'julenisse: lys teint',
    '🧑🏼‍🎄' => 'julenisse: medium til lys teint',
    '🧑🏽‍🎄' => 'julenisse: medium teint',
    '🧑🏾‍🎄' => 'julenisse: medium til mørk teint',
    '🧑🏿‍🎄' => 'julenisse: mørk teint',
    '🦸🏻‍♂' => 'mandlig superhelt: lys teint',
    '🦸🏼‍♂' => 'mandlig superhelt: medium til lys teint',
    '🦸🏽‍♂' => 'mandlig superhelt: medium teint',
    '🦸🏾‍♂' => 'mandlig superhelt: medium til mørk teint',
    '🦸🏿‍♂' => 'mandlig superhelt: mørk teint',
    '🦸🏻‍♀' => 'kvindelig superhelt: lys teint',
    '🦸🏼‍♀' => 'kvindelig superhelt: medium til lys teint',
    '🦸🏽‍♀' => 'kvindelig superhelt: medium teint',
    '🦸🏾‍♀' => 'kvindelig superhelt: medium til mørk teint',
    '🦸🏿‍♀' => 'kvindelig superhelt: mørk teint',
    '🦹🏻‍♂' => 'mandlig superskurk: lys teint',
    '🦹🏼‍♂' => 'mandlig superskurk: medium til lys teint',
    '🦹🏽‍♂' => 'mandlig superskurk: medium teint',
    '🦹🏾‍♂' => 'mandlig superskurk: medium til mørk teint',
    '🦹🏿‍♂' => 'mandlig superskurk: mørk teint',
    '🦹🏻‍♀' => 'kvindelig superskurk: lys teint',
    '🦹🏼‍♀' => 'kvindelig superskurk: medium til lys teint',
    '🦹🏽‍♀' => 'kvindelig superskurk: medium teint',
    '🦹🏾‍♀' => 'kvindelig superskurk: medium til mørk teint',
    '🦹🏿‍♀' => 'kvindelig superskurk: mørk teint',
    '🧙🏻‍♂' => 'mandlig magiker: lys teint',
    '🧙🏼‍♂' => 'mandlig magiker: medium til lys teint',
    '🧙🏽‍♂' => 'mandlig magiker: medium teint',
    '🧙🏾‍♂' => 'mandlig magiker: medium til mørk teint',
    '🧙🏿‍♂' => 'mandlig magiker: mørk teint',
    '🧙🏻‍♀' => 'kvindelig magiker: lys teint',
    '🧙🏼‍♀' => 'kvindelig magiker: medium til lys teint',
    '🧙🏽‍♀' => 'kvindelig magiker: medium teint',
    '🧙🏾‍♀' => 'kvindelig magiker: medium til mørk teint',
    '🧙🏿‍♀' => 'kvindelig magiker: mørk teint',
    '🧚🏻‍♂' => 'mandlig fe: lys teint',
    '🧚🏼‍♂' => 'mandlig fe: medium til lys teint',
    '🧚🏽‍♂' => 'mandlig fe: medium teint',
    '🧚🏾‍♂' => 'mandlig fe: medium til mørk teint',
    '🧚🏿‍♂' => 'mandlig fe: mørk teint',
    '🧚🏻‍♀' => 'kvindelig fe: lys teint',
    '🧚🏼‍♀' => 'kvindelig fe: medium til lys teint',
    '🧚🏽‍♀' => 'kvindelig fe: medium teint',
    '🧚🏾‍♀' => 'kvindelig fe: medium til mørk teint',
    '🧚🏿‍♀' => 'kvindelig fe: mørk teint',
    '🧛🏻‍♂' => 'mandlig vampyr: lys teint',
    '🧛🏼‍♂' => 'mandlig vampyr: medium til lys teint',
    '🧛🏽‍♂' => 'mandlig vampyr: medium teint',
    '🧛🏾‍♂' => 'mandlig vampyr: medium til mørk teint',
    '🧛🏿‍♂' => 'mandlig vampyr: mørk teint',
    '🧛🏻‍♀' => 'kvindelig vampyr: lys teint',
    '🧛🏼‍♀' => 'kvindelig vampyr: medium til lys teint',
    '🧛🏽‍♀' => 'kvindelig vampyr: medium teint',
    '🧛🏾‍♀' => 'kvindelig vampyr: medium til mørk teint',
    '🧛🏿‍♀' => 'kvindelig vampyr: mørk teint',
    '🧜🏻‍♂' => 'havmand: lys teint',
    '🧜🏼‍♂' => 'havmand: medium til lys teint',
    '🧜🏽‍♂' => 'havmand: medium teint',
    '🧜🏾‍♂' => 'havmand: medium til mørk teint',
    '🧜🏿‍♂' => 'havmand: mørk teint',
    '🧜🏻‍♀' => 'havfrue: lys teint',
    '🧜🏼‍♀' => 'havfrue: medium til lys teint',
    '🧜🏽‍♀' => 'havfrue: medium teint',
    '🧜🏾‍♀' => 'havfrue: medium til mørk teint',
    '🧜🏿‍♀' => 'havfrue: mørk teint',
    '🧝🏻‍♂' => 'elvermand: lys teint',
    '🧝🏼‍♂' => 'elvermand: medium til lys teint',
    '🧝🏽‍♂' => 'elvermand: medium teint',
    '🧝🏾‍♂' => 'elvermand: medium til mørk teint',
    '🧝🏿‍♂' => 'elvermand: mørk teint',
    '🧝🏻‍♀' => 'elverkvinde: lys teint',
    '🧝🏼‍♀' => 'elverkvinde: medium til lys teint',
    '🧝🏽‍♀' => 'elverkvinde: medium teint',
    '🧝🏾‍♀' => 'elverkvinde: medium til mørk teint',
    '🧝🏿‍♀' => 'elverkvinde: mørk teint',
    '💆🏻‍♂' => 'mand får ansigtsmassage: lys teint',
    '💆🏼‍♂' => 'mand får ansigtsmassage: medium til lys teint',
    '💆🏽‍♂' => 'mand får ansigtsmassage: medium teint',
    '💆🏾‍♂' => 'mand får ansigtsmassage: medium til mørk teint',
    '💆🏿‍♂' => 'mand får ansigtsmassage: mørk teint',
    '💆🏻‍♀' => 'kvinde får ansigtsmassage: lys teint',
    '💆🏼‍♀' => 'kvinde får ansigtsmassage: medium til lys teint',
    '💆🏽‍♀' => 'kvinde får ansigtsmassage: medium teint',
    '💆🏾‍♀' => 'kvinde får ansigtsmassage: medium til mørk teint',
    '💆🏿‍♀' => 'kvinde får ansigtsmassage: mørk teint',
    '💇🏻‍♂' => 'mand bliver klippet: lys teint',
    '💇🏼‍♂' => 'mand bliver klippet: medium til lys teint',
    '💇🏽‍♂' => 'mand bliver klippet: medium teint',
    '💇🏾‍♂' => 'mand bliver klippet: medium til mørk teint',
    '💇🏿‍♂' => 'mand bliver klippet: mørk teint',
    '💇🏻‍♀' => 'kvinde bliver klippet: lys teint',
    '💇🏼‍♀' => 'kvinde bliver klippet: medium til lys teint',
    '💇🏽‍♀' => 'kvinde bliver klippet: medium teint',
    '💇🏾‍♀' => 'kvinde bliver klippet: medium til mørk teint',
    '💇🏿‍♀' => 'kvinde bliver klippet: mørk teint',
    '🚶🏻‍♂' => 'mand går: lys teint',
    '🚶🏼‍♂' => 'mand går: medium til lys teint',
    '🚶🏽‍♂' => 'mand går: medium teint',
    '🚶🏾‍♂' => 'mand går: medium til mørk teint',
    '🚶🏿‍♂' => 'mand går: mørk teint',
    '🚶🏻‍♀' => 'kvinde går: lys teint',
    '🚶🏼‍♀' => 'kvinde går: medium til lys teint',
    '🚶🏽‍♀' => 'kvinde går: medium teint',
    '🚶🏾‍♀' => 'kvinde går: medium til mørk teint',
    '🚶🏿‍♀' => 'kvinde går: mørk teint',
    '🚶🏻‍➡' => 'fodgænger: lys teint og mod højre',
    '🚶🏼‍➡' => 'fodgænger: medium til lys teint og mod højre',
    '🚶🏽‍➡' => 'fodgænger: medium teint og mod højre',
    '🚶🏾‍➡' => 'fodgænger: medium til mørk teint og mod højre',
    '🚶🏿‍➡' => 'fodgænger: mørk teint og mod højre',
    '🧍🏻‍♂' => 'stående mand: lys teint',
    '🧍🏼‍♂' => 'stående mand: medium til lys teint',
    '🧍🏽‍♂' => 'stående mand: medium teint',
    '🧍🏾‍♂' => 'stående mand: medium til mørk teint',
    '🧍🏿‍♂' => 'stående mand: mørk teint',
    '🧍🏻‍♀' => 'stående kvinde: lys teint',
    '🧍🏼‍♀' => 'stående kvinde: medium til lys teint',
    '🧍🏽‍♀' => 'stående kvinde: medium teint',
    '🧍🏾‍♀' => 'stående kvinde: medium til mørk teint',
    '🧍🏿‍♀' => 'stående kvinde: mørk teint',
    '🧎🏻‍♂' => 'knælende mand: lys teint',
    '🧎🏼‍♂' => 'knælende mand: medium til lys teint',
    '🧎🏽‍♂' => 'knælende mand: medium teint',
    '🧎🏾‍♂' => 'knælende mand: medium til mørk teint',
    '🧎🏿‍♂' => 'knælende mand: mørk teint',
    '🧎🏻‍♀' => 'knælende kvinde: lys teint',
    '🧎🏼‍♀' => 'knælende kvinde: medium til lys teint',
    '🧎🏽‍♀' => 'knælende kvinde: medium teint',
    '🧎🏾‍♀' => 'knælende kvinde: medium til mørk teint',
    '🧎🏿‍♀' => 'knælende kvinde: mørk teint',
    '🧎🏻‍➡' => 'knælende person: lys teint og mod højre',
    '🧎🏼‍➡' => 'knælende person: medium til lys teint og mod højre',
    '🧎🏽‍➡' => 'knælende person: medium teint og mod højre',
    '🧎🏾‍➡' => 'knælende person: medium til mørk teint og mod højre',
    '🧎🏿‍➡' => 'knælende person: mørk teint og mod højre',
    '🧑🏻‍🦯' => 'person med blindestok: lys teint',
    '🧑🏼‍🦯' => 'person med blindestok: medium til lys teint',
    '🧑🏽‍🦯' => 'person med blindestok: medium teint',
    '🧑🏾‍🦯' => 'person med blindestok: medium til mørk teint',
    '🧑🏿‍🦯' => 'person med blindestok: mørk teint',
    '👨🏻‍🦯' => 'mand med blindestok: lys teint',
    '👨🏼‍🦯' => 'mand med blindestok: medium til lys teint',
    '👨🏽‍🦯' => 'mand med blindestok: medium teint',
    '👨🏾‍🦯' => 'mand med blindestok: medium til mørk teint',
    '👨🏿‍🦯' => 'mand med blindestok: mørk teint',
    '👩🏻‍🦯' => 'kvinde med blindestok: lys teint',
    '👩🏼‍🦯' => 'kvinde med blindestok: medium til lys teint',
    '👩🏽‍🦯' => 'kvinde med blindestok: medium teint',
    '👩🏾‍🦯' => 'kvinde med blindestok: medium til mørk teint',
    '👩🏿‍🦯' => 'kvinde med blindestok: mørk teint',
    '🧑🏻‍🦼' => 'person i elkørestol: lys teint',
    '🧑🏼‍🦼' => 'person i elkørestol: medium til lys teint',
    '🧑🏽‍🦼' => 'person i elkørestol: medium teint',
    '🧑🏾‍🦼' => 'person i elkørestol: medium til mørk teint',
    '🧑🏿‍🦼' => 'person i elkørestol: mørk teint',
    '👨🏻‍🦼' => 'mand i elektrisk kørestol: lys teint',
    '👨🏼‍🦼' => 'mand i elektrisk kørestol: medium til lys teint',
    '👨🏽‍🦼' => 'mand i elektrisk kørestol: medium teint',
    '👨🏾‍🦼' => 'mand i elektrisk kørestol: medium til mørk teint',
    '👨🏿‍🦼' => 'mand i elektrisk kørestol: mørk teint',
    '👩🏻‍🦼' => 'kvinde i elektrisk kørestol: lys teint',
    '👩🏼‍🦼' => 'kvinde i elektrisk kørestol: medium til lys teint',
    '👩🏽‍🦼' => 'kvinde i elektrisk kørestol: medium teint',
    '👩🏾‍🦼' => 'kvinde i elektrisk kørestol: medium til mørk teint',
    '👩🏿‍🦼' => 'kvinde i elektrisk kørestol: mørk teint',
    '🧑🏻‍🦽' => 'person i manuel kørestol: lys teint',
    '🧑🏼‍🦽' => 'person i manuel kørestol: medium til lys teint',
    '🧑🏽‍🦽' => 'person i manuel kørestol: medium teint',
    '🧑🏾‍🦽' => 'person i manuel kørestol: medium til mørk teint',
    '🧑🏿‍🦽' => 'person i manuel kørestol: mørk teint',
    '👨🏻‍🦽' => 'mand i manuel kørestol: lys teint',
    '👨🏼‍🦽' => 'mand i manuel kørestol: medium til lys teint',
    '👨🏽‍🦽' => 'mand i manuel kørestol: medium teint',
    '👨🏾‍🦽' => 'mand i manuel kørestol: medium til mørk teint',
    '👨🏿‍🦽' => 'mand i manuel kørestol: mørk teint',
    '👩🏻‍🦽' => 'kvinde i manuel kørestol: lys teint',
    '👩🏼‍🦽' => 'kvinde i manuel kørestol: medium til lys teint',
    '👩🏽‍🦽' => 'kvinde i manuel kørestol: medium teint',
    '👩🏾‍🦽' => 'kvinde i manuel kørestol: medium til mørk teint',
    '👩🏿‍🦽' => 'kvinde i manuel kørestol: mørk teint',
    '🏃🏻‍♂' => 'mand løber: lys teint',
    '🏃🏼‍♂' => 'mand løber: medium til lys teint',
    '🏃🏽‍♂' => 'mand løber: medium teint',
    '🏃🏾‍♂' => 'mand løber: medium til mørk teint',
    '🏃🏿‍♂' => 'mand løber: mørk teint',
    '🏃🏻‍♀' => 'kvinde løber: lys teint',
    '🏃🏼‍♀' => 'kvinde løber: medium til lys teint',
    '🏃🏽‍♀' => 'kvinde løber: medium teint',
    '🏃🏾‍♀' => 'kvinde løber: medium til mørk teint',
    '🏃🏿‍♀' => 'kvinde løber: mørk teint',
    '🏃🏻‍➡' => 'løber: lys teint og mod højre',
    '🏃🏼‍➡' => 'løber: medium til lys teint og mod højre',
    '🏃🏽‍➡' => 'løber: medium teint og mod højre',
    '🏃🏾‍➡' => 'løber: medium til mørk teint og mod højre',
    '🏃🏿‍➡' => 'løber: mørk teint og mod højre',
    '👯🏻‍♀' => 'kvinder med kaninører: lys teint',
    '👯🏼‍♀' => 'kvinder med kaninører: medium til lys teint',
    '👯🏽‍♀' => 'kvinder med kaninører: medium teint',
    '👯🏾‍♀' => 'kvinder med kaninører: medium til mørk teint',
    '👯🏿‍♀' => 'kvinder med kaninører: mørk teint',
    '👯🏻‍♂' => 'mænd med kaninører: lys teint',
    '👯🏼‍♂' => 'mænd med kaninører: medium til lys teint',
    '👯🏽‍♂' => 'mænd med kaninører: medium teint',
    '👯🏾‍♂' => 'mænd med kaninører: medium til mørk teint',
    '👯🏿‍♂' => 'mænd med kaninører: mørk teint',
    '🧖🏻‍♂' => 'mand i dampbad: lys teint',
    '🧖🏼‍♂' => 'mand i dampbad: medium til lys teint',
    '🧖🏽‍♂' => 'mand i dampbad: medium teint',
    '🧖🏾‍♂' => 'mand i dampbad: medium til mørk teint',
    '🧖🏿‍♂' => 'mand i dampbad: mørk teint',
    '🧖🏻‍♀' => 'kvinde i dampbad: lys teint',
    '🧖🏼‍♀' => 'kvinde i dampbad: medium til lys teint',
    '🧖🏽‍♀' => 'kvinde i dampbad: medium teint',
    '🧖🏾‍♀' => 'kvinde i dampbad: medium til mørk teint',
    '🧖🏿‍♀' => 'kvinde i dampbad: mørk teint',
    '🧗🏻‍♂' => 'mandlig bjergbestiger: lys teint',
    '🧗🏼‍♂' => 'mandlig bjergbestiger: medium til lys teint',
    '🧗🏽‍♂' => 'mandlig bjergbestiger: medium teint',
    '🧗🏾‍♂' => 'mandlig bjergbestiger: medium til mørk teint',
    '🧗🏿‍♂' => 'mandlig bjergbestiger: mørk teint',
    '🧗🏻‍♀' => 'kvindelig bjergbestiger: lys teint',
    '🧗🏼‍♀' => 'kvindelig bjergbestiger: medium til lys teint',
    '🧗🏽‍♀' => 'kvindelig bjergbestiger: medium teint',
    '🧗🏾‍♀' => 'kvindelig bjergbestiger: medium til mørk teint',
    '🧗🏿‍♀' => 'kvindelig bjergbestiger: mørk teint',
    '🏌🏻‍♂' => 'mandlig golfspiller: lys teint',
    '🏌🏼‍♂' => 'mandlig golfspiller: medium til lys teint',
    '🏌🏽‍♂' => 'mandlig golfspiller: medium teint',
    '🏌🏾‍♂' => 'mandlig golfspiller: medium til mørk teint',
    '🏌🏿‍♂' => 'mandlig golfspiller: mørk teint',
    '🏌🏻‍♀' => 'kvindelig golfspiller: lys teint',
    '🏌🏼‍♀' => 'kvindelig golfspiller: medium til lys teint',
    '🏌🏽‍♀' => 'kvindelig golfspiller: medium teint',
    '🏌🏾‍♀' => 'kvindelig golfspiller: medium til mørk teint',
    '🏌🏿‍♀' => 'kvindelig golfspiller: mørk teint',
    '🏄🏻‍♂' => 'mandlig surfer: lys teint',
    '🏄🏼‍♂' => 'mandlig surfer: medium til lys teint',
    '🏄🏽‍♂' => 'mandlig surfer: medium teint',
    '🏄🏾‍♂' => 'mandlig surfer: medium til mørk teint',
    '🏄🏿‍♂' => 'mandlig surfer: mørk teint',
    '🏄🏻‍♀' => 'kvindelig surfer: lys teint',
    '🏄🏼‍♀' => 'kvindelig surfer: medium til lys teint',
    '🏄🏽‍♀' => 'kvindelig surfer: medium teint',
    '🏄🏾‍♀' => 'kvindelig surfer: medium til mørk teint',
    '🏄🏿‍♀' => 'kvindelig surfer: mørk teint',
    '🚣🏻‍♂' => 'mand i robåd: lys teint',
    '🚣🏼‍♂' => 'mand i robåd: medium til lys teint',
    '🚣🏽‍♂' => 'mand i robåd: medium teint',
    '🚣🏾‍♂' => 'mand i robåd: medium til mørk teint',
    '🚣🏿‍♂' => 'mand i robåd: mørk teint',
    '🚣🏻‍♀' => 'kvinde i robåd: lys teint',
    '🚣🏼‍♀' => 'kvinde i robåd: medium til lys teint',
    '🚣🏽‍♀' => 'kvinde i robåd: medium teint',
    '🚣🏾‍♀' => 'kvinde i robåd: medium til mørk teint',
    '🚣🏿‍♀' => 'kvinde i robåd: mørk teint',
    '🏊🏻‍♂' => 'mandlig svømmer: lys teint',
    '🏊🏼‍♂' => 'mandlig svømmer: medium til lys teint',
    '🏊🏽‍♂' => 'mandlig svømmer: medium teint',
    '🏊🏾‍♂' => 'mandlig svømmer: medium til mørk teint',
    '🏊🏿‍♂' => 'mandlig svømmer: mørk teint',
    '🏊🏻‍♀' => 'kvindelig svømmer: lys teint',
    '🏊🏼‍♀' => 'kvindelig svømmer: medium til lys teint',
    '🏊🏽‍♀' => 'kvindelig svømmer: medium teint',
    '🏊🏾‍♀' => 'kvindelig svømmer: medium til mørk teint',
    '🏊🏿‍♀' => 'kvindelig svømmer: mørk teint',
    '⛹🏻‍♂' => 'mand, der dribler med en bold: lys teint',
    '⛹🏼‍♂' => 'mand, der dribler med en bold: medium til lys teint',
    '⛹🏽‍♂' => 'mand, der dribler med en bold: medium teint',
    '⛹🏾‍♂' => 'mand, der dribler med en bold: medium til mørk teint',
    '⛹🏿‍♂' => 'mand, der dribler med en bold: mørk teint',
    '⛹🏻‍♀' => 'kvinde, der dribler med en bold: lys teint',
    '⛹🏼‍♀' => 'kvinde, der dribler med en bold: medium til lys teint',
    '⛹🏽‍♀' => 'kvinde, der dribler med en bold: medium teint',
    '⛹🏾‍♀' => 'kvinde, der dribler med en bold: medium til mørk teint',
    '⛹🏿‍♀' => 'kvinde, der dribler med en bold: mørk teint',
    '🏋🏻‍♂' => 'mandlig vægtløfter: lys teint',
    '🏋🏼‍♂' => 'mandlig vægtløfter: medium til lys teint',
    '🏋🏽‍♂' => 'mandlig vægtløfter: medium teint',
    '🏋🏾‍♂' => 'mandlig vægtløfter: medium til mørk teint',
    '🏋🏿‍♂' => 'mandlig vægtløfter: mørk teint',
    '🏋🏻‍♀' => 'kvindelig vægtløfter: lys teint',
    '🏋🏼‍♀' => 'kvindelig vægtløfter: medium til lys teint',
    '🏋🏽‍♀' => 'kvindelig vægtløfter: medium teint',
    '🏋🏾‍♀' => 'kvindelig vægtløfter: medium til mørk teint',
    '🏋🏿‍♀' => 'kvindelig vægtløfter: mørk teint',
    '🚴🏻‍♂' => 'mandlig cyklist: lys teint',
    '🚴🏼‍♂' => 'mandlig cyklist: medium til lys teint',
    '🚴🏽‍♂' => 'mandlig cyklist: medium teint',
    '🚴🏾‍♂' => 'mandlig cyklist: medium til mørk teint',
    '🚴🏿‍♂' => 'mandlig cyklist: mørk teint',
    '🚴🏻‍♀' => 'kvindelig cyklist: lys teint',
    '🚴🏼‍♀' => 'kvindelig cyklist: medium til lys teint',
    '🚴🏽‍♀' => 'kvindelig cyklist: medium teint',
    '🚴🏾‍♀' => 'kvindelig cyklist: medium til mørk teint',
    '🚴🏿‍♀' => 'kvindelig cyklist: mørk teint',
    '🚵🏻‍♂' => 'mand på mountainbike: lys teint',
    '🚵🏼‍♂' => 'mand på mountainbike: medium til lys teint',
    '🚵🏽‍♂' => 'mand på mountainbike: medium teint',
    '🚵🏾‍♂' => 'mand på mountainbike: medium til mørk teint',
    '🚵🏿‍♂' => 'mand på mountainbike: mørk teint',
    '🚵🏻‍♀' => 'kvinde på mountainbike: lys teint',
    '🚵🏼‍♀' => 'kvinde på mountainbike: medium til lys teint',
    '🚵🏽‍♀' => 'kvinde på mountainbike: medium teint',
    '🚵🏾‍♀' => 'kvinde på mountainbike: medium til mørk teint',
    '🚵🏿‍♀' => 'kvinde på mountainbike: mørk teint',
    '🤸🏻‍♂' => 'mand slår vejrmøller: lys teint',
    '🤸🏼‍♂' => 'mand slår vejrmøller: medium til lys teint',
    '🤸🏽‍♂' => 'mand slår vejrmøller: medium teint',
    '🤸🏾‍♂' => 'mand slår vejrmøller: medium til mørk teint',
    '🤸🏿‍♂' => 'mand slår vejrmøller: mørk teint',
    '🤸🏻‍♀' => 'kvinde slår vejrmøller: lys teint',
    '🤸🏼‍♀' => 'kvinde slår vejrmøller: medium til lys teint',
    '🤸🏽‍♀' => 'kvinde slår vejrmøller: medium teint',
    '🤸🏾‍♀' => 'kvinde slår vejrmøller: medium til mørk teint',
    '🤸🏿‍♀' => 'kvinde slår vejrmøller: mørk teint',
    '🤼🏻‍♀' => 'kvindelige brydere: lys teint',
    '🤼🏼‍♀' => 'kvindelige brydere: medium til lys teint',
    '🤼🏽‍♀' => 'kvindelige brydere: medium teint',
    '🤼🏾‍♀' => 'kvindelige brydere: medium til mørk teint',
    '🤼🏿‍♀' => 'kvindelige brydere: mørk teint',
    '🤼🏻‍♂' => 'mandlige brydere: lys teint',
    '🤼🏼‍♂' => 'mandlige brydere: medium til lys teint',
    '🤼🏽‍♂' => 'mandlige brydere: medium teint',
    '🤼🏾‍♂' => 'mandlige brydere: medium til mørk teint',
    '🤼🏿‍♂' => 'mandlige brydere: mørk teint',
    '🤽🏻‍♂' => 'mandlig vandpolospiller: lys teint',
    '🤽🏼‍♂' => 'mandlig vandpolospiller: medium til lys teint',
    '🤽🏽‍♂' => 'mandlig vandpolospiller: medium teint',
    '🤽🏾‍♂' => 'mandlig vandpolospiller: medium til mørk teint',
    '🤽🏿‍♂' => 'mandlig vandpolospiller: mørk teint',
    '🤽🏻‍♀' => 'kvindelig vandpolospiller: lys teint',
    '🤽🏼‍♀' => 'kvindelig vandpolospiller: medium til lys teint',
    '🤽🏽‍♀' => 'kvindelig vandpolospiller: medium teint',
    '🤽🏾‍♀' => 'kvindelig vandpolospiller: medium til mørk teint',
    '🤽🏿‍♀' => 'kvindelig vandpolospiller: mørk teint',
    '🤾🏻‍♂' => 'mandlig håndboldspiller: lys teint',
    '🤾🏼‍♂' => 'mandlig håndboldspiller: medium til lys teint',
    '🤾🏽‍♂' => 'mandlig håndboldspiller: medium teint',
    '🤾🏾‍♂' => 'mandlig håndboldspiller: medium til mørk teint',
    '🤾🏿‍♂' => 'mandlig håndboldspiller: mørk teint',
    '🤾🏻‍♀' => 'kvindelig håndboldspiller: lys teint',
    '🤾🏼‍♀' => 'kvindelig håndboldspiller: medium til lys teint',
    '🤾🏽‍♀' => 'kvindelig håndboldspiller: medium teint',
    '🤾🏾‍♀' => 'kvindelig håndboldspiller: medium til mørk teint',
    '🤾🏿‍♀' => 'kvindelig håndboldspiller: mørk teint',
    '🤹🏻‍♂' => 'mandlig jonglør: lys teint',
    '🤹🏼‍♂' => 'mandlig jonglør: medium til lys teint',
    '🤹🏽‍♂' => 'mandlig jonglør: medium teint',
    '🤹🏾‍♂' => 'mandlig jonglør: medium til mørk teint',
    '🤹🏿‍♂' => 'mandlig jonglør: mørk teint',
    '🤹🏻‍♀' => 'kvindelig jonglør: lys teint',
    '🤹🏼‍♀' => 'kvindelig jonglør: medium til lys teint',
    '🤹🏽‍♀' => 'kvindelig jonglør: medium teint',
    '🤹🏾‍♀' => 'kvindelig jonglør: medium til mørk teint',
    '🤹🏿‍♀' => 'kvindelig jonglør: mørk teint',
    '🧘🏻‍♂' => 'mand i lotusstilling: lys teint',
    '🧘🏼‍♂' => 'mand i lotusstilling: medium til lys teint',
    '🧘🏽‍♂' => 'mand i lotusstilling: medium teint',
    '🧘🏾‍♂' => 'mand i lotusstilling: medium til mørk teint',
    '🧘🏿‍♂' => 'mand i lotusstilling: mørk teint',
    '🧘🏻‍♀' => 'kvinde i lotusstilling: lys teint',
    '🧘🏼‍♀' => 'kvinde i lotusstilling: medium til lys teint',
    '🧘🏽‍♀' => 'kvinde i lotusstilling: medium teint',
    '🧘🏾‍♀' => 'kvinde i lotusstilling: medium til mørk teint',
    '🧘🏿‍♀' => 'kvinde i lotusstilling: mørk teint',
    '🧑‍🦰' => 'voksen: rødt hår',
    '🧑‍🦱' => 'voksen: krøllet hår',
    '🧑‍🦳' => 'voksen: hvidt hår',
    '🧑‍🦲' => 'voksen: skaldet',
    '👨‍🦰' => 'mand: rødt hår',
    '👨‍🦱' => 'mand: krøllet hår',
    '👨‍🦳' => 'mand: hvidt hår',
    '👨‍🦲' => 'mand: skaldet',
    '👩‍🦰' => 'kvinde: rødt hår',
    '👩‍🦱' => 'kvinde: krøllet hår',
    '👩‍🦳' => 'kvinde: hvidt hår',
    '👩‍🦲' => 'kvinde: skaldet',
    '🚶‍➡' => 'fodgænger: mod højre',
    '🧎‍➡' => 'knælende person: mod højre',
    '🏃‍➡' => 'løber: mod højre',
    '👨‍👦' => 'familie: mand og dreng',
    '👨‍👧' => 'familie: mand og pige',
    '👩‍👦' => 'familie: kvinde og dreng',
    '👩‍👧' => 'familie: kvinde og pige',
    '😶‍🌫' => 'ansigt i sky',
    '😮‍💨' => 'udåndende ansigt',
    '🙂‍↕' => 'ryster på hovedet lodret',
    '😵‍💫' => 'ansigt med spiraløjne',
    '❤‍🔥' => 'brændende hjerte',
    '❤‍🩹' => 'helende hjerte',
    '👁‍🗨' => 'øje i taleboble',
    '🧔‍♂' => 'mand med skæg',
    '👱‍♂' => 'blond mand',
    '🧔‍♀' => 'kvinde med skæg',
    '👱‍♀' => 'blond kvinde',
    '🙍‍♂' => 'Utilfreds mand',
    '🙍‍♀' => 'Utilfreds kvinde',
    '🙎‍♂' => 'surmulende mand',
    '🙎‍♀' => 'surmulende kvinde',
    '🙅‍♂' => 'mand signalerer nej',
    '🙅‍♀' => 'kvinde signalerer nej',
    '🙆‍♂' => 'mand signalerer ok',
    '🙆‍♀' => 'kvinde signalerer ok',
    '💁‍♂' => 'mand vender håndfladen op',
    '💁‍♀' => 'kvinde vender håndfladen op',
    '🙋‍♂' => 'mand med løftet hånd',
    '🙋‍♀' => 'kvinde med løftet hånd',
    '🧏‍♂' => 'døv mand',
    '🧏‍♀' => 'døv kvinde',
    '🙇‍♂' => 'mand bukker dybt',
    '🙇‍♀' => 'kvinde bukker dybt',
    '🤦‍♂' => 'mand slår sig for panden',
    '🤦‍♀' => 'kvinde slår sig for panden',
    '🤷‍♂' => 'mand trækker på skuldrene',
    '🤷‍♀' => 'kvinde trækker på skuldrene',
    '🧑‍⚕' => 'sundhedspersonale',
    '👨‍⚕' => 'mandlig sundhedsperson',
    '👩‍⚕' => 'kvindelig sundhedsperson',
    '🧑‍🎓' => 'studerende',
    '👨‍🎓' => 'mandlig studerende',
    '👩‍🎓' => 'kvindelig studerende',
    '🧑‍🏫' => 'lærer',
    '👨‍🏫' => 'mandlig lærer',
    '👩‍🏫' => 'kvindelig lærer',
    '🧑‍⚖' => 'dommer',
    '👨‍⚖' => 'mandlig dommer',
    '👩‍⚖' => 'kvindelig dommer',
    '🧑‍🌾' => 'bonde',
    '👨‍🌾' => 'landmand',
    '👩‍🌾' => 'kvindelig landmand',
    '🧑‍🍳' => 'kok',
    '👨‍🍳' => 'mandlig kok',
    '👩‍🍳' => 'kvindelig kok',
    '🧑‍🔧' => 'mekaniker',
    '👨‍🔧' => 'mandlig mekaniker',
    '👩‍🔧' => 'kvindelig mekaniker',
    '🧑‍🏭' => 'fabriksarbejder',
    '👨‍🏭' => 'mandlig fabriksarbejder',
    '👩‍🏭' => 'kvindelig fabriksarbejder',
    '🧑‍💼' => 'kontoransat',
    '👨‍💼' => 'mandlig kontoransat',
    '👩‍💼' => 'kvindelig kontoransat',
    '🧑‍🔬' => 'forsker',
    '👨‍🔬' => 'mandlig forsker',
    '👩‍🔬' => 'kvindelig forsker',
    '🧑‍💻' => 'it-medarbejder',
    '👨‍💻' => 'mandlig IT-medarbejder',
    '👩‍💻' => 'kvindelig IT-medarbejder',
    '🧑‍🎤' => 'sanger',
    '👨‍🎤' => 'mandlig sanger',
    '👩‍🎤' => 'sangerinde',
    '🧑‍🎨' => 'kunstner',
    '👨‍🎨' => 'mandlig kunstner',
    '👩‍🎨' => 'kvindelig kunstner',
    '🧑‍✈' => 'pilot',
    '👨‍✈' => 'mandlig pilot',
    '👩‍✈' => 'kvindelig pilot',
    '🧑‍🚀' => 'astronaut',
    '👨‍🚀' => 'mandlig astronaut',
    '👩‍🚀' => 'kvindelig astronaut',
    '🧑‍🚒' => 'brandfolk',
    '👨‍🚒' => 'brandmand',
    '👩‍🚒' => 'kvindelig brandmand',
    '👮‍♂' => 'mandlig politibetjent',
    '👮‍♀' => 'kvindelig politibetjent',
    '🕵‍♂' => 'mandlig detektiv',
    '🕵‍♀' => 'kvindelig detektiv',
    '💂‍♂' => 'mandlig garder',
    '💂‍♀' => 'kvindelig garder',
    '👷‍♂' => 'mandlig bygningsarbejder',
    '👷‍♀' => 'kvindelig bygningsarbejder',
    '👳‍♂' => 'mand med turban',
    '👳‍♀' => 'kvinde med turban',
    '🤵‍♂' => 'mand i smoking',
    '🤵‍♀' => 'kvinde i smoking',
    '👰‍♂' => 'mand med brudeslør',
    '👰‍♀' => 'kvinde med brudeslør',
    '👩‍🍼' => 'kvinde, der mader baby',
    '👨‍🍼' => 'mand, der mader baby',
    '🧑‍🍼' => 'person, der mader baby',
    '🧑‍🎄' => 'julenisse',
    '🦸‍♂' => 'mandlig superhelt',
    '🦸‍♀' => 'kvindelig superhelt',
    '🦹‍♂' => 'mandlig superskurk',
    '🦹‍♀' => 'kvindelig superskurk',
    '🧙‍♂' => 'mandlig magiker',
    '🧙‍♀' => 'kvindelig magiker',
    '🧚‍♂' => 'mandlig fe',
    '🧚‍♀' => 'kvindelig fe',
    '🧛‍♂' => 'mandlig vampyr',
    '🧛‍♀' => 'kvindelig vampyr',
    '🧜‍♂' => 'havmand',
    '🧜‍♀' => 'havfrue',
    '🧝‍♂' => 'elvermand',
    '🧝‍♀' => 'elverkvinde',
    '🧞‍♂' => 'mandlig magisk ånd',
    '🧞‍♀' => 'kvindelig magisk ånd',
    '🧟‍♂' => 'mandlig zombie',
    '🧟‍♀' => 'kvindelig zombie',
    '💆‍♂' => 'mand får ansigtsmassage',
    '💆‍♀' => 'kvinde får ansigtsmassage',
    '💇‍♂' => 'mand bliver klippet',
    '💇‍♀' => 'kvinde bliver klippet',
    '🚶‍♂' => 'mand går',
    '🚶‍♀' => 'kvinde går',
    '🧍‍♂' => 'stående mand',
    '🧍‍♀' => 'stående kvinde',
    '🧎‍♂' => 'knælende mand',
    '🧎‍♀' => 'knælende kvinde',
    '🧑‍🦯' => 'person med blindestok',
    '👨‍🦯' => 'mand med blindestok',
    '👩‍🦯' => 'kvinde med blindestok',
    '🧑‍🦼' => 'person i elkørestol',
    '👨‍🦼' => 'mand i elektrisk kørestol',
    '👩‍🦼' => 'kvinde i elektrisk kørestol',
    '🧑‍🦽' => 'person i manuel kørestol',
    '👨‍🦽' => 'mand i manuel kørestol',
    '👩‍🦽' => 'kvinde i manuel kørestol',
    '🏃‍♂' => 'mand løber',
    '🏃‍♀' => 'kvinde løber',
    '🧑‍🩰' => 'balletdanser',
    '👯‍♂' => 'mænd med kaninører',
    '👯‍♀' => 'kvinder med kaninører',
    '🧖‍♂' => 'mand i dampbad',
    '🧖‍♀' => 'kvinde i dampbad',
    '🧗‍♂' => 'mandlig bjergbestiger',
    '🧗‍♀' => 'kvindelig bjergbestiger',
    '🏌‍♂' => 'mandlig golfspiller',
    '🏌‍♀' => 'kvindelig golfspiller',
    '🏄‍♂' => 'mandlig surfer',
    '🏄‍♀' => 'kvindelig surfer',
    '🚣‍♂' => 'mand i robåd',
    '🚣‍♀' => 'kvinde i robåd',
    '🏊‍♂' => 'mandlig svømmer',
    '🏊‍♀' => 'kvindelig svømmer',
    '⛹‍♂' => 'mand, der dribler med en bold',
    '⛹‍♀' => 'kvinde, der dribler med en bold',
    '🏋‍♂' => 'mandlig vægtløfter',
    '🏋‍♀' => 'kvindelig vægtløfter',
    '🚴‍♂' => 'mandlig cyklist',
    '🚴‍♀' => 'kvindelig cyklist',
    '🚵‍♂' => 'mand på mountainbike',
    '🚵‍♀' => 'kvinde på mountainbike',
    '🤸‍♂' => 'mand slår vejrmøller',
    '🤸‍♀' => 'kvinde slår vejrmøller',
    '🤼‍♂' => 'mandlige brydere',
    '🤼‍♀' => 'kvindelige brydere',
    '🤽‍♂' => 'mandlig vandpolospiller',
    '🤽‍♀' => 'kvindelig vandpolospiller',
    '🤾‍♂' => 'mandlig håndboldspiller',
    '🤾‍♀' => 'kvindelig håndboldspiller',
    '🤹‍♂' => 'mandlig jonglør',
    '🤹‍♀' => 'kvindelig jonglør',
    '🧘‍♂' => 'mand i lotusstilling',
    '🧘‍♀' => 'kvinde i lotusstilling',
    '🧑‍🧒' => 'familie: voksen, barn',
    '🐕‍🦺' => 'servicehund',
    '🐈‍⬛' => 'sort kat',
    '🐻‍❄' => 'isbjørn',
    '🐦‍⬛' => 'sort fugl',
    '🐦‍🔥' => 'føniks',
    '🍋‍🟩' => 'lime',
    '🍄‍🟫' => 'brun svamp',
    '⛓‍💥' => 'brudt kæde',
    '🏳‍🌈' => 'regnbueflag',
    '🏳‍⚧' => 'transkønnet flag',
    '🏴‍☠' => 'piratflag',
    '👋🏻' => 'vinker: lys teint',
    '👋🏼' => 'vinker: medium til lys teint',
    '👋🏽' => 'vinker: medium teint',
    '👋🏾' => 'vinker: medium til mørk teint',
    '👋🏿' => 'vinker: mørk teint',
    '🤚🏻' => 'løftet håndryg: lys teint',
    '🤚🏼' => 'løftet håndryg: medium til lys teint',
    '🤚🏽' => 'løftet håndryg: medium teint',
    '🤚🏾' => 'løftet håndryg: medium til mørk teint',
    '🤚🏿' => 'løftet håndryg: mørk teint',
    '🖐🏻' => 'hånd med spredte fingre: lys teint',
    '🖐🏼' => 'hånd med spredte fingre: medium til lys teint',
    '🖐🏽' => 'hånd med spredte fingre: medium teint',
    '🖐🏾' => 'hånd med spredte fingre: medium til mørk teint',
    '🖐🏿' => 'hånd med spredte fingre: mørk teint',
    '✋🏻' => 'løftet hånd: lys teint',
    '✋🏼' => 'løftet hånd: medium til lys teint',
    '✋🏽' => 'løftet hånd: medium teint',
    '✋🏾' => 'løftet hånd: medium til mørk teint',
    '✋🏿' => 'løftet hånd: mørk teint',
    '🖖🏻' => 'vulcan-hilsen: lys teint',
    '🖖🏼' => 'vulcan-hilsen: medium til lys teint',
    '🖖🏽' => 'vulcan-hilsen: medium teint',
    '🖖🏾' => 'vulcan-hilsen: medium til mørk teint',
    '🖖🏿' => 'vulcan-hilsen: mørk teint',
    '🫱🏻' => 'hånd til højre: lys teint',
    '🫱🏼' => 'hånd til højre: medium til lys teint',
    '🫱🏽' => 'hånd til højre: medium teint',
    '🫱🏾' => 'hånd til højre: medium til mørk teint',
    '🫱🏿' => 'hånd til højre: mørk teint',
    '🫲🏻' => 'hånd til venstre: lys teint',
    '🫲🏼' => 'hånd til venstre: medium til lys teint',
    '🫲🏽' => 'hånd til venstre: medium teint',
    '🫲🏾' => 'hånd til venstre: medium til mørk teint',
    '🫲🏿' => 'hånd til venstre: mørk teint',
    '🫳🏻' => 'håndflade nedad: lys teint',
    '🫳🏼' => 'håndflade nedad: medium til lys teint',
    '🫳🏽' => 'håndflade nedad: medium teint',
    '🫳🏾' => 'håndflade nedad: medium til mørk teint',
    '🫳🏿' => 'håndflade nedad: mørk teint',
    '🫴🏻' => 'håndflade opad: lys teint',
    '🫴🏼' => 'håndflade opad: medium til lys teint',
    '🫴🏽' => 'håndflade opad: medium teint',
    '🫴🏾' => 'håndflade opad: medium til mørk teint',
    '🫴🏿' => 'håndflade opad: mørk teint',
    '🫷🏻' => 'hånd skubber mod venstre: lys teint',
    '🫷🏼' => 'hånd skubber mod venstre: medium til lys teint',
    '🫷🏽' => 'hånd skubber mod venstre: medium teint',
    '🫷🏾' => 'hånd skubber mod venstre: medium til mørk teint',
    '🫷🏿' => 'hånd skubber mod venstre: mørk teint',
    '🫸🏻' => 'hånd skubber mod højre: lys teint',
    '🫸🏼' => 'hånd skubber mod højre: medium til lys teint',
    '🫸🏽' => 'hånd skubber mod højre: medium teint',
    '🫸🏾' => 'hånd skubber mod højre: medium til mørk teint',
    '🫸🏿' => 'hånd skubber mod højre: mørk teint',
    '👌🏻' => 'ok-tegn: lys teint',
    '👌🏼' => 'ok-tegn: medium til lys teint',
    '👌🏽' => 'ok-tegn: medium teint',
    '👌🏾' => 'ok-tegn: medium til mørk teint',
    '👌🏿' => 'ok-tegn: mørk teint',
    '🤌🏻' => 'samlede fingre: lys teint',
    '🤌🏼' => 'samlede fingre: medium til lys teint',
    '🤌🏽' => 'samlede fingre: medium teint',
    '🤌🏾' => 'samlede fingre: medium til mørk teint',
    '🤌🏿' => 'samlede fingre: mørk teint',
    '🤏🏻' => 'lidt vist med tommel- og pegefinger: lys teint',
    '🤏🏼' => 'lidt vist med tommel- og pegefinger: medium til lys teint',
    '🤏🏽' => 'lidt vist med tommel- og pegefinger: medium teint',
    '🤏🏾' => 'lidt vist med tommel- og pegefinger: medium til mørk teint',
    '🤏🏿' => 'lidt vist med tommel- og pegefinger: mørk teint',
    '✌🏻' => 'v-tegn: lys teint',
    '✌🏼' => 'v-tegn: medium til lys teint',
    '✌🏽' => 'v-tegn: medium teint',
    '✌🏾' => 'v-tegn: medium til mørk teint',
    '✌🏿' => 'v-tegn: mørk teint',
    '🤞🏻' => 'krydsede fingre: lys teint',
    '🤞🏼' => 'krydsede fingre: medium til lys teint',
    '🤞🏽' => 'krydsede fingre: medium teint',
    '🤞🏾' => 'krydsede fingre: medium til mørk teint',
    '🤞🏿' => 'krydsede fingre: mørk teint',
    '🫰🏻' => 'krydset pegefinger og tommelfinger: lys teint',
    '🫰🏼' => 'krydset pegefinger og tommelfinger: medium til lys teint',
    '🫰🏽' => 'krydset pegefinger og tommelfinger: medium teint',
    '🫰🏾' => 'krydset pegefinger og tommelfinger: medium til mørk teint',
    '🫰🏿' => 'krydset pegefinger og tommelfinger: mørk teint',
    '🤟🏻' => 'elsker dig-gestus: lys teint',
    '🤟🏼' => 'elsker dig-gestus: medium til lys teint',
    '🤟🏽' => 'elsker dig-gestus: medium teint',
    '🤟🏾' => 'elsker dig-gestus: medium til mørk teint',
    '🤟🏿' => 'elsker dig-gestus: mørk teint',
    '🤘🏻' => 'djævletegn: lys teint',
    '🤘🏼' => 'djævletegn: medium til lys teint',
    '🤘🏽' => 'djævletegn: medium teint',
    '🤘🏾' => 'djævletegn: medium til mørk teint',
    '🤘🏿' => 'djævletegn: mørk teint',
    '🤙🏻' => 'ring til mig-hånd: lys teint',
    '🤙🏼' => 'ring til mig-hånd: medium til lys teint',
    '🤙🏽' => 'ring til mig-hånd: medium teint',
    '🤙🏾' => 'ring til mig-hånd: medium til mørk teint',
    '🤙🏿' => 'ring til mig-hånd: mørk teint',
    '👈🏻' => 'peger mod venstre: lys teint',
    '👈🏼' => 'peger mod venstre: medium til lys teint',
    '👈🏽' => 'peger mod venstre: medium teint',
    '👈🏾' => 'peger mod venstre: medium til mørk teint',
    '👈🏿' => 'peger mod venstre: mørk teint',
    '👉🏻' => 'peger mod højre: lys teint',
    '👉🏼' => 'peger mod højre: medium til lys teint',
    '👉🏽' => 'peger mod højre: medium teint',
    '👉🏾' => 'peger mod højre: medium til mørk teint',
    '👉🏿' => 'peger mod højre: mørk teint',
    '👆🏻' => 'peger opad: lys teint',
    '👆🏼' => 'peger opad: medium til lys teint',
    '👆🏽' => 'peger opad: medium teint',
    '👆🏾' => 'peger opad: medium til mørk teint',
    '👆🏿' => 'peger opad: mørk teint',
    '🖕🏻' => 'langefinger: lys teint',
    '🖕🏼' => 'langefinger: medium til lys teint',
    '🖕🏽' => 'langefinger: medium teint',
    '🖕🏾' => 'langefinger: medium til mørk teint',
    '🖕🏿' => 'langefinger: mørk teint',
    '👇🏻' => 'peger nedad: lys teint',
    '👇🏼' => 'peger nedad: medium til lys teint',
    '👇🏽' => 'peger nedad: medium teint',
    '👇🏾' => 'peger nedad: medium til mørk teint',
    '👇🏿' => 'peger nedad: mørk teint',
    '☝🏻' => 'rækker finger op: lys teint',
    '☝🏼' => 'rækker finger op: medium til lys teint',
    '☝🏽' => 'rækker finger op: medium teint',
    '☝🏾' => 'rækker finger op: medium til mørk teint',
    '☝🏿' => 'rækker finger op: mørk teint',
    '🫵🏻' => 'peger på seeren: lys teint',
    '🫵🏼' => 'peger på seeren: medium til lys teint',
    '🫵🏽' => 'peger på seeren: medium teint',
    '🫵🏾' => 'peger på seeren: medium til mørk teint',
    '🫵🏿' => 'peger på seeren: mørk teint',
    '👍🏻' => 'tommelfinger op: lys teint',
    '👍🏼' => 'tommelfinger op: medium til lys teint',
    '👍🏽' => 'tommelfinger op: medium teint',
    '👍🏾' => 'tommelfinger op: medium til mørk teint',
    '👍🏿' => 'tommelfinger op: mørk teint',
    '👎🏻' => 'tommelfinger ned: lys teint',
    '👎🏼' => 'tommelfinger ned: medium til lys teint',
    '👎🏽' => 'tommelfinger ned: medium teint',
    '👎🏾' => 'tommelfinger ned: medium til mørk teint',
    '👎🏿' => 'tommelfinger ned: mørk teint',
    '✊🏻' => 'løftet knytnæve: lys teint',
    '✊🏼' => 'løftet knytnæve: medium til lys teint',
    '✊🏽' => 'løftet knytnæve: medium teint',
    '✊🏾' => 'løftet knytnæve: medium til mørk teint',
    '✊🏿' => 'løftet knytnæve: mørk teint',
    '👊🏻' => 'knytnæve: lys teint',
    '👊🏼' => 'knytnæve: medium til lys teint',
    '👊🏽' => 'knytnæve: medium teint',
    '👊🏾' => 'knytnæve: medium til mørk teint',
    '👊🏿' => 'knytnæve: mørk teint',
    '🤛🏻' => 'venstrevendt knytnæve: lys teint',
    '🤛🏼' => 'venstrevendt knytnæve: medium til lys teint',
    '🤛🏽' => 'venstrevendt knytnæve: medium teint',
    '🤛🏾' => 'venstrevendt knytnæve: medium til mørk teint',
    '🤛🏿' => 'venstrevendt knytnæve: mørk teint',
    '🤜🏻' => 'højrevendt knytnæve: lys teint',
    '🤜🏼' => 'højrevendt knytnæve: medium til lys teint',
    '🤜🏽' => 'højrevendt knytnæve: medium teint',
    '🤜🏾' => 'højrevendt knytnæve: medium til mørk teint',
    '🤜🏿' => 'højrevendt knytnæve: mørk teint',
    '👏🏻' => 'klappende hænder: lys teint',
    '👏🏼' => 'klappende hænder: medium til lys teint',
    '👏🏽' => 'klappende hænder: medium teint',
    '👏🏾' => 'klappende hænder: medium til mørk teint',
    '👏🏿' => 'klappende hænder: mørk teint',
    '🙌🏻' => 'løftede hænder: lys teint',
    '🙌🏼' => 'løftede hænder: medium til lys teint',
    '🙌🏽' => 'løftede hænder: medium teint',
    '🙌🏾' => 'løftede hænder: medium til mørk teint',
    '🙌🏿' => 'løftede hænder: mørk teint',
    '🫶🏻' => 'hjertehænder: lys teint',
    '🫶🏼' => 'hjertehænder: medium til lys teint',
    '🫶🏽' => 'hjertehænder: medium teint',
    '🫶🏾' => 'hjertehænder: medium til mørk teint',
    '🫶🏿' => 'hjertehænder: mørk teint',
    '👐🏻' => 'åbne hænder: lys teint',
    '👐🏼' => 'åbne hænder: medium til lys teint',
    '👐🏽' => 'åbne hænder: medium teint',
    '👐🏾' => 'åbne hænder: medium til mørk teint',
    '👐🏿' => 'åbne hænder: mørk teint',
    '🤲🏻' => 'håndflader samlet og løftet: lys teint',
    '🤲🏼' => 'håndflader samlet og løftet: medium til lys teint',
    '🤲🏽' => 'håndflader samlet og løftet: medium teint',
    '🤲🏾' => 'håndflader samlet og løftet: medium til mørk teint',
    '🤲🏿' => 'håndflader samlet og løftet: mørk teint',
    '🤝🏻' => 'håndtryk: lys teint',
    '🤝🏼' => 'håndtryk: medium til lys teint',
    '🤝🏽' => 'håndtryk: medium teint',
    '🤝🏾' => 'håndtryk: medium til mørk teint',
    '🤝🏿' => 'håndtryk: mørk teint',
    '🙏🏻' => 'foldede hænder: lys teint',
    '🙏🏼' => 'foldede hænder: medium til lys teint',
    '🙏🏽' => 'foldede hænder: medium teint',
    '🙏🏾' => 'foldede hænder: medium til mørk teint',
    '🙏🏿' => 'foldede hænder: mørk teint',
    '✍🏻' => 'skrivende hånd: lys teint',
    '✍🏼' => 'skrivende hånd: medium til lys teint',
    '✍🏽' => 'skrivende hånd: medium teint',
    '✍🏾' => 'skrivende hånd: medium til mørk teint',
    '✍🏿' => 'skrivende hånd: mørk teint',
    '💅🏻' => 'neglelak: lys teint',
    '💅🏼' => 'neglelak: medium til lys teint',
    '💅🏽' => 'neglelak: medium teint',
    '💅🏾' => 'neglelak: medium til mørk teint',
    '💅🏿' => 'neglelak: mørk teint',
    '🤳🏻' => 'selfie: lys teint',
    '🤳🏼' => 'selfie: medium til lys teint',
    '🤳🏽' => 'selfie: medium teint',
    '🤳🏾' => 'selfie: medium til mørk teint',
    '🤳🏿' => 'selfie: mørk teint',
    '💪🏻' => 'armmuskler: lys teint',
    '💪🏼' => 'armmuskler: medium til lys teint',
    '💪🏽' => 'armmuskler: medium teint',
    '💪🏾' => 'armmuskler: medium til mørk teint',
    '💪🏿' => 'armmuskler: mørk teint',
    '🦵🏻' => 'ben: lys teint',
    '🦵🏼' => 'ben: medium til lys teint',
    '🦵🏽' => 'ben: medium teint',
    '🦵🏾' => 'ben: medium til mørk teint',
    '🦵🏿' => 'ben: mørk teint',
    '🦶🏻' => 'fod: lys teint',
    '🦶🏼' => 'fod: medium til lys teint',
    '🦶🏽' => 'fod: medium teint',
    '🦶🏾' => 'fod: medium til mørk teint',
    '🦶🏿' => 'fod: mørk teint',
    '👂🏻' => 'øre: lys teint',
    '👂🏼' => 'øre: medium til lys teint',
    '👂🏽' => 'øre: medium teint',
    '👂🏾' => 'øre: medium til mørk teint',
    '👂🏿' => 'øre: mørk teint',
    '🦻🏻' => 'øre med høreapparat: lys teint',
    '🦻🏼' => 'øre med høreapparat: medium til lys teint',
    '🦻🏽' => 'øre med høreapparat: medium teint',
    '🦻🏾' => 'øre med høreapparat: medium til mørk teint',
    '🦻🏿' => 'øre med høreapparat: mørk teint',
    '👃🏻' => 'næse: lys teint',
    '👃🏼' => 'næse: medium til lys teint',
    '👃🏽' => 'næse: medium teint',
    '👃🏾' => 'næse: medium til mørk teint',
    '👃🏿' => 'næse: mørk teint',
    '👶🏻' => 'baby: lys teint',
    '👶🏼' => 'baby: medium til lys teint',
    '👶🏽' => 'baby: medium teint',
    '👶🏾' => 'baby: medium til mørk teint',
    '👶🏿' => 'baby: mørk teint',
    '🧒🏻' => 'barn: lys teint',
    '🧒🏼' => 'barn: medium til lys teint',
    '🧒🏽' => 'barn: medium teint',
    '🧒🏾' => 'barn: medium til mørk teint',
    '🧒🏿' => 'barn: mørk teint',
    '👦🏻' => 'dreng: lys teint',
    '👦🏼' => 'dreng: medium til lys teint',
    '👦🏽' => 'dreng: medium teint',
    '👦🏾' => 'dreng: medium til mørk teint',
    '👦🏿' => 'dreng: mørk teint',
    '👧🏻' => 'pige: lys teint',
    '👧🏼' => 'pige: medium til lys teint',
    '👧🏽' => 'pige: medium teint',
    '👧🏾' => 'pige: medium til mørk teint',
    '👧🏿' => 'pige: mørk teint',
    '🧑🏻' => 'voksen: lys teint',
    '🧑🏼' => 'voksen: medium til lys teint',
    '🧑🏽' => 'voksen: medium teint',
    '🧑🏾' => 'voksen: medium til mørk teint',
    '🧑🏿' => 'voksen: mørk teint',
    '👱🏻' => 'blond person: lys teint',
    '👱🏼' => 'blond person: medium til lys teint',
    '👱🏽' => 'blond person: medium teint',
    '👱🏾' => 'blond person: medium til mørk teint',
    '👱🏿' => 'blond person: mørk teint',
    '👨🏻' => 'mand: lys teint',
    '👨🏼' => 'mand: medium til lys teint',
    '👨🏽' => 'mand: medium teint',
    '👨🏾' => 'mand: medium til mørk teint',
    '👨🏿' => 'mand: mørk teint',
    '🧔🏻' => 'person med skæg: lys teint',
    '🧔🏼' => 'person med skæg: medium til lys teint',
    '🧔🏽' => 'person med skæg: medium teint',
    '🧔🏾' => 'person med skæg: medium til mørk teint',
    '🧔🏿' => 'person med skæg: mørk teint',
    '👩🏻' => 'kvinde: lys teint',
    '👩🏼' => 'kvinde: medium til lys teint',
    '👩🏽' => 'kvinde: medium teint',
    '👩🏾' => 'kvinde: medium til mørk teint',
    '👩🏿' => 'kvinde: mørk teint',
    '🧓🏻' => 'ældre menneske: lys teint',
    '🧓🏼' => 'ældre menneske: medium til lys teint',
    '🧓🏽' => 'ældre menneske: medium teint',
    '🧓🏾' => 'ældre menneske: medium til mørk teint',
    '🧓🏿' => 'ældre menneske: mørk teint',
    '👴🏻' => 'gammel mand: lys teint',
    '👴🏼' => 'gammel mand: medium til lys teint',
    '👴🏽' => 'gammel mand: medium teint',
    '👴🏾' => 'gammel mand: medium til mørk teint',
    '👴🏿' => 'gammel mand: mørk teint',
    '👵🏻' => 'gammel kvinde: lys teint',
    '👵🏼' => 'gammel kvinde: medium til lys teint',
    '👵🏽' => 'gammel kvinde: medium teint',
    '👵🏾' => 'gammel kvinde: medium til mørk teint',
    '👵🏿' => 'gammel kvinde: mørk teint',
    '🙍🏻' => 'Utilfreds person: lys teint',
    '🙍🏼' => 'Utilfreds person: medium til lys teint',
    '🙍🏽' => 'Utilfreds person: medium teint',
    '🙍🏾' => 'Utilfreds person: medium til mørk teint',
    '🙍🏿' => 'Utilfreds person: mørk teint',
    '🙎🏻' => 'surmulende person: lys teint',
    '🙎🏼' => 'surmulende person: medium til lys teint',
    '🙎🏽' => 'surmulende person: medium teint',
    '🙎🏾' => 'surmulende person: medium til mørk teint',
    '🙎🏿' => 'surmulende person: mørk teint',
    '🙅🏻' => 'signalerer nej: lys teint',
    '🙅🏼' => 'signalerer nej: medium til lys teint',
    '🙅🏽' => 'signalerer nej: medium teint',
    '🙅🏾' => 'signalerer nej: medium til mørk teint',
    '🙅🏿' => 'signalerer nej: mørk teint',
    '🙆🏻' => 'signalerer ok: lys teint',
    '🙆🏼' => 'signalerer ok: medium til lys teint',
    '🙆🏽' => 'signalerer ok: medium teint',
    '🙆🏾' => 'signalerer ok: medium til mørk teint',
    '🙆🏿' => 'signalerer ok: mørk teint',
    '💁🏻' => 'person vender håndfladen op: lys teint',
    '💁🏼' => 'person vender håndfladen op: medium til lys teint',
    '💁🏽' => 'person vender håndfladen op: medium teint',
    '💁🏾' => 'person vender håndfladen op: medium til mørk teint',
    '💁🏿' => 'person vender håndfladen op: mørk teint',
    '🙋🏻' => 'person med løftet hånd: lys teint',
    '🙋🏼' => 'person med løftet hånd: medium til lys teint',
    '🙋🏽' => 'person med løftet hånd: medium teint',
    '🙋🏾' => 'person med løftet hånd: medium til mørk teint',
    '🙋🏿' => 'person med løftet hånd: mørk teint',
    '🧏🏻' => 'døv person: lys teint',
    '🧏🏼' => 'døv person: medium til lys teint',
    '🧏🏽' => 'døv person: medium teint',
    '🧏🏾' => 'døv person: medium til mørk teint',
    '🧏🏿' => 'døv person: mørk teint',
    '🙇🏻' => 'person bukker dybt: lys teint',
    '🙇🏼' => 'person bukker dybt: medium til lys teint',
    '🙇🏽' => 'person bukker dybt: medium teint',
    '🙇🏾' => 'person bukker dybt: medium til mørk teint',
    '🙇🏿' => 'person bukker dybt: mørk teint',
    '🤦🏻' => 'slå sig for panden: lys teint',
    '🤦🏼' => 'slå sig for panden: medium til lys teint',
    '🤦🏽' => 'slå sig for panden: medium teint',
    '🤦🏾' => 'slå sig for panden: medium til mørk teint',
    '🤦🏿' => 'slå sig for panden: mørk teint',
    '🤷🏻' => 'trækker på skuldrene: lys teint',
    '🤷🏼' => 'trækker på skuldrene: medium til lys teint',
    '🤷🏽' => 'trækker på skuldrene: medium teint',
    '🤷🏾' => 'trækker på skuldrene: medium til mørk teint',
    '🤷🏿' => 'trækker på skuldrene: mørk teint',
    '👮🏻' => 'politibetjent: lys teint',
    '👮🏼' => 'politibetjent: medium til lys teint',
    '👮🏽' => 'politibetjent: medium teint',
    '👮🏾' => 'politibetjent: medium til mørk teint',
    '👮🏿' => 'politibetjent: mørk teint',
    '🕵🏻' => 'detektiv: lys teint',
    '🕵🏼' => 'detektiv: medium til lys teint',
    '🕵🏽' => 'detektiv: medium teint',
    '🕵🏾' => 'detektiv: medium til mørk teint',
    '🕵🏿' => 'detektiv: mørk teint',
    '💂🏻' => 'garder: lys teint',
    '💂🏼' => 'garder: medium til lys teint',
    '💂🏽' => 'garder: medium teint',
    '💂🏾' => 'garder: medium til mørk teint',
    '💂🏿' => 'garder: mørk teint',
    '🥷🏻' => 'ninja: lys teint',
    '🥷🏼' => 'ninja: medium til lys teint',
    '🥷🏽' => 'ninja: medium teint',
    '🥷🏾' => 'ninja: medium til mørk teint',
    '🥷🏿' => 'ninja: mørk teint',
    '👷🏻' => 'bygningsarbejder: lys teint',
    '👷🏼' => 'bygningsarbejder: medium til lys teint',
    '👷🏽' => 'bygningsarbejder: medium teint',
    '👷🏾' => 'bygningsarbejder: medium til mørk teint',
    '👷🏿' => 'bygningsarbejder: mørk teint',
    '🫅🏻' => 'person med krone: lys teint',
    '🫅🏼' => 'person med krone: medium til lys teint',
    '🫅🏽' => 'person med krone: medium teint',
    '🫅🏾' => 'person med krone: medium til mørk teint',
    '🫅🏿' => 'person med krone: mørk teint',
    '🤴🏻' => 'prins: lys teint',
    '🤴🏼' => 'prins: medium til lys teint',
    '🤴🏽' => 'prins: medium teint',
    '🤴🏾' => 'prins: medium til mørk teint',
    '🤴🏿' => 'prins: mørk teint',
    '👸🏻' => 'prinsesse: lys teint',
    '👸🏼' => 'prinsesse: medium til lys teint',
    '👸🏽' => 'prinsesse: medium teint',
    '👸🏾' => 'prinsesse: medium til mørk teint',
    '👸🏿' => 'prinsesse: mørk teint',
    '👳🏻' => 'person med turban: lys teint',
    '👳🏼' => 'person med turban: medium til lys teint',
    '👳🏽' => 'person med turban: medium teint',
    '👳🏾' => 'person med turban: medium til mørk teint',
    '👳🏿' => 'person med turban: mørk teint',
    '👲🏻' => 'mand med kinesisk hat: lys teint',
    '👲🏼' => 'mand med kinesisk hat: medium til lys teint',
    '👲🏽' => 'mand med kinesisk hat: medium teint',
    '👲🏾' => 'mand med kinesisk hat: medium til mørk teint',
    '👲🏿' => 'mand med kinesisk hat: mørk teint',
    '🧕🏻' => 'kvinde med tørklæde: lys teint',
    '🧕🏼' => 'kvinde med tørklæde: medium til lys teint',
    '🧕🏽' => 'kvinde med tørklæde: medium teint',
    '🧕🏾' => 'kvinde med tørklæde: medium til mørk teint',
    '🧕🏿' => 'kvinde med tørklæde: mørk teint',
    '🤵🏻' => 'person i smoking: lys teint',
    '🤵🏼' => 'person i smoking: medium til lys teint',
    '🤵🏽' => 'person i smoking: medium teint',
    '🤵🏾' => 'person i smoking: medium til mørk teint',
    '🤵🏿' => 'person i smoking: mørk teint',
    '👰🏻' => 'person med brudeslør: lys teint',
    '👰🏼' => 'person med brudeslør: medium til lys teint',
    '👰🏽' => 'person med brudeslør: medium teint',
    '👰🏾' => 'person med brudeslør: medium til mørk teint',
    '👰🏿' => 'person med brudeslør: mørk teint',
    '🤰🏻' => 'gravid kvinde: lys teint',
    '🤰🏼' => 'gravid kvinde: medium til lys teint',
    '🤰🏽' => 'gravid kvinde: medium teint',
    '🤰🏾' => 'gravid kvinde: medium til mørk teint',
    '🤰🏿' => 'gravid kvinde: mørk teint',
    '🫃🏻' => 'gravid mand: lys teint',
    '🫃🏼' => 'gravid mand: medium til lys teint',
    '🫃🏽' => 'gravid mand: medium teint',
    '🫃🏾' => 'gravid mand: medium til mørk teint',
    '🫃🏿' => 'gravid mand: mørk teint',
    '🫄🏻' => 'gravid person: lys teint',
    '🫄🏼' => 'gravid person: medium til lys teint',
    '🫄🏽' => 'gravid person: medium teint',
    '🫄🏾' => 'gravid person: medium til mørk teint',
    '🫄🏿' => 'gravid person: mørk teint',
    '🤱🏻' => 'kvinde, der ammer: lys teint',
    '🤱🏼' => 'kvinde, der ammer: medium til lys teint',
    '🤱🏽' => 'kvinde, der ammer: medium teint',
    '🤱🏾' => 'kvinde, der ammer: medium til mørk teint',
    '🤱🏿' => 'kvinde, der ammer: mørk teint',
    '👼🏻' => 'babyengel: lys teint',
    '👼🏼' => 'babyengel: medium til lys teint',
    '👼🏽' => 'babyengel: medium teint',
    '👼🏾' => 'babyengel: medium til mørk teint',
    '👼🏿' => 'babyengel: mørk teint',
    '🎅🏻' => 'julemand: lys teint',
    '🎅🏼' => 'julemand: medium til lys teint',
    '🎅🏽' => 'julemand: medium teint',
    '🎅🏾' => 'julemand: medium til mørk teint',
    '🎅🏿' => 'julemand: mørk teint',
    '🤶🏻' => 'julemandens kone: lys teint',
    '🤶🏼' => 'julemandens kone: medium til lys teint',
    '🤶🏽' => 'julemandens kone: medium teint',
    '🤶🏾' => 'julemandens kone: medium til mørk teint',
    '🤶🏿' => 'julemandens kone: mørk teint',
    '🦸🏻' => 'superhelt: lys teint',
    '🦸🏼' => 'superhelt: medium til lys teint',
    '🦸🏽' => 'superhelt: medium teint',
    '🦸🏾' => 'superhelt: medium til mørk teint',
    '🦸🏿' => 'superhelt: mørk teint',
    '🦹🏻' => 'superskurk: lys teint',
    '🦹🏼' => 'superskurk: medium til lys teint',
    '🦹🏽' => 'superskurk: medium teint',
    '🦹🏾' => 'superskurk: medium til mørk teint',
    '🦹🏿' => 'superskurk: mørk teint',
    '🧙🏻' => 'magiker: lys teint',
    '🧙🏼' => 'magiker: medium til lys teint',
    '🧙🏽' => 'magiker: medium teint',
    '🧙🏾' => 'magiker: medium til mørk teint',
    '🧙🏿' => 'magiker: mørk teint',
    '🧚🏻' => 'fe: lys teint',
    '🧚🏼' => 'fe: medium til lys teint',
    '🧚🏽' => 'fe: medium teint',
    '🧚🏾' => 'fe: medium til mørk teint',
    '🧚🏿' => 'fe: mørk teint',
    '🧛🏻' => 'vampyr: lys teint',
    '🧛🏼' => 'vampyr: medium til lys teint',
    '🧛🏽' => 'vampyr: medium teint',
    '🧛🏾' => 'vampyr: medium til mørk teint',
    '🧛🏿' => 'vampyr: mørk teint',
    '🧜🏻' => 'havvæsen: lys teint',
    '🧜🏼' => 'havvæsen: medium til lys teint',
    '🧜🏽' => 'havvæsen: medium teint',
    '🧜🏾' => 'havvæsen: medium til mørk teint',
    '🧜🏿' => 'havvæsen: mørk teint',
    '🧝🏻' => 'elver: lys teint',
    '🧝🏼' => 'elver: medium til lys teint',
    '🧝🏽' => 'elver: medium teint',
    '🧝🏾' => 'elver: medium til mørk teint',
    '🧝🏿' => 'elver: mørk teint',
    '💆🏻' => 'ansigtsmassage: lys teint',
    '💆🏼' => 'ansigtsmassage: medium til lys teint',
    '💆🏽' => 'ansigtsmassage: medium teint',
    '💆🏾' => 'ansigtsmassage: medium til mørk teint',
    '💆🏿' => 'ansigtsmassage: mørk teint',
    '💇🏻' => 'bliver klippet: lys teint',
    '💇🏼' => 'bliver klippet: medium til lys teint',
    '💇🏽' => 'bliver klippet: medium teint',
    '💇🏾' => 'bliver klippet: medium til mørk teint',
    '💇🏿' => 'bliver klippet: mørk teint',
    '🚶🏻' => 'fodgænger: lys teint',
    '🚶🏼' => 'fodgænger: medium til lys teint',
    '🚶🏽' => 'fodgænger: medium teint',
    '🚶🏾' => 'fodgænger: medium til mørk teint',
    '🚶🏿' => 'fodgænger: mørk teint',
    '🧍🏻' => 'stående person: lys teint',
    '🧍🏼' => 'stående person: medium til lys teint',
    '🧍🏽' => 'stående person: medium teint',
    '🧍🏾' => 'stående person: medium til mørk teint',
    '🧍🏿' => 'stående person: mørk teint',
    '🧎🏻' => 'knælende person: lys teint',
    '🧎🏼' => 'knælende person: medium til lys teint',
    '🧎🏽' => 'knælende person: medium teint',
    '🧎🏾' => 'knælende person: medium til mørk teint',
    '🧎🏿' => 'knælende person: mørk teint',
    '🏃🏻' => 'løber: lys teint',
    '🏃🏼' => 'løber: medium til lys teint',
    '🏃🏽' => 'løber: medium teint',
    '🏃🏾' => 'løber: medium til mørk teint',
    '🏃🏿' => 'løber: mørk teint',
    '💃🏻' => 'danser: lys teint',
    '💃🏼' => 'danser: medium til lys teint',
    '💃🏽' => 'danser: medium teint',
    '💃🏾' => 'danser: medium til mørk teint',
    '💃🏿' => 'danser: mørk teint',
    '🕺🏻' => 'dansende mand: lys teint',
    '🕺🏼' => 'dansende mand: medium til lys teint',
    '🕺🏽' => 'dansende mand: medium teint',
    '🕺🏾' => 'dansende mand: medium til mørk teint',
    '🕺🏿' => 'dansende mand: mørk teint',
    '🕴🏻' => 'svævende forretningsmand: lys teint',
    '🕴🏼' => 'svævende forretningsmand: medium til lys teint',
    '🕴🏽' => 'svævende forretningsmand: medium teint',
    '🕴🏾' => 'svævende forretningsmand: medium til mørk teint',
    '🕴🏿' => 'svævende forretningsmand: mørk teint',
    '👯🏻' => 'personer med kaninører: lys teint',
    '👯🏼' => 'personer med kaninører: medium til lys teint',
    '👯🏽' => 'personer med kaninører: medium teint',
    '👯🏾' => 'personer med kaninører: medium til mørk teint',
    '👯🏿' => 'personer med kaninører: mørk teint',
    '🧖🏻' => 'person i dampbad: lys teint',
    '🧖🏼' => 'person i dampbad: medium til lys teint',
    '🧖🏽' => 'person i dampbad: medium teint',
    '🧖🏾' => 'person i dampbad: medium til mørk teint',
    '🧖🏿' => 'person i dampbad: mørk teint',
    '🧗🏻' => 'bjergbestiger: lys teint',
    '🧗🏼' => 'bjergbestiger: medium til lys teint',
    '🧗🏽' => 'bjergbestiger: medium teint',
    '🧗🏾' => 'bjergbestiger: medium til mørk teint',
    '🧗🏿' => 'bjergbestiger: mørk teint',
    '🏇🏻' => 'hestevæddeløb: lys teint',
    '🏇🏼' => 'hestevæddeløb: medium til lys teint',
    '🏇🏽' => 'hestevæddeløb: medium teint',
    '🏇🏾' => 'hestevæddeløb: medium til mørk teint',
    '🏇🏿' => 'hestevæddeløb: mørk teint',
    '🏂🏻' => 'snowboarder: lys teint',
    '🏂🏼' => 'snowboarder: medium til lys teint',
    '🏂🏽' => 'snowboarder: medium teint',
    '🏂🏾' => 'snowboarder: medium til mørk teint',
    '🏂🏿' => 'snowboarder: mørk teint',
    '🏌🏻' => 'golfspiller: lys teint',
    '🏌🏼' => 'golfspiller: medium til lys teint',
    '🏌🏽' => 'golfspiller: medium teint',
    '🏌🏾' => 'golfspiller: medium til mørk teint',
    '🏌🏿' => 'golfspiller: mørk teint',
    '🏄🏻' => 'surfer: lys teint',
    '🏄🏼' => 'surfer: medium til lys teint',
    '🏄🏽' => 'surfer: medium teint',
    '🏄🏾' => 'surfer: medium til mørk teint',
    '🏄🏿' => 'surfer: mørk teint',
    '🚣🏻' => 'roer: lys teint',
    '🚣🏼' => 'roer: medium til lys teint',
    '🚣🏽' => 'roer: medium teint',
    '🚣🏾' => 'roer: medium til mørk teint',
    '🚣🏿' => 'roer: mørk teint',
    '🏊🏻' => 'svømmer: lys teint',
    '🏊🏼' => 'svømmer: medium til lys teint',
    '🏊🏽' => 'svømmer: medium teint',
    '🏊🏾' => 'svømmer: medium til mørk teint',
    '🏊🏿' => 'svømmer: mørk teint',
    '⛹🏻' => 'person, der dribler med en bold: lys teint',
    '⛹🏼' => 'person, der dribler med en bold: medium til lys teint',
    '⛹🏽' => 'person, der dribler med en bold: medium teint',
    '⛹🏾' => 'person, der dribler med en bold: medium til mørk teint',
    '⛹🏿' => 'person, der dribler med en bold: mørk teint',
    '🏋🏻' => 'vægtløfter: lys teint',
    '🏋🏼' => 'vægtløfter: medium til lys teint',
    '🏋🏽' => 'vægtløfter: medium teint',
    '🏋🏾' => 'vægtløfter: medium til mørk teint',
    '🏋🏿' => 'vægtløfter: mørk teint',
    '🚴🏻' => 'cyklist: lys teint',
    '🚴🏼' => 'cyklist: medium til lys teint',
    '🚴🏽' => 'cyklist: medium teint',
    '🚴🏾' => 'cyklist: medium til mørk teint',
    '🚴🏿' => 'cyklist: mørk teint',
    '🚵🏻' => 'mountainbikerytter: lys teint',
    '🚵🏼' => 'mountainbikerytter: medium til lys teint',
    '🚵🏽' => 'mountainbikerytter: medium teint',
    '🚵🏾' => 'mountainbikerytter: medium til mørk teint',
    '🚵🏿' => 'mountainbikerytter: mørk teint',
    '🤸🏻' => 'person slår vejrmølle: lys teint',
    '🤸🏼' => 'person slår vejrmølle: medium til lys teint',
    '🤸🏽' => 'person slår vejrmølle: medium teint',
    '🤸🏾' => 'person slår vejrmølle: medium til mørk teint',
    '🤸🏿' => 'person slår vejrmølle: mørk teint',
    '🤼🏻' => 'brydere: lys teint',
    '🤼🏼' => 'brydere: medium til lys teint',
    '🤼🏽' => 'brydere: medium teint',
    '🤼🏾' => 'brydere: medium til mørk teint',
    '🤼🏿' => 'brydere: mørk teint',
    '🤽🏻' => 'vandpolospiller: lys teint',
    '🤽🏼' => 'vandpolospiller: medium til lys teint',
    '🤽🏽' => 'vandpolospiller: medium teint',
    '🤽🏾' => 'vandpolospiller: medium til mørk teint',
    '🤽🏿' => 'vandpolospiller: mørk teint',
    '🤾🏻' => 'håndboldspiller: lys teint',
    '🤾🏼' => 'håndboldspiller: medium til lys teint',
    '🤾🏽' => 'håndboldspiller: medium teint',
    '🤾🏾' => 'håndboldspiller: medium til mørk teint',
    '🤾🏿' => 'håndboldspiller: mørk teint',
    '🤹🏻' => 'jonglør: lys teint',
    '🤹🏼' => 'jonglør: medium til lys teint',
    '🤹🏽' => 'jonglør: medium teint',
    '🤹🏾' => 'jonglør: medium til mørk teint',
    '🤹🏿' => 'jonglør: mørk teint',
    '🧘🏻' => 'lotusstilling: lys teint',
    '🧘🏼' => 'lotusstilling: medium til lys teint',
    '🧘🏽' => 'lotusstilling: medium teint',
    '🧘🏾' => 'lotusstilling: medium til mørk teint',
    '🧘🏿' => 'lotusstilling: mørk teint',
    '🛀🏻' => 'bad: lys teint',
    '🛀🏼' => 'bad: medium til lys teint',
    '🛀🏽' => 'bad: medium teint',
    '🛀🏾' => 'bad: medium til mørk teint',
    '🛀🏿' => 'bad: mørk teint',
    '🛌🏻' => 'person i seng: lys teint',
    '🛌🏼' => 'person i seng: medium til lys teint',
    '🛌🏽' => 'person i seng: medium teint',
    '🛌🏾' => 'person i seng: medium til mørk teint',
    '🛌🏿' => 'person i seng: mørk teint',
    '👭🏻' => 'to kvinder hånd i hånd: lys teint',
    '👭🏼' => 'to kvinder hånd i hånd: medium til lys teint',
    '👭🏽' => 'to kvinder hånd i hånd: medium teint',
    '👭🏾' => 'to kvinder hånd i hånd: medium til mørk teint',
    '👭🏿' => 'to kvinder hånd i hånd: mørk teint',
    '👫🏻' => 'mand og kvinde hånd i hånd: lys teint',
    '👫🏼' => 'mand og kvinde hånd i hånd: medium til lys teint',
    '👫🏽' => 'mand og kvinde hånd i hånd: medium teint',
    '👫🏾' => 'mand og kvinde hånd i hånd: medium til mørk teint',
    '👫🏿' => 'mand og kvinde hånd i hånd: mørk teint',
    '👬🏻' => 'to mænd hånd i hånd: lys teint',
    '👬🏼' => 'to mænd hånd i hånd: medium til lys teint',
    '👬🏽' => 'to mænd hånd i hånd: medium teint',
    '👬🏾' => 'to mænd hånd i hånd: medium til mørk teint',
    '👬🏿' => 'to mænd hånd i hånd: mørk teint',
    '💏🏻' => 'kys: lys teint',
    '💏🏼' => 'kys: medium til lys teint',
    '💏🏽' => 'kys: medium teint',
    '💏🏾' => 'kys: medium til mørk teint',
    '💏🏿' => 'kys: mørk teint',
    '💑🏻' => 'par med hjerte: lys teint',
    '💑🏼' => 'par med hjerte: medium til lys teint',
    '💑🏽' => 'par med hjerte: medium teint',
    '💑🏾' => 'par med hjerte: medium til mørk teint',
    '💑🏿' => 'par med hjerte: mørk teint',
    '🏻' => 'lys teint',
    '🏼' => 'medium til lys teint',
    '🏽' => 'medium teint',
    '🏾' => 'medium til mørk teint',
    '🏿' => 'mørk teint',
    '😀' => 'grinende ansigt',
    '😃' => 'grinende ansigt med store øjne',
    '😄' => 'grinende ansigt med smilende øjne',
    '😁' => 'strålende ansigt med smilende øjne',
    '😆' => 'grinende ansigt med lukkede øjne',
    '😅' => 'grinende ansigt med sveddråbe',
    '🤣' => 'ruller rundt på gulvet af grin',
    '😂' => 'ansigt med glædestårer',
    '🙂' => 'let smilende ansigt',
    '🙃' => 'omvendt ansigt',
    '🫠' => 'smeltende ansigt',
    '😉' => 'blinkende ansigt',
    '😊' => 'smilende ansigt og øjne',
    '😇' => 'smilende ansigt med glorie',
    '🥰' => 'smilende ansigt med tre hjerter',
    '😍' => 'smilende ansigt med hjerteøjne',
    '🤩' => 'benovet',
    '😘' => 'kyssende ansigt',
    '😗' => 'kysseansigt',
    '☺' => 'smilende ansigt',
    '😚' => 'kysseansigt med lukkede øjne',
    '😙' => 'kysseansigt med smilende øjne',
    '🥲' => 'smilende ansigt med tåre',
    '😋' => 'nydende ansigt',
    '😛' => 'ansigt med tungen ude',
    '😜' => 'ansigt med tungen ude og blinkende øje',
    '🤪' => 'skørt ansigt',
    '😝' => 'ansigt med tungen ude og sammenknebne øjne',
    '🤑' => 'ansigt med dollartegn',
    '🤗' => 'krammende ansigt',
    '🤭' => 'ansigt med hånd over munden',
    '🫢' => 'ansigt med åbne øjne og hånden over munden',
    '🫣' => 'ansigt, der smugkigger',
    '🤫' => 'tyssende ansigt',
    '🤔' => 'tænkende ansigt',
    '🫡' => 'ansigt, der gør honnør',
    '🤐' => 'ansigt med lynlåsmund',
    '🤨' => 'ansigt med løftet øjenbryn',
    '😐' => 'neutralt ansigt',
    '😑' => 'udtryksløst ansigt',
    '😶' => 'ansigt uden mund',
    '🫥' => 'stiplet linje ansigt',
    '😏' => 'ansigt med smørret grin',
    '😒' => 'uimponeret ansigt',
    '🙄' => 'ansigt med rullende øjne',
    '😬' => 'sammenbidt ansigt',
    '🤥' => 'løgneransigt',
    '🫨' => 'rystende ansigt',
    '😌' => 'lettet ansigt',
    '😔' => 'eftertænksomt ansigt',
    '😪' => 'søvnigt ansigt',
    '🤤' => 'savlende ansigt',
    '😴' => 'sovende ansigt',
    '🫩' => 'ansigt med poser under øjnene',
    '😷' => 'ansigt med mundbind',
    '🤒' => 'ansigt med termometer',
    '🤕' => 'ansigt med bandage',
    '🤢' => 'ansigt med kvalme',
    '🤮' => 'ansigt, der kaster op',
    '🤧' => 'nysende ansigt',
    '🥵' => 'svedende ansigt',
    '🥶' => 'frysende ansigt',
    '🥴' => 'ørt ansigt',
    '😵' => 'svimmelt ansigt',
    '🤯' => 'hoved, der eksploderer',
    '🤠' => 'ansigt med cowboyhat',
    '🥳' => 'festansigt',
    '🥸' => 'maske',
    '😎' => 'smilende ansigt med solbriller',
    '🤓' => 'nørdansigt',
    '🧐' => 'ansigt med monokel',
    '😕' => 'forvirret ansigt',
    '🫤' => 'ansigt med skrå mund',
    '😟' => 'bekymret ansigt',
    '🙁' => 'lidt trist ansigt',
    '☹' => 'trist ansigt',
    '😮' => 'ansigt med åben mund',
    '😯' => 'tavst ansigt',
    '😲' => 'overrasket ansigt',
    '😳' => 'rødmende ansigt',
    '🫪' => 'forvrænget ansigt',
    '🥺' => 'bønfaldende ansigt',
    '🥹' => 'ansigt, der holder tårer tilbage',
    '😦' => 'måbende ansigt med åben mund',
    '😧' => 'forpint ansigt',
    '😨' => 'bange ansigt',
    '😰' => 'ansigt med åben mund og koldsved',
    '😥' => 'skuffet men lettet ansigt',
    '😢' => 'grædende ansigt',
    '😭' => 'stortudende ansigt',
    '😱' => 'skrigende ansigt',
    '😖' => 'forbistret ansigt',
    '😣' => 'stædigt ansigt',
    '😞' => 'skuffet ansigt',
    '😓' => 'ansigt med koldsved',
    '😩' => 'udmattet ansigt',
    '😫' => 'træt ansigt',
    '🥱' => 'gabende ansigt',
    '😤' => 'fnysende ansigt',
    '😡' => 'surt ansigt',
    '😠' => 'vredt ansigt',
    '🤬' => 'ansigt med symboler på munden',
    '😈' => 'glad lilla djævel',
    '👿' => 'sur lilla djævel',
    '💀' => 'kranium',
    '☠' => 'kranium og korslagte knogler',
    '💩' => 'bæ',
    '🤡' => 'klovneansigt',
    '👹' => 'uhyre',
    '👺' => 'ånd',
    '👻' => 'spøgelse',
    '👽' => 'rumvæsen',
    '👾' => 'alien-monster',
    '🤖' => 'robot',
    '😺' => 'smilende kat',
    '😸' => 'grinende kat',
    '😹' => 'kat med glædestårer',
    '😻' => 'glad kat med hjerteøjne',
    '😼' => 'kat med ironisk smil',
    '😽' => 'kyssende kat',
    '🙀' => 'overrasket kat',
    '😿' => 'grædende kat',
    '😾' => 'sur kat',
    '🙈' => 'ikke se',
    '🙉' => 'ikke høre',
    '🙊' => 'ikke tale',
    '💌' => 'kærlighedsbrev',
    '💘' => 'hjerte med pil',
    '💝' => 'hjerte med bånd',
    '💖' => 'hjerte med stjerner',
    '💗' => 'voksende hjerte',
    '💓' => 'bankende hjerte',
    '💞' => 'roterende hjerter',
    '💕' => 'to hjerter',
    '💟' => 'hjertedekoration',
    '❣' => 'hjerte som udråbstegn',
    '💔' => 'knust hjerte',
    '❤' => 'rødt hjerte',
    '🩷' => 'lyserødt hjerte',
    '🧡' => 'orange hjerte',
    '💛' => 'gult hjerte',
    '💚' => 'grønt hjerte',
    '💙' => 'blåt hjerte',
    '🩵' => 'lyseblåt hjerte',
    '💜' => 'violet hjerte',
    '🤎' => 'brunt hjerte',
    '🖤' => 'sort hjerte',
    '🩶' => 'gråt hjerte',
    '🤍' => 'hvidt hjerte',
    '💋' => 'læbeaftryk',
    '💯' => '100 point',
    '💢' => 'vrede',
    '🫯' => 'slagsmålssky',
    '💥' => 'kollision',
    '💫' => 'svimmel',
    '💦' => 'sveddråber',
    '💨' => 'smutter',
    '🕳' => 'hul',
    '💬' => 'taleboble',
    '🗨' => 'taleboble til venstre',
    '🗯' => 'vred taleboble til højre',
    '💭' => 'tankeboble',
    '💤' => 'søvnig',
    '👋' => 'vinker',
    '🤚' => 'løftet håndryg',
    '🖐' => 'hånd med spredte fingre',
    '✋' => 'løftet hånd',
    '🖖' => 'vulcan-hilsen',
    '🫱' => 'hånd til højre',
    '🫲' => 'hånd til venstre',
    '🫳' => 'håndflade nedad',
    '🫴' => 'håndflade opad',
    '🫷' => 'hånd skubber mod venstre',
    '🫸' => 'hånd skubber mod højre',
    '👌' => 'ok-tegn',
    '🤌' => 'samlede fingre',
    '🤏' => 'lidt vist med tommel- og pegefinger',
    '✌' => 'v-tegn',
    '🤞' => 'krydsede fingre',
    '🫰' => 'krydset pegefinger og tommelfinger',
    '🤟' => 'elsker dig-gestus',
    '🤘' => 'djævletegn',
    '🤙' => 'ring til mig-hånd',
    '👈' => 'peger mod venstre',
    '👉' => 'peger mod højre',
    '👆' => 'peger opad',
    '🖕' => 'langefinger',
    '👇' => 'peger nedad',
    '☝' => 'rækker finger op',
    '🫵' => 'peger på seeren',
    '👍' => 'tommelfinger op',
    '👎' => 'tommelfinger ned',
    '✊' => 'løftet knytnæve',
    '👊' => 'knytnæve',
    '🤛' => 'venstrevendt knytnæve',
    '🤜' => 'højrevendt knytnæve',
    '👏' => 'klappende hænder',
    '🙌' => 'løftede hænder',
    '🫶' => 'hjertehænder',
    '👐' => 'åbne hænder',
    '🤲' => 'håndflader samlet og løftet',
    '🤝' => 'håndtryk',
    '🙏' => 'foldede hænder',
    '✍' => 'skrivende hånd',
    '💅' => 'neglelak',
    '🤳' => 'selfie',
    '💪' => 'armmuskler',
    '🦾' => 'mekanisk arm',
    '🦿' => 'mekanisk ben',
    '🦵' => 'ben',
    '🦶' => 'fod',
    '👂' => 'øre',
    '🦻' => 'øre med høreapparat',
    '👃' => 'næse',
    '🧠' => 'hjerne',
    '🫀' => 'hjerte',
    '🫁' => 'lunger',
    '🦷' => 'tand',
    '🦴' => 'knogle',
    '👀' => 'øjne',
    '👁' => 'øje',
    '👅' => 'tunge',
    '👄' => 'mund',
    '🫦' => 'bider i læben',
    '👶' => 'baby',
    '🧒' => 'barn',
    '👦' => 'dreng',
    '👧' => 'pige',
    '🧑' => 'voksen',
    '👱' => 'blond person',
    '👨' => 'mand',
    '🧔' => 'person med skæg',
    '👩' => 'kvinde',
    '🧓' => 'ældre menneske',
    '👴' => 'gammel mand',
    '👵' => 'gammel kvinde',
    '🙍' => 'Utilfreds person',
    '🙎' => 'surmulende person',
    '🙅' => 'signalerer nej',
    '🙆' => 'signalerer ok',
    '💁' => 'person vender håndfladen op',
    '🙋' => 'person med løftet hånd',
    '🧏' => 'døv person',
    '🙇' => 'person bukker dybt',
    '🤦' => 'slå sig for panden',
    '🤷' => 'trækker på skuldrene',
    '👮' => 'politibetjent',
    '🕵' => 'detektiv',
    '💂' => 'garder',
    '🥷' => 'ninja',
    '👷' => 'bygningsarbejder',
    '🫅' => 'person med krone',
    '🤴' => 'prins',
    '👸' => 'prinsesse',
    '👳' => 'person med turban',
    '👲' => 'mand med kinesisk hat',
    '🧕' => 'kvinde med tørklæde',
    '🤵' => 'person i smoking',
    '👰' => 'person med brudeslør',
    '🤰' => 'gravid kvinde',
    '🫃' => 'gravid mand',
    '🫄' => 'gravid person',
    '🤱' => 'kvinde, der ammer',
    '👼' => 'babyengel',
    '🎅' => 'julemand',
    '🤶' => 'julemandens kone',
    '🦸' => 'superhelt',
    '🦹' => 'superskurk',
    '🧙' => 'magiker',
    '🧚' => 'fe',
    '🧛' => 'vampyr',
    '🧜' => 'havvæsen',
    '🧝' => 'elver',
    '🧞' => 'magisk ånd',
    '🧟' => 'zombie',
    '🧌' => 'trold',
    '🫈' => 'behåret væsen',
    '💆' => 'ansigtsmassage',
    '💇' => 'bliver klippet',
    '🚶' => 'fodgænger',
    '🧍' => 'stående person',
    '🧎' => 'knælende person',
    '🏃' => 'løber',
    '💃' => 'danser',
    '🕺' => 'dansende mand',
    '🕴' => 'svævende forretningsmand',
    '👯' => 'personer med kaninører',
    '🧖' => 'person i dampbad',
    '🧗' => 'bjergbestiger',
    '🤺' => 'fægter',
    '🏇' => 'hestevæddeløb',
    '⛷' => 'skiløber',
    '🏂' => 'snowboarder',
    '🏌' => 'golfspiller',
    '🏄' => 'surfer',
    '🚣' => 'roer',
    '🏊' => 'svømmer',
    '⛹' => 'person, der dribler med en bold',
    '🏋' => 'vægtløfter',
    '🚴' => 'cyklist',
    '🚵' => 'mountainbikerytter',
    '🤸' => 'person slår vejrmølle',
    '🤼' => 'brydere',
    '🤽' => 'vandpolospiller',
    '🤾' => 'håndboldspiller',
    '🤹' => 'jonglør',
    '🧘' => 'lotusstilling',
    '🛀' => 'bad',
    '🛌' => 'person i seng',
    '👭' => 'to kvinder hånd i hånd',
    '👫' => 'mand og kvinde hånd i hånd',
    '👬' => 'to mænd hånd i hånd',
    '💏' => 'kys',
    '💑' => 'par med hjerte',
    '🗣' => 'talende hoved',
    '👤' => 'buste i silhuet',
    '👥' => 'buster i silhuet',
    '🫂' => 'knus',
    '👪' => 'familie',
    '👣' => 'fodspor',
    '🫆' => 'fingeraftryk',
    '🦰' => 'rødt hår',
    '🦱' => 'krøllet hår',
    '🦳' => 'hvidt hår',
    '🦲' => 'skaldet',
    '🐵' => 'abehoved',
    '🐒' => 'abe',
    '🦍' => 'gorilla',
    '🦧' => 'orangutang',
    '🐶' => 'hundehoved',
    '🐕' => 'hund',
    '🦮' => 'førerhund',
    '🐩' => 'puddel',
    '🐺' => 'ulvehoved',
    '🦊' => 'rævehoved',
    '🦝' => 'vaskebjørn',
    '🐱' => 'kattehoved',
    '🐈' => 'kat',
    '🦁' => 'løvehoved',
    '🐯' => 'tigerhoved',
    '🐅' => 'tiger',
    '🐆' => 'leopard',
    '🐴' => 'hestehoved',
    '🫎' => 'elg',
    '🫏' => 'æsel',
    '🐎' => 'hest',
    '🦄' => 'enhjørningehoved',
    '🦓' => 'zebra',
    '🦌' => 'hjort',
    '🦬' => 'bison',
    '🐮' => 'kohoved',
    '🐂' => 'okse',
    '🐃' => 'vandbøffel',
    '🐄' => 'ko',
    '🐷' => 'grisehoved',
    '🐖' => 'gris',
    '🐗' => 'vildsvin',
    '🐽' => 'grisetryne',
    '🐏' => 'vædder',
    '🐑' => 'får',
    '🐐' => 'ged',
    '🐪' => 'dromedar',
    '🐫' => 'kamel',
    '🦙' => 'lama',
    '🦒' => 'giraf',
    '🐘' => 'elefant',
    '🦣' => 'mammut',
    '🦏' => 'næsehorn',
    '🦛' => 'flodhest',
    '🐭' => 'musehoved',
    '🐁' => 'mus',
    '🐀' => 'rotte',
    '🐹' => 'hamsterhoved',
    '🐰' => 'kaninhoved',
    '🐇' => 'kanin',
    '🐿' => 'jordegern',
    '🦫' => 'bæver',
    '🦔' => 'pindsvin',
    '🦇' => 'flagermus',
    '🐻' => 'bjørnehoved',
    '🐨' => 'koala',
    '🐼' => 'pandahoved',
    '🦥' => 'dovendyr',
    '🦦' => 'odder',
    '🦨' => 'stinkdyr',
    '🦘' => 'kænguru',
    '🦡' => 'grævling',
    '🐾' => 'poteaftryk',
    '🦃' => 'kalkun',
    '🐔' => 'høne',
    '🐓' => 'hane',
    '🐣' => 'nyudklækket kylling',
    '🐤' => 'kylling',
    '🐥' => 'kylling forfra',
    '🐦' => 'fugl',
    '🐧' => 'pingvin',
    '🕊' => 'due',
    '🦅' => 'ørn',
    '🦆' => 'and',
    '🦢' => 'svane',
    '🦉' => 'ugle',
    '🦤' => 'dronte',
    '🪶' => 'fjer',
    '🦩' => 'flamingo',
    '🦚' => 'påfugl',
    '🦜' => 'papegøje',
    '🪽' => 'vinge',
    '🪿' => 'gås',
    '🐸' => 'frø',
    '🐊' => 'krokodille',
    '🐢' => 'skildpadde',
    '🦎' => 'firben',
    '🐍' => 'slange',
    '🐲' => 'dragehoved',
    '🐉' => 'drage',
    '🦕' => 'sauropod',
    '🦖' => 'T-Rex',
    '🐳' => 'hval med vandsprøjt',
    '🐋' => 'hval',
    '🐬' => 'delfin',
    '🫍' => 'spækhugger',
    '🦭' => 'sæl',
    '🐟' => 'fisk',
    '🐠' => 'tropisk fisk',
    '🐡' => 'kuglefisk',
    '🦈' => 'haj',
    '🐙' => 'blæksprutte',
    '🐚' => 'konkylie',
    '🪸' => 'koral',
    '🪼' => 'gople',
    '🦀' => 'krabbe',
    '🦞' => 'hummer',
    '🦐' => 'reje',
    '🦑' => 'sprutte',
    '🦪' => 'østers',
    '🐌' => 'snegl',
    '🦋' => 'sommerfugl',
    '🐛' => 'larve',
    '🐜' => 'myre',
    '🐝' => 'honningbi',
    '🪲' => 'bille',
    '🐞' => 'mariehøne',
    '🦗' => 'fårekylling',
    '🪳' => 'kakerlak',
    '🕷' => 'edderkop',
    '🕸' => 'edderkoppespind',
    '🦂' => 'skorpion',
    '🦟' => 'myg',
    '🪰' => 'flue',
    '🪱' => 'orm',
    '🦠' => 'mikrobe',
    '💐' => 'blomsterbuket',
    '🌸' => 'kirsebærblomst',
    '💮' => 'hvid blomst',
    '🪷' => 'lotus',
    '🏵' => 'roset',
    '🌹' => 'rose',
    '🥀' => 'vissen blomst',
    '🌺' => 'hibiscus',
    '🌻' => 'solsikke',
    '🌼' => 'blomst',
    '🌷' => 'tulipan',
    '🪻' => 'hyacint',
    '🌱' => 'spire',
    '🪴' => 'potteplante',
    '🌲' => 'nåletræ',
    '🌳' => 'løvtræ',
    '🌴' => 'palme',
    '🌵' => 'kaktus',
    '🌾' => 'risplante',
    '🌿' => 'urt',
    '☘' => 'kløver',
    '🍀' => 'firkløver',
    '🍁' => 'ahornblad',
    '🍂' => 'faldende blade',
    '🍃' => 'blade i vinden',
    '🪹' => 'tom rede',
    '🪺' => 'rede med æg',
    '🍄' => 'svamp',
    '🪾' => 'træ uden blade',
    '🍇' => 'vindruer',
    '🍈' => 'melon',
    '🍉' => 'vandmelon',
    '🍊' => 'appelsin',
    '🍋' => 'citron',
    '🍌' => 'banan',
    '🍍' => 'ananas',
    '🥭' => 'mango',
    '🍎' => 'rødt æble',
    '🍏' => 'grønt æble',
    '🍐' => 'pære',
    '🍑' => 'fersken',
    '🍒' => 'kirsebær',
    '🍓' => 'jordbær',
    '🫐' => 'blåbær',
    '🥝' => 'kiwifrugt',
    '🍅' => 'tomat',
    '🫒' => 'oliven',
    '🥥' => 'kokosnød',
    '🥑' => 'avokado',
    '🍆' => 'aubergine',
    '🥔' => 'kartoffel',
    '🥕' => 'gulerod',
    '🌽' => 'majs',
    '🌶' => 'chili',
    '🫑' => 'peberfrugt',
    '🥒' => 'agurk',
    '🥬' => 'bladgrønt',
    '🥦' => 'broccoli',
    '🧄' => 'hvidløg',
    '🧅' => 'løg',
    '🥜' => 'jordnødder',
    '🫘' => 'bønner',
    '🌰' => 'kastanje',
    '🫚' => 'ingefærrod',
    '🫛' => 'ærtebælg',
    '🫜' => 'rodfrugt',
    '🍞' => 'brød',
    '🥐' => 'croissant',
    '🥖' => 'flute',
    '🫓' => 'fladbrød',
    '🥨' => 'kringle',
    '🥯' => 'bagel',
    '🥞' => 'pandekager',
    '🧇' => 'vaffel',
    '🧀' => 'et stykke ost',
    '🍖' => 'kød',
    '🍗' => 'kyllingelår',
    '🥩' => 'kødudskæring',
    '🥓' => 'bacon',
    '🍔' => 'hamburger',
    '🍟' => 'pomfritter',
    '🍕' => 'pizza',
    '🌭' => 'hotdog',
    '🥪' => 'sandwich',
    '🌮' => 'taco',
    '🌯' => 'burrito',
    '🫔' => 'tamales',
    '🥙' => 'fyldt pitabrød',
    '🧆' => 'falafel',
    '🥚' => 'æg',
    '🍳' => 'stegepande',
    '🥘' => 'pande med mad',
    '🍲' => 'gryde med mad',
    '🫕' => 'fondue',
    '🥣' => 'ske i skål',
    '🥗' => 'grøn salat',
    '🍿' => 'popcorn',
    '🧈' => 'smør',
    '🧂' => 'salt',
    '🥫' => 'konserves',
    '🍱' => 'bento',
    '🍘' => 'riskiks',
    '🍙' => 'riskugle',
    '🍚' => 'ris',
    '🍛' => 'ris og karry',
    '🍜' => 'nudler',
    '🍝' => 'spaghetti',
    '🍠' => 'sød kartoffel',
    '🍢' => 'mad på spyd',
    '🍣' => 'sushi',
    '🍤' => 'dybstegt reje',
    '🍥' => 'fiskekage',
    '🥮' => 'månekage',
    '🍡' => 'dango',
    '🥟' => 'dumpling',
    '🥠' => 'lykkekage',
    '🥡' => 'kinesisk takeaway',
    '🍦' => 'softice',
    '🍧' => 'isdessert',
    '🍨' => 'is',
    '🍩' => 'donut',
    '🍪' => 'småkage',
    '🎂' => 'fødselsdagskage',
    '🍰' => 'lagkage',
    '🧁' => 'cupcake',
    '🥧' => 'tærte',
    '🍫' => 'chokolade',
    '🍬' => 'bolsje',
    '🍭' => 'slikkepind',
    '🍮' => 'dessert',
    '🍯' => 'honning',
    '🍼' => 'sutteflaske',
    '🥛' => 'glas mælk',
    '☕' => 'varm drik',
    '🫖' => 'tekande',
    '🍵' => 'tekrus',
    '🍶' => 'sake',
    '🍾' => 'flaske med flyvende prop',
    '🍷' => 'vinglas',
    '🍸' => 'cocktailglas',
    '🍹' => 'tropisk drink',
    '🍺' => 'ølkrus',
    '🍻' => 'skålende ølkrus',
    '🥂' => 'skål',
    '🥃' => 'fladbundet glas',
    '🫗' => 'hælde vand',
    '🥤' => 'bæger med sugerør',
    '🧋' => 'bubble tea',
    '🧃' => 'brik',
    '🧉' => 'mate',
    '🧊' => 'isterning',
    '🥢' => 'spisepinde',
    '🍽' => 'kniv og gaffel med tallerken',
    '🍴' => 'kniv og gaffel',
    '🥄' => 'ske',
    '🔪' => 'køkkenkniv',
    '🫙' => 'krukke',
    '🏺' => 'amfora',
    '🌍' => 'globus med Europa og Afrika',
    '🌎' => 'globus med Nord- og Sydamerika',
    '🌏' => 'globus med Asien og Australien',
    '🌐' => 'globus med meridianer',
    '🗺' => 'verdenskort',
    '🗾' => 'kort over Japan',
    '🧭' => 'kompas',
    '🏔' => 'sneklædt bjerg',
    '⛰' => 'bjerg',
    '🛘' => 'jordskred',
    '🌋' => 'vulkan',
    '🗻' => 'Fuji-bjerget',
    '🏕' => 'camping',
    '🏖' => 'strand med parasol',
    '🏜' => 'ørken',
    '🏝' => 'øde ø',
    '🏞' => 'nationalpark',
    '🏟' => 'stadion',
    '🏛' => 'klassisk bygning',
    '🏗' => 'byggeplads',
    '🧱' => 'mursten',
    '🪨' => 'sten',
    '🪵' => 'træ',
    '🛖' => 'hytte',
    '🏘' => 'huse',
    '🏚' => 'faldefærdigt hus',
    '🏠' => 'hus',
    '🏡' => 'hus med have',
    '🏢' => 'kontorbygning',
    '🏣' => 'japansk posthus',
    '🏤' => 'posthus',
    '🏥' => 'hospital',
    '🏦' => 'bank',
    '🏨' => 'hotel',
    '🏩' => 'kærlighedshotel',
    '🏪' => 'døgnkiosk',
    '🏫' => 'skole',
    '🏬' => 'stormagasin',
    '🏭' => 'fabrik',
    '🏯' => 'japansk slot',
    '🏰' => 'slot',
    '💒' => 'bryllup',
    '🗼' => 'Tokyo Tower',
    '🗽' => 'Frihedsgudinden',
    '⛪' => 'kirke',
    '🕌' => 'moské',
    '🛕' => 'hindutempel',
    '🕍' => 'synagoge',
    '⛩' => 'Shinto-helligdom',
    '🕋' => 'Kabaen',
    '⛲' => 'springvand',
    '⛺' => 'telt',
    '🌁' => 'tåget',
    '🌃' => 'stjernehimmel',
    '🏙' => 'bylandskab',
    '🌄' => 'solopgang over bjerge',
    '🌅' => 'solopgang',
    '🌆' => 'by i solnedgang',
    '🌇' => 'solnedgang',
    '🌉' => 'bro i mørke',
    '♨' => 'varme kilder',
    '🎠' => 'karrusel',
    '🛝' => 'legeplads-rutsjebane',
    '🎡' => 'pariserhjul',
    '🎢' => 'rutsjebane',
    '💈' => 'barber',
    '🎪' => 'cirkus',
    '🚂' => 'lokomotiv',
    '🚃' => 'togvogn',
    '🚄' => 'lyntog',
    '🚅' => 'højhastighedstog',
    '🚆' => 'tog',
    '🚇' => 'metro',
    '🚈' => 'letbane',
    '🚉' => 'togstation',
    '🚊' => 'sporvogn',
    '🚝' => 'monorail',
    '🚞' => 'bjergbane',
    '🚋' => 'vogn',
    '🚌' => 'bus',
    '🚍' => 'bus forfra',
    '🚎' => 'trolleybus',
    '🚐' => 'minibus',
    '🚑' => 'ambulance',
    '🚒' => 'brandbil',
    '🚓' => 'politibil',
    '🚔' => 'politibil forfra',
    '🚕' => 'taxa',
    '🚖' => 'taxa forfra',
    '🚗' => 'bil',
    '🚘' => 'bil forfra',
    '🚙' => 'firehjulstrækker',
    '🛻' => 'pickup',
    '🚚' => 'lastbil',
    '🚛' => 'lastvogn',
    '🚜' => 'traktor',
    '🏎' => 'racerbil',
    '🏍' => 'motorcykel',
    '🛵' => 'scooter',
    '🦽' => 'manuel kørestol',
    '🦼' => 'elektrisk kørestol',
    '🛺' => 'motor-rickshaw',
    '🚲' => 'cykel',
    '🛴' => 'løbehjul',
    '🛹' => 'skateboard',
    '🛼' => 'rulleskøjte',
    '🚏' => 'busstoppested',
    '🛣' => 'motorvej',
    '🛤' => 'jernbane',
    '🛢' => 'olietønde',
    '⛽' => 'tankstation',
    '🛞' => 'hjul',
    '🚨' => 'politiblink',
    '🚥' => 'liggende trafiklys',
    '🚦' => 'trafiklys',
    '🛑' => 'stopskilt',
    '🚧' => 'byggeri',
    '⚓' => 'anker',
    '🛟' => 'redningskrans',
    '⛵' => 'sejlbåd',
    '🛶' => 'kano',
    '🚤' => 'speedbåd',
    '🛳' => 'passagerskib',
    '⛴' => 'færge',
    '🛥' => 'motorbåd',
    '🚢' => 'skib',
    '✈' => 'fly',
    '🛩' => 'lille fly',
    '🛫' => 'flyafgang',
    '🛬' => 'flyankomst',
    '🪂' => 'faldskærm',
    '💺' => 'sæde',
    '🚁' => 'helikopter',
    '🚟' => 'luftbane',
    '🚠' => 'kabelbane',
    '🚡' => 'svævebane',
    '🛰' => 'satellit',
    '🚀' => 'raket',
    '🛸' => 'ufo',
    '🛎' => 'hotelklokke',
    '🧳' => 'bagage',
    '⌛' => 'udløbet timeglas',
    '⏳' => 'timeglas med løbende sand',
    '⌚' => 'ur',
    '⏰' => 'vækkeur',
    '⏱' => 'stopur',
    '⏲' => 'æggeur',
    '🕰' => 'pynteur',
    '🕛' => 'kl. tolv',
    '🕧' => 'halv et',
    '🕐' => 'kl. et',
    '🕜' => 'halv to',
    '🕑' => 'kl. to',
    '🕝' => 'halv tre',
    '🕒' => 'kl. tre',
    '🕞' => 'halv fire',
    '🕓' => 'kl. fire',
    '🕟' => 'halv fem',
    '🕔' => 'kl. fem',
    '🕠' => 'halv seks',
    '🕕' => 'kl. seks',
    '🕡' => 'halv syv',
    '🕖' => 'kl. syv',
    '🕢' => 'halv otte',
    '🕗' => 'kl. otte',
    '🕣' => 'halv ni',
    '🕘' => 'kl. ni',
    '🕤' => 'halv ti',
    '🕙' => 'kl. ti',
    '🕥' => 'halv elleve',
    '🕚' => 'kl. elleve',
    '🕦' => 'halv tolv',
    '🌑' => 'nymåne',
    '🌒' => 'tiltagende måne',
    '🌓' => 'halvmåne 1. fjerdedel',
    '🌔' => 'tiltagende måne næsten fuld',
    '🌕' => 'fuldmåne',
    '🌖' => 'aftagende måne næsten fuld',
    '🌗' => 'halvmåne 4. fjerdedel',
    '🌘' => 'aftagende måne',
    '🌙' => 'halvmåne',
    '🌚' => 'nymåne med ansigt',
    '🌛' => 'måne med ansigt 1. fjerdedel',
    '🌜' => 'måne med ansigt 4. fjerdedel',
    '🌡' => 'termometer',
    '☀' => 'sol',
    '🌝' => 'fuldmåne med ansigt',
    '🌞' => 'sol med ansigt',
    '🪐' => 'planet med ringe',
    '⭐' => 'stjerne',
    '🌟' => 'blinkende stjerne',
    '🌠' => 'stjerneskud',
    '🌌' => 'mælkevejen',
    '☁' => 'sky',
    '⛅' => 'sol bag sky',
    '⛈' => 'sky med lyn og regn',
    '🌤' => 'sol bag lille sky',
    '🌥' => 'sol bag stor sky',
    '🌦' => 'sol bag sky med regn',
    '🌧' => 'sky med regn',
    '🌨' => 'sky med sne',
    '🌩' => 'tordensky',
    '🌪' => 'tornado',
    '🌫' => 'tåge',
    '🌬' => 'vindansigt',
    '🌀' => 'cyklon',
    '🌈' => 'regnbue',
    '🌂' => 'lukket paraply',
    '☂' => 'paraply',
    '☔' => 'paraply med regndråber',
    '⛱' => 'parasol',
    '⚡' => 'højspænding',
    '❄' => 'snefnug',
    '☃' => 'snemand',
    '⛄' => 'snemand uden snevejr',
    '☄' => 'komet',
    '🔥' => 'ild',
    '💧' => 'dråbe',
    '🌊' => 'bølge',
    '🎃' => 'græskarmand',
    '🎄' => 'juletræ',
    '🎆' => 'fyrværkeri',
    '🎇' => 'stjernekaster',
    '🧨' => 'kanonslag',
    '✨' => 'stjerner',
    '🎈' => 'ballon',
    '🎉' => 'bordbombe',
    '🎊' => 'konfetti',
    '🎋' => 'træ med papirpynt',
    '🎍' => 'fyrretræsdekoration',
    '🎎' => 'japanske dukker',
    '🎏' => 'karpevimpel',
    '🎐' => 'vindspil',
    '🎑' => 'måneceremoni',
    '🧧' => 'pengegave',
    '🎀' => 'sløjfe',
    '🎁' => 'gave',
    '🎗' => 'mindebånd',
    '🎟' => 'adgangsbillet',
    '🎫' => 'billet',
    '🎖' => 'militærmedalje',
    '🏆' => 'pokal',
    '🏅' => 'sportsmedalje',
    '🥇' => 'guldmedalje',
    '🥈' => 'sølvmedalje',
    '🥉' => 'bronzemedalje',
    '⚽' => 'fodbold',
    '⚾' => 'baseball',
    '🥎' => 'softball',
    '🏀' => 'basketball',
    '🏐' => 'volleyball',
    '🏈' => 'amerikansk fodbold',
    '🏉' => 'rugbybold',
    '🎾' => 'tennis',
    '🥏' => 'frisbee',
    '🎳' => 'bowling',
    '🏏' => 'cricket',
    '🏑' => 'hockey',
    '🏒' => 'ishockey',
    '🥍' => 'lacrosse',
    '🏓' => 'bordtennis',
    '🏸' => 'badminton',
    '🥊' => 'boksehandske',
    '🥋' => 'karatedragt',
    '🥅' => 'målnet',
    '⛳' => 'golfhul med flag',
    '⛸' => 'skøjte',
    '🎣' => 'fiskestang',
    '🤿' => 'dykkermaske',
    '🎽' => 'løbetrøje',
    '🎿' => 'ski',
    '🛷' => 'kælk',
    '🥌' => 'curlingsten',
    '🎯' => 'pletskud',
    '🪀' => 'yoyo',
    '🪁' => 'legetøjsdrage',
    '🔫' => 'vandpistol',
    '🎱' => 'billard',
    '🔮' => 'krystalkugle',
    '🪄' => 'tryllestav',
    '🎮' => 'videospil',
    '🕹' => 'joystick',
    '🎰' => 'spillemaskine',
    '🎲' => 'terning',
    '🧩' => 'brik til puslespil',
    '🧸' => 'bamse',
    '🪅' => 'piñata',
    '🪩' => 'diskokugle',
    '🪆' => 'russiske dukker',
    '♠' => 'spar',
    '♥' => 'hjerter',
    '♦' => 'ruder',
    '♣' => 'klør',
    '♟' => 'skakbrik',
    '🃏' => 'joker',
    '🀄' => 'mahjong-brik',
    '🎴' => 'spillekort med blomster',
    '🎭' => 'masker',
    '🖼' => 'ramme med billede',
    '🎨' => 'palet',
    '🧵' => 'tråd',
    '🪡' => 'synål',
    '🧶' => 'garn',
    '🪢' => 'knude',
    '👓' => 'briller',
    '🕶' => 'solbriller',
    '🥽' => 'sikkerhedsbriller',
    '🥼' => 'kittel',
    '🦺' => 'sikkerhedsvest',
    '👔' => 'slips',
    '👕' => 'T-shirt',
    '👖' => 'bukser',
    '🧣' => 'halstørklæde',
    '🧤' => 'handsker',
    '🧥' => 'frakke',
    '🧦' => 'sokker',
    '👗' => 'kjole',
    '👘' => 'kimono',
    '🥻' => 'sari',
    '🩱' => 'badedragt',
    '🩲' => 'badebukser',
    '🩳' => 'shorts',
    '👙' => 'bikini',
    '👚' => 'bluse',
    '🪭' => 'sammenklappelig håndvifte',
    '👛' => 'pung',
    '👜' => 'håndtaske',
    '👝' => 'clutch',
    '🛍' => 'indkøbsposer',
    '🎒' => 'rygsæk',
    '🩴' => 'klipklapper',
    '👞' => 'herresko',
    '👟' => 'løbesko',
    '🥾' => 'vandrestøvle',
    '🥿' => 'flad sko',
    '👠' => 'høje hæle',
    '👡' => 'damesandal',
    '🩰' => 'balletsko',
    '👢' => 'damestøvle',
    '🪮' => 'afrokam',
    '👑' => 'krone',
    '👒' => 'hat',
    '🎩' => 'høj hat',
    '🎓' => 'eksamenshat',
    '🧢' => 'kasket',
    '🪖' => 'militærhjelm',
    '⛑' => 'hjelm med hvidt kors',
    '📿' => 'bedekrans',
    '💄' => 'læbestift',
    '💍' => 'ring',
    '💎' => 'ædelsten',
    '🔇' => 'højttaler fra',
    '🔈' => 'højttaler lav lydstyrke',
    '🔉' => 'højttaler mellem lydstyrke',
    '🔊' => 'højttaler høj lydstyrke',
    '📢' => 'elektrisk megafon',
    '📣' => 'megafon',
    '📯' => 'posthorn',
    '🔔' => 'klokke',
    '🔕' => 'ingen klokke',
    '🎼' => 'partitur',
    '🎵' => 'node',
    '🎶' => 'noder',
    '🎙' => 'studiemikrofon',
    '🎚' => 'volumenkontrol',
    '🎛' => 'knapper',
    '🎤' => 'mikrofon',
    '🎧' => 'hovedtelefon',
    '📻' => 'radio',
    '🎷' => 'saxofon',
    '🎺' => 'trompet',
    '🪊' => 'basun',
    '🪗' => 'akkordeon',
    '🎸' => 'guitar',
    '🎹' => 'klaver',
    '🎻' => 'violin',
    '🪕' => 'banjo',
    '🥁' => 'tromme',
    '🪘' => 'høj tromme',
    '🪇' => 'maracas',
    '🪈' => 'fløjte',
    '🪉' => 'harpe',
    '📱' => 'mobil',
    '📲' => 'mobil med pil',
    '☎' => 'telefon',
    '📞' => 'telefonrør',
    '📟' => 'personsøger',
    '📠' => 'fax',
    '🔋' => 'batteri',
    '🪫' => 'lavt batteriniveau',
    '🔌' => 'stik',
    '💻' => 'bærbar computer',
    '🖥' => 'stationær computer',
    '🖨' => 'printer',
    '⌨' => 'tastatur',
    '🖱' => 'computermus',
    '🖲' => 'trackball',
    '💽' => 'cd-rom',
    '💾' => 'diskette',
    '💿' => 'cd',
    '📀' => 'dvd',
    '🧮' => 'kugleramme',
    '🎥' => 'filmkamera',
    '🎞' => 'filmstrimmel',
    '📽' => 'filmprojektor',
    '🎬' => 'klaptræ',
    '📺' => 'tv',
    '📷' => 'kamera',
    '📸' => 'kamera med blitz',
    '📹' => 'videokamera',
    '📼' => 'videobånd',
    '🔍' => 'forstørrelsesglas til venstre',
    '🔎' => 'forstørrelsesglas til højre',
    '🕯' => 'stearinlys',
    '💡' => 'elpære',
    '🔦' => 'lommelygte',
    '🏮' => 'papirlanterne',
    '🪔' => 'diya-lampe',
    '📔' => 'notesbog med udsmykning',
    '📕' => 'lukket bog',
    '📖' => 'åben bog',
    '📗' => 'grøn bog',
    '📘' => 'blå bog',
    '📙' => 'orange bog',
    '📚' => 'bøger',
    '📓' => 'notesbog',
    '📒' => 'regnskabsbog',
    '📃' => 'side med fold',
    '📜' => 'skriftrulle',
    '📄' => 'dokument',
    '📰' => 'avis',
    '🗞' => 'sammenrullet avis',
    '📑' => 'faner',
    '🔖' => 'bogmærke',
    '🏷' => 'mærkat',
    '🪙' => 'mønt',
    '💰' => 'pengepose',
    '🪎' => 'skattekiste',
    '💴' => 'yenseddel',
    '💵' => 'dollarseddel',
    '💶' => 'euroseddel',
    '💷' => 'pundseddel',
    '💸' => 'flyvende penge',
    '💳' => 'kreditkort',
    '🧾' => 'kvittering',
    '💹' => 'stigende marked',
    '✉' => 'konvolut',
    '📧' => 'mail',
    '📨' => 'indgående post',
    '📩' => 'udgående post',
    '📤' => 'udbakke',
    '📥' => 'indbakke',
    '📦' => 'pakke',
    '📫' => 'lukket postkasse med hævet flag',
    '📪' => 'lukket postkasse med sænket flag',
    '📬' => 'åben postkasse med hævet flag',
    '📭' => 'åben postkasse med sænket flag',
    '📮' => 'postkasse',
    '🗳' => 'valgurne med stemmeseddel',
    '✏' => 'blyant',
    '✒' => 'sort fyldepen',
    '🖋' => 'fyldepen',
    '🖊' => 'kuglepen',
    '🖌' => 'malerpensel',
    '🖍' => 'farvekridt',
    '📝' => 'notat',
    '💼' => 'attachémappe',
    '📁' => 'mappe',
    '📂' => 'åben mappe',
    '🗂' => 'kartotekskort',
    '📅' => 'kalender',
    '📆' => 'kalenderblok',
    '🗒' => 'notesblok',
    '🗓' => 'spiralkalender',
    '📇' => 'kartotek',
    '📈' => 'opadgående graf',
    '📉' => 'nedadgående graf',
    '📊' => 'søjlediagram',
    '📋' => 'clipboard',
    '📌' => 'tegnestift',
    '📍' => 'rund tegnestift',
    '📎' => 'papirclips',
    '🖇' => 'sammensatte papirclips',
    '📏' => 'lineal',
    '📐' => 'tegnetrekant',
    '✂' => 'saks',
    '🗃' => 'arkivkasse',
    '🗄' => 'arkivskab',
    '🗑' => 'papirkurv',
    '🔒' => 'lukket hængelås',
    '🔓' => 'åben hængelås',
    '🔏' => 'lukket hængelås med pen',
    '🔐' => 'lukket hængelås med nøgle',
    '🔑' => 'nøgle',
    '🗝' => 'gammel nøgle',
    '🔨' => 'hammer',
    '🪓' => 'økse',
    '⛏' => 'hakke',
    '⚒' => 'hammer og hakke',
    '🛠' => 'hammer og skruenøgle',
    '🗡' => 'dolk',
    '⚔' => 'korslagte sværd',
    '💣' => 'bombe',
    '🪃' => 'boomerang',
    '🏹' => 'bue og pil',
    '🛡' => 'skjold',
    '🪚' => 'sav',
    '🔧' => 'skruenøgle',
    '🪛' => 'skruetrækker',
    '🔩' => 'møtrik og bolt',
    '⚙' => 'tandhjul',
    '🗜' => 'skruetvinge',
    '⚖' => 'vægt',
    '🦯' => 'blindestok',
    '🔗' => 'link',
    '⛓' => 'kæder',
    '🪝' => 'krog',
    '🧰' => 'værktøjskasse',
    '🧲' => 'magnet',
    '🪜' => 'stige',
    '🪏' => 'skovl',
    '⚗' => 'kolbe',
    '🧪' => 'reagensglas',
    '🧫' => 'petriskål',
    '🧬' => 'dna',
    '🔬' => 'mikroskop',
    '🔭' => 'teleskop',
    '📡' => 'parabolantenne',
    '💉' => 'sprøjte',
    '🩸' => 'bloddråbe',
    '💊' => 'pille',
    '🩹' => 'plaster',
    '🩼' => 'krykke',
    '🩺' => 'stetoskop',
    '🩻' => 'røntgen',
    '🚪' => 'dør',
    '🛗' => 'elevator',
    '🪞' => 'spejl',
    '🪟' => 'vindue',
    '🛏' => 'seng',
    '🛋' => 'sofa og lampe',
    '🪑' => 'stol',
    '🚽' => 'toilet',
    '🪠' => 'svupper',
    '🚿' => 'brusebad',
    '🛁' => 'badekar',
    '🪤' => 'musefælde',
    '🪒' => 'ragekniv',
    '🧴' => 'bodylotion',
    '🧷' => 'sikkerhedsnål',
    '🧹' => 'kost',
    '🧺' => 'kurv',
    '🧻' => 'papirrulle',
    '🪣' => 'spand',
    '🧼' => 'sæbe',
    '🫧' => 'bobler',
    '🪥' => 'tandbørste',
    '🧽' => 'vaskesvamp',
    '🧯' => 'brandslukker',
    '🛒' => 'indkøbsvogn',
    '🚬' => 'cigaret',
    '⚰' => 'kiste',
    '🪦' => 'gravsten',
    '⚱' => 'urne',
    '🧿' => 'nazaramulet',
    '🪬' => 'hamsa',
    '🗿' => 'statue',
    '🪧' => 'skilt',
    '🪪' => 'legitimationskort',
    '🏧' => 'hæveautomat',
    '🚮' => 'brug affaldsspanden',
    '🚰' => 'drikkevand',
    '♿' => 'symbol for kørestol',
    '🚹' => 'herretoilet',
    '🚺' => 'dametoilet',
    '🚻' => 'toiletskilt',
    '🚼' => 'babysymbol',
    '🚾' => 'wc',
    '🛂' => 'paskontrol',
    '🛃' => 'told',
    '🛄' => 'bagageudlevering',
    '🛅' => 'bagageopbevaring',
    '⚠' => 'advarselsskilt',
    '🚸' => 'børn krydser vej',
    '⛔' => 'adgang forbudt',
    '🚫' => 'ingen adgang',
    '🚳' => 'cykler forbudt',
    '🚭' => 'rygning forbudt',
    '🚯' => 'smid ikke affald',
    '🚱' => 'ikke drikkevand',
    '🚷' => 'ingen fodgængere',
    '📵' => 'mobiltelefoner forbudt',
    '🔞' => 'forbudt for under 18',
    '☢' => 'radioaktiv',
    '☣' => 'biologisk fare',
    '⬆' => 'opadvendt pil',
    '↗' => 'opadvendt pil mod højre',
    '➡' => 'pil mod højre',
    '↘' => 'nedadvendt pil mod højre',
    '⬇' => 'nedadvendt pil',
    '↙' => 'nedadvendt pil mod venstre',
    '⬅' => 'pil mod venstre',
    '↖' => 'opadvendt pil mod venstre',
    '↕' => 'op- og nedadvendt pil',
    '↔' => 'pil mod venstre og højre',
    '↩' => 'pil mod højre med sving til venstre',
    '↪' => 'pil mod venstre med sving til højre',
    '⤴' => 'pil mod højre med sving opad',
    '⤵' => 'pil mod højre med sving nedad',
    '🔃' => 'lodrette cirkulære pile med uret',
    '🔄' => 'vandrette cirkulære pile mod uret',
    '🔙' => 'BACK-pil',
    '🔚' => 'END-pil',
    '🔛' => 'ON!-dobbeltpil',
    '🔜' => 'SOON-pil',
    '🔝' => 'TOP-pil',
    '🛐' => 'bedested',
    '⚛' => 'atomsymbol',
    '🕉' => 'om',
    '✡' => 'davidsstjerne',
    '☸' => 'dharma-hjul',
    '☯' => 'yin og yang',
    '✝' => 'latinsk kors',
    '☦' => 'ortodokst kors',
    '☪' => 'stjerne og halvmåne',
    '☮' => 'fredssymbol',
    '🕎' => 'syvarmet lysestage',
    '🔯' => 'sekstakket stjerne med prik',
    '🪯' => 'khanda',
    '♈' => 'vædderen',
    '♉' => 'tyren',
    '♊' => 'tvillingen',
    '♋' => 'krebsen',
    '♌' => 'løven',
    '♍' => 'jomfruen',
    '♎' => 'vægten',
    '♏' => 'skorpionen',
    '♐' => 'skytten',
    '♑' => 'stenbukken',
    '♒' => 'vandmanden',
    '♓' => 'fisken',
    '⛎' => 'slangebæreren',
    '🔀' => 'bland sange-knap',
    '🔁' => 'gentageknap',
    '🔂' => 'knap til én gentagelse',
    '▶' => 'afspilningsknap',
    '⏩' => 'spol frem-knap',
    '⏭' => 'knap til næste nummer',
    '⏯' => 'knap til afspilning og pause',
    '◀' => 'knap til baglæns afspilning',
    '⏪' => 'spol tilbage-knap',
    '⏮' => 'knap til forrige nummer',
    '🔼' => 'op-knap',
    '⏫' => 'hurtigt op-knap',
    '🔽' => 'ned-knap',
    '⏬' => 'hurtigt ned-knap',
    '⏸' => 'pauseknap',
    '⏹' => 'stopknap',
    '⏺' => 'optageknap',
    '⏏' => 'udskubningsknap',
    '🎦' => 'film',
    '🔅' => 'lav lysstyrke',
    '🔆' => 'høj lysstyrke',
    '📶' => 'mobilsignal',
    '🛜' => 'trådløs',
    '📳' => 'vibration',
    '📴' => 'mobil slået fra',
    '♀' => 'kvindesymbol',
    '♂' => 'mandesymbol',
    '⚧' => 'symbol for transkønnethed',
    '✖' => 'gange',
    '➕' => 'plus',
    '➖' => 'minus',
    '➗' => 'dividere',
    '🟰' => 'fedt lighedstegn',
    '♾' => 'uendelig',
    '‼' => 'dobbelt udråbstegn',
    '⁉' => 'udråbstegn og spørgsmålstegn',
    '❓' => 'rødt spørgsmålstegn',
    '❔' => 'hvidt spørgsmålstegn',
    '❕' => 'hvidt udråbstegn',
    '❗' => 'rødt udråbstegn',
    '〰' => 'bølgestreg',
    '💱' => 'valutaveksling',
    '💲' => 'dollartegn',
    '⚕' => 'medicinsymbol',
    '♻' => 'genbrug',
    '⚜' => 'fransk lilje',
    '🔱' => 'trefork',
    '📛' => 'navneskilt',
    '🔰' => 'japansk begyndersymbol',
    '⭕' => 'stor rød cirkel',
    '✅' => 'hvidt flueben',
    '☑' => 'afkrydsningsfelt med flueben',
    '✔' => 'flueben',
    '❌' => 'kryds',
    '❎' => 'krydsknap',
    '➰' => 'krølle',
    '➿' => 'dobbelt krølle',
    '〽' => 'japansk kommatering',
    '✳' => 'ottetakket spids stjerne',
    '✴' => 'ottetakket stjerne',
    '❇' => 'funkle',
    '™' => 'varemærke',
    '🫟' => 'klat',
    '🔠' => 'store bogstaver',
    '🔡' => 'små bogstaver',
    '🔢' => 'tal',
    '🔣' => 'symboler',
    '🔤' => 'latinske alfabet',
    '🅰' => 'blodtype A',
    '🆎' => 'blodtype AB',
    '🅱' => 'blodtype B',
    '🆑' => 'CL-knap',
    '🆒' => 'COOL-knap',
    '🆓' => 'FREE-knap',
    'ℹ' => 'information',
    '🆔' => 'ID-knap',
    'Ⓜ' => 'm i cirkel',
    '🆕' => 'NEW-knap',
    '🆖' => 'NG-knap',
    '🅾' => 'blodtype O',
    '🆗' => 'OK',
    '🅿' => 'parkering',
    '🆘' => 'SOS',
    '🆙' => 'UP!-knap',
    '🆚' => 'versus',
    '🈁' => 'kvadratisk ideogram for her',
    '🈂' => 'kvadratisk ideogram for serviceafgift',
    '🈷' => 'kvadratisk ideogram for månedligt beløb',
    '🈶' => 'kvadratisk ideogram for ikke gratis',
    '🈯' => 'kvadratisk ideogram for reserveret',
    '🉐' => 'cirkulært ideogram for tilbud',
    '🈹' => 'kvadratisk ideogram for rabat',
    '🈚' => 'kvadratisk ideogram for gratis',
    '🈲' => 'kvadratisk ideogram for forbud',
    '🉑' => 'cirkulært ideogram for accept',
    '🈸' => 'kvadratisk ideogram for anvendelse',
    '🈴' => 'kvadratisk ideogram for bestået',
    '🈳' => 'kvadratisk ideogram for ledig',
    '㊗' => 'cirkulært ideogram for lykønskning',
    '㊙' => 'cirkulært ideogram for hemmelighed',
    '🈺' => 'kvadratisk ideogram for åben',
    '🈵' => 'kvadratisk ideogram for optaget',
    '🔴' => 'rød cirkel',
    '🟠' => 'orange cirkel',
    '🟡' => 'gul cirkel',
    '🟢' => 'grøn cirkel',
    '🔵' => 'blå cirkel',
    '🟣' => 'lilla cirkel',
    '🟤' => 'brun cirkel',
    '⚫' => 'sort cirkel',
    '⚪' => 'hvid cirkel',
    '🟥' => 'rødt kvadrat',
    '🟧' => 'orange kvadrat',
    '🟨' => 'gult kvadrat',
    '🟩' => 'grønt kvadrat',
    '🟦' => 'blåt kvadrat',
    '🟪' => 'lilla kvadrat',
    '🟫' => 'brunt kvadrat',
    '⬛' => 'stort sort kvadrat',
    '⬜' => 'stort hvidt kvadrat',
    '◼' => 'mellemstort sort kvadrat',
    '◻' => 'mellemstort hvidt kvadrat',
    '◾' => 'halvlille sort kvadrat',
    '◽' => 'halvlille hvidt kvadrat',
    '▪' => 'lille sort kvadrat',
    '▫' => 'lille hvidt kvadrat',
    '🔶' => 'stor orange ruder',
    '🔷' => 'stor blå ruder',
    '🔸' => 'lille orange ruder',
    '🔹' => 'lille blå ruder',
    '🔺' => 'op-trekant',
    '🔻' => 'ned-trekant',
    '💠' => 'ruder med prik',
    '🔘' => 'alternativknap',
    '🔳' => 'hvid kvadratisk knap',
    '🔲' => 'sort kvadratisk knap',
    '🏁' => 'ternet flag',
    '🚩' => 'trekantet flag',
    '🎌' => 'to krydsede flag',
    '🏴' => 'sort flag',
    '🏳' => 'hvidt flag',
];
